@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -16,18 +16,18 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 #ifdef PRECOMP
 #	include "xmule-headers.h"
-#else
-#	include "BarShader.h"
-#	include "otherfunctions.h"
-#	include "wintypes.h"
-#	include "xmule.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include "BarShader.h"                      // Module's Prototype(s) - audited 5 Nov 2004
+#include "wintypes.h"                       // DWORD - audited 4 Nov 2004
+#include "xmule.h"                          // theApp - audited 4 Nov 2004
 
-#include <math.h>
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+
+#include <cmath>                            // sin
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -56,7 +56,7 @@ static char THIS_FILE[] = __FILE__;
 
 #define min(a,b) ((a)<(b)?(a):(b))
 
-CBarShader::CBarShader(uint32 height, uint32 width)
+CBarShader::CBarShader(uint32_t height, uint32_t width)
 {
     m_iWidth = width;
     m_iHeight = height;
@@ -96,17 +96,31 @@ void CBarShader::BuildModifiers()
     m_Modifiers[i] = (float)(sin(base + i *increment));
 }
 
-void CBarShader::SetFileSize(uint32 fileSize)
+void CBarShader::SetScaling(void)
+{
+  // Take care to avoid division by zero in corner cases.
+  if (m_uFileSize == 0)
+    m_dPixelsPerByte = (double) m_iWidth;
+  else
+    m_dPixelsPerByte = (double) m_iWidth / m_uFileSize;
+
+  if (m_iWidth == 0)
+    m_dBytesPerPixel = (double) m_uFileSize;
+  else
+    m_dBytesPerPixel = (double) m_uFileSize / m_iWidth;
+
+}
+
+void CBarShader::SetFileSize(uint32_t fileSize)
 {
     if (m_uFileSize != fileSize)
     {
         m_uFileSize = fileSize;
-        m_dPixelsPerByte = (double) m_iWidth / m_uFileSize;
-        m_dBytesPerPixel = (double) m_uFileSize / m_iWidth;
+        SetScaling();
     }
 }
 
-void CBarShader::FillRange(uint32 start, uint32 end, DWORD color)
+void CBarShader::FillRange(uint32_t start, uint32_t end, DWORD color)
 {
     if (end > m_uFileSize)
     {
@@ -198,11 +212,11 @@ void CBarShader::Draw(wxDC *dc, int iLeft, int iTop, bool bFlat)
     dc->SetPen( *wxTRANSPARENT_PEN);
     int iBytesInOnePixel = (int)(m_dBytesPerPixel + 0.5f);
     //bsCurrent->start;:
-    uint32 start = 0;
-    uint32 drawnItems = 0;
+    uint32_t start = 0;
+    uint32_t drawnItems = 0;
     while (bsCurrent != NULL && rectSpan.right < static_cast<unsigned int>(iLeft + m_iWidth))
     {
-        uint32 uSpan = bsCurrent->end - start;
+        uint32_t uSpan = bsCurrent->end - start;
         int iPixels = (int)(uSpan *m_dPixelsPerByte + 0.5f);
         if (iPixels > 0)
         {
@@ -217,7 +231,7 @@ void CBarShader::Draw(wxDC *dc, int iLeft, int iTop, bool bFlat)
             float fRed = 0;
             float fGreen = 0;
             float fBlue = 0;
-            uint32 iEnd = start + iBytesInOnePixel;
+            uint32_t iEnd = start + iBytesInOnePixel;
             int iLast = start;
             do
             {
