@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     29/01/98
-// RCS-ID:      $Id: CFile.h,v 1.19 2004/10/29 17:23:25 HopeSeekr Exp $
+// RCS-ID:      $Id: CFile.h,v 1.21 2004/11/08 04:58:50 HopeSeekr Exp $
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -43,8 +43,6 @@
 
 #include <wx/file.h>
 
-#include "mfc.h"
-
 // ----------------------------------------------------------------------------
 // constants
 // ----------------------------------------------------------------------------
@@ -109,7 +107,7 @@ public:
               int access = wxS_DEFAULT);
   virtual bool Open(const wxChar *szFileName, OpenMode mode = read,
             int access = wxS_DEFAULT);
-  bool Open(CString szFileName, OpenMode mode = read,
+  bool Open(wxString szFileName, OpenMode mode = read,
 		    int access = wxS_DEFAULT) {
     return Open(szFileName.GetData(),mode,access);
   };
