@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 //Copyright (C)2002 Merkur (merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -20,15 +20,14 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "ChatWnd.h"
-#	include "muuli_wdr.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/sizer.h>                       // wxSizer
+#include "ChatWnd.h"                        // Needed for Module's Prototype(s) - audited 6 Nov 2004
+#include "muuli_wdr.h"                      // Needed for messageDlg - audited 4 Nov 2004
+
+#include <wx/settings.h>                    // Needed for wxSystemSettings
+#include <wx/sizer.h>                       // Needed for wxSizer
 
 CChatWnd::CChatWnd(wxWindow *pParent): wxPanel(pParent, -1)
 {
@@ -57,7 +56,7 @@ END_MESSAGE_MAP()
 
 // CChatWnd message handlers
 
-BOOL CChatWnd::OnInitDialog()
+bool CChatWnd::OnInitDialog()
 {
     CResizableDialog::OnInitDialog();
     Localize();
@@ -90,7 +89,7 @@ void CChatWnd::StartSession(CUpDownClient *client)
 #if 0
 void CChatWnd::OnBnClickedCsend()
 {
-    uint16 len = GetDlgItem(IDC_CMESSAGE)->GetWindowTextLength() + 2;
+    uint16_t len = GetDlgItem(IDC_CMESSAGE)->GetWindowTextLength() + 2;
     char *messagetosend = new char[len + 1];
     GetDlgItem(IDC_CMESSAGE)->GetWindowText(messagetosend, len);
     if (chatselector.SendMessage(messagetosend))
@@ -98,7 +97,7 @@ void CChatWnd::OnBnClickedCsend()
     delete[] messagetosend;
 }
 
-void CChatWnd::OnShowWindow(BOOL bShow, UINT nStatus)
+void CChatWnd::OnShowWindow(bool bShow, UINT nStatus)
 {
     if (bShow)
     chatselector.ShowChat();
@@ -109,7 +108,7 @@ void CChatWnd::OnBnClickedCclose()
     chatselector.EndSession();
 }
 
-BOOL CChatWnd::PreTranslateMessage(MSG *pMsg)
+bool CChatWnd::PreTranslateMessage(MSG *pMsg)
 {
     if ((pMsg->message == WM_KEYDOWN) && (pMsg->wParam == 13))
     {
