@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,40 +22,36 @@
 #ifndef CHATWND_H
 #define CHATWND_H 1
 
-#include <wx/panel.h>
+#include "resource.h"                       // Needed for IDD_CHAT - audited 4 Nov 2004
+
+#include <wx/panel.h>                       // Needed for wxPanel
 
 class CUpDownClient;
 
-//#include "afxdlgs.h"
-#include "resource.h"
-#include "wintypes.h"
-//#include "HyperTextCtrl.h"
-//#include "ChatSelector.h"
-//#include "ResizableLib/ResizableDialog.h"
-// CChatWnd dialog
-
 class CChatWnd : public wxPanel //CResizableDialog
 {
-  //DECLARE_DYNAMIC(CChatWnd)
 public:
-	CChatWnd(wxWindow* pParent = NULL);   // standard constructor
-	virtual ~CChatWnd();
+    CChatWnd(wxWindow* pParent = NULL);   // standard constructor
+    virtual ~CChatWnd();
 
 // Dialog Data
-	enum { IDD = IDD_CHAT };
-	void StartSession(CUpDownClient* client);
-	void Localize();
-	//CChatSelector chatselector;
+    enum
+    {
+        IDD = IDD_CHAT
+    };
+
+    void StartSession(CUpDownClient* client);
+    void Localize();
 protected:
-#if 0
-	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support	
-	DECLARE_MESSAGE_MAP()
-	virtual BOOL OnInitDialog(); 
-	afx_msg void OnBnClickedCsend();
-	void	OnShowWindow(BOOL bShow,UINT nStatus);
-	virtual BOOL	PreTranslateMessage(MSG* pMsg);
+/*
+    virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support	
+    DECLARE_MESSAGE_MAP()
+    virtual bool OnInitDialog(); 
+    afx_msg void OnBnClickedCsend();
+    void	OnShowWindow(bool bShow,UINT nStatus);
+    virtual bool	PreTranslateMessage(MSG* pMsg);
 public:
-	afx_msg void OnBnClickedCclose();
-#endif
+    afx_msg void OnBnClickedCclose();
+*/
 };
 #endif
