@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,37 +22,29 @@
 #ifndef CLIENTDETAILDLG_H
 #define CLIENTDETAILDLG_H
 
-#include "resource.h"
-#include "types.h"
-#include "updownclient.h"
-#include "wintypes.h"
+#include "resource.h"                       // Needed for IDD_SOURCEDETAILWND - audited 4 Nov 2004
 
-#include <wx/dialog.h>
-// CClientDetailDialog dialog
+#include <stdint.h>                         // Needed for uint16_t
+#include <wx/dialog.h>                      // Needed for wxDialog
+
+class CUpDownClient;
 
 class CClientDetailDialog : public wxDialog
 {
-  //DECLARE_DYNAMIC(CClientDetailDialog)
-
 public:
-	CClientDetailDialog(wxWindow*parent,CUpDownClient* client);   // standard constructor
-	void Localize();
-	virtual ~CClientDetailDialog();
-	virtual BOOL OnInitDialog();
+    CClientDetailDialog(wxWindow* parent, CUpDownClient* client);   // standard constructor
+    void Localize();
+    virtual ~CClientDetailDialog();
+    virtual bool OnInitDialog();
 // Dialog Data
-	enum { IDD = IDD_SOURCEDETAILWND };
+enum { IDD = IDD_SOURCEDETAILWND };
 
 protected:
-#if 0
-	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-
-	DECLARE_MESSAGE_MAP()
-#endif
-	  void OnBnClose(wxCommandEvent& evt);
-
-	  DECLARE_EVENT_TABLE()
+    void OnBnClose(wxCommandEvent& evt);
+    DECLARE_EVENT_TABLE()
 
 private:
-	CUpDownClient* m_client;
+    CUpDownClient* m_client;
 };
+
 #endif
