@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,16 +22,17 @@
 //#include "stdafx.h"
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "ClientList.h"
-#	include "DownloadQueue.h"
-#	include "otherfunctions.h"
-#	include "UploadQueue.h"
-#	include "wintypes.h"
-#	include "xmule.h"
+    #include "xmule-headers.h"
 #endif
 
+#include "ClientList.h"                     // Needed for Module's Prototype(s) - audited 5 Nov 2004
+
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue - audited 5 Nov 2004
+#include "ListenSocket.h"                   // Needed for CClientReqSocket - audited 5 Nov 2004
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
+#include "UploadQueue.h"                    // Needed for CUploadQueue - audited 5 Nov 2004
+#include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
+
 CClientList::CClientList()
 {
 }
@@ -41,7 +42,7 @@ CClientList::~CClientList()
 }
 
 // xrmb : statsclientstatus
-void CClientList::GetStatistics(uint32 &totalclient, int stats[], std::map<uint16_t, uint32_t>* clientVersionEDonkey, std::map< uint16_t, uint32_t >* clientVersionEDonkeyHybrid, std::map< uint8_t, uint32_t >* clientVersionEMule)
+void CClientList::GetStatistics(uint32_t &totalclient, int stats[], std::map<uint16_t, uint32_t>* clientVersionEDonkey, std::map< uint16_t, uint32_t >* clientVersionEDonkeyHybrid, std::map< uint8_t, uint32_t >* clientVersionEMule)
 {
     memset(stats, 0, 8 * sizeof(int));
     //if(clientStatus)		clientStatus->RemoveAll();
@@ -81,7 +82,7 @@ void CClientList::GetStatistics(uint32 &totalclient, int stats[], std::map<uint1
             stats[2]++;
             if (clientVersionEMule)
             {
-                uint8 version = cur_client->GetMuleVersion();
+                uint8_t version = cur_client->GetMuleVersion();
                 ( *clientVersionEMule) [version]++;
             }
             break;
@@ -139,6 +140,7 @@ void CClientList::DeleteAll()
         CUpDownClient* cur_client = list.GetAt(pos2);
         list.RemoveAt(pos2);
         // recursiv: this will call RemoveClient:
+        delete cur_client;
     }
 }
 
@@ -175,7 +177,7 @@ bool CClientList::AttachToAlreadyKnown(CUpDownClient **client, CClientReqSocket
     return false;
 }
 
-CUpDownClient *CClientList::FindClientByIP(uint32 clientip, uint16 port)
+CUpDownClient *CClientList::FindClientByIP(uint32_t clientip, uint16_t port)
 {
     POSITION pos1, pos2;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
@@ -188,7 +190,7 @@ CUpDownClient *CClientList::FindClientByIP(uint32 clientip, uint16 port)
     return 0;
 }
 
-CUpDownClient *CClientList::FindClientByUserHash(uchar *clienthash)
+CUpDownClient *CClientList::FindClientByUserHash(unsigned char *clienthash)
 {
     POSITION pos1, pos2;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
