@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -86,11 +86,11 @@ END_EVENT_TABLE()
 
 #if 0
 /////////////////////////////////////////////////////////////////////////////
-BOOL CColorFrameCtrl::Create(DWORD dwStyle, const RECT &rect,
+bool CColorFrameCtrl::Create(DWORD dwStyle, const RECT &rect,
 CWnd *pParentWnd, UINT nID)
 {
-    BOOL result;
-    static CString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
+    bool result;
+    static wxString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
     result = CWnd::CreateEx(WS_EX_STATICEDGE,
     className, NULL, dwStyle,
     rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
@@ -138,11 +138,18 @@ void CColorFrameCtrl::OnPaint(wxPaintEvent &evt)
 {
     //CPaintDC dc(this) ;  // device context for painting
     wxPaintDC dc(this);
-    wxRect rc;
+    wxRect rc = GetClientRect();
+
+    /*    wxRect rc = GetClientRect();
+    m_rectClient.left = rc.x;
+    m_rectClient.top = rc.y;
+    m_rectClient.right = rc.x + rc.width;
+    m_rectClient.bottom = rc.y + rc.height;
+
     rc.x = m_rectClient.left;
     rc.y = m_rectClient.top;
     rc.width = m_rectClient.right - m_rectClient.left;
-    rc.height = m_rectClient.bottom - m_rectClient.top;
+    rc.height = m_rectClient.bottom - m_rectClient.top;*/
     //rc.Deflate(1,1);
     //rc.Offset(1,1);
     //rc.Inflate(-1,-1);
@@ -175,11 +182,11 @@ void CColorFrameCtrl::OnSize(wxSizeEvent &evt)
     //CWnd::OnSize(nType, cx, cy) ;
     // NOTE: OnSize automatically gets called during the setup of the control
     //GetClientRect(m_rectClient) ;
-    wxRect rc = GetClientRect();
+/*    wxRect rc = GetClientRect();
     m_rectClient.left = rc.x;
     m_rectClient.top = rc.y;
     m_rectClient.right = rc.x + rc.width;
-    m_rectClient.bottom = rc.y + rc.height;
+    m_rectClient.bottom = rc.y + rc.height;*/
     // OnSize:
 }
 
