@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -74,7 +74,7 @@ void CCommentDialogLst::OnBnClickedRefresh(wxCommandEvent &evt)
     CompleteList();
 }
 
-BOOL CCommentDialogLst::OnInitDialog()
+bool CCommentDialogLst::OnInitDialog()
 {
     //CDialog::OnInitDialog();
     pmyListCtrl->InsertColumn(0, GetResString(IDS_CD_UNAME), wxLIST_FORMAT_LEFT, 130);
