@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,25 +22,28 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#	include "updownclient.h"
 #include "ClientList.h"                     // CClientList
 #	include "ClientUDPSocket.h"
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl - audited 5 Nov 2004
 #	include "DownloadQueue.h"
 #	include "ListenSocket.h"
+#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOPdata - audited 5 Nov 2004
 #	include "opcodes.h"
 #	include "packets.h"
 #	include "PartFile.h"
 #include "SafeFile.h"                       // CSafeMemFile
 #include "ServerSocket.h"                   // CServerConnect
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
 #	include "TransferWnd.h"
-#	include "updownclient.h"
 #	include "UploadQueue.h"
 #	include "wintypes.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
-#	include "NewSockets.h"
 #endif
-
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include "ClientCredits.h"                  // CClientCredits
+#include "otherstructs.h"                   // Needed for Requested_Block_Struct - audited 5 Nov 2004
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <zlib.h>
 
@@ -82,11 +85,11 @@ void CUpDownClient::DrawStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyrect
     ShowDownloadingParts(gettingParts);
     if (!onlygreyrect &&reqfile &&m_abyPartStatus)
     {
-        for (uint32 i = 0 ; i != m_nPartCount ; i++)
+        for (uint32_t i = 0; i != m_nPartCount; i++)
         {
             if (m_abyPartStatus[i])
             {
-                uint32 uEnd;
+                uint32_t uEnd;
                 if (PARTSIZE * (i + 1) > reqfile->GetFileSize())
                 uEnd = reqfile->GetFileSize();
                 else
@@ -214,13 +217,13 @@ void CUpDownClient::SendFileRequest()
             dataFileReq = new CSafeMemFile(16);
             dataFileReq->Write(reqfile->GetFileHash(), 16);
         }
-        NewSocket_SendPacketOPdata(2, OP_FILEREQUEST, dataFileReq, (wxUint32) this, 0);
+        NewSocket_SendPacketOPdata(2, OP_FILEREQUEST, dataFileReq, (uint32_t) this, 0);
         delete dataFileReq;
         if (reqfile->GetPartCount() > 0)
         {
             CSafeMemFile dataSetReqFileID(16);
             dataSetReqFileID.Write(reqfile->GetFileHash(), 16);
-            NewSocket_SendPacketOPdata(2, OP_SETREQFILEID, &dataSetReqFileID, (wxUint32) this, 0);
+            NewSocket_SendPacketOPdata(2, OP_SETREQFILEID, &dataSetReqFileID, (uint32_t) this, 0);
         }
         if (IsEmuleClient())
         {
@@ -234,19 +237,19 @@ void CUpDownClient::SendFileRequest()
                 reqfile->SetLastAnsweredTimeTimeout();
                 Packet *packet = new Packet(OP_REQUESTSOURCES, 16, OP_EMULEPROT);
                 md4cpy(packet->pBuffer, reqfile->GetFileHash());
-                NewSocket_SendPacketOP(2, OP_REQUESTSOURCES, packet, (wxUint32) this, 0);
+                NewSocket_SendPacketOP(2, OP_REQUESTSOURCES, packet, (uint32_t) this, 0);
                 SetLastAskedForSources();
             }
         }
     }
 }
 
-void CUpDownClient::ProcessFileInfo(char *packet, uint32 size)
+void CUpDownClient::ProcessFileInfo(char *packet, uint32_t size)
 {
     CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
-    uchar cfilehash[16];
+    unsigned char cfilehash[16];
     data->Read(cfilehash, 16);
-    uint16 namelength;
+    uint16_t namelength;
     data->Read( &namelength, 2);
     if (m_pszClientFilename) {
     delete[] m_pszClientFilename;
@@ -255,14 +258,14 @@ void CUpDownClient::ProcessFileInfo(char *packet, uint32 size)
     memset(m_pszClientFilename, 0, namelength + 1);
     // TODO why does this overwrite the end of the buffer:
     data->Read(m_pszClientFilename, namelength);
-    //- because sizeof(uint16) is always 2
+    //- because sizeof(uint16_t) is always 2
     delete data;
 }
 
-void CUpDownClient::ProcessFileStatus(char *packet, uint32 size)
+void CUpDownClient::ProcessFileStatus(char *packet, uint32_t size)
 {
     CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
-    uchar cfilehash[16];
+    unsigned char cfilehash[16];
     data->Read(cfilehash, 16);
     if ((reqfile) && (! memcmp(cfilehash, reqfile->GetFileHash(), 16)))
     {
@@ -276,7 +279,7 @@ void CUpDownClient::ProcessFileStatus(char *packet, uint32 size)
         if (!m_nPartCount)
         {
             m_nPartCount = reqfile->GetPartCount();
-            m_abyPartStatus = new uint8[m_nPartCount];
+            m_abyPartStatus = new uint8_t[m_nPartCount];
             memset(m_abyPartStatus, 1, m_nPartCount);
             bPartsNeeded = true;
             m_bCompleteSource = true;
@@ -286,13 +289,13 @@ void CUpDownClient::ProcessFileStatus(char *packet, uint32 size)
             if (reqfile->GetPartCount() == m_nPartCount)
             {
                 m_bCompleteSource = false;
-                m_abyPartStatus = new uint8[m_nPartCount];
-                uint16 done = 0;
+                m_abyPartStatus = new uint8_t[m_nPartCount];
+                uint16_t done = 0;
                 while (done != m_nPartCount)
                 {
-                    uint8 toread;
+                    uint8_t toread;
                     data->Read( &toread, 1);
-                    for (sint32 i = 0 ; i != 8 ; i++)
+                    for (int32_t i = 0; i != 8; i++)
                     {
                         m_abyPartStatus[done] = ((toread >> i) &1) ? 1: 0;
                         if (m_abyPartStatus[done] && !reqfile->IsComplete(done *PARTSIZE, ((done + 1) *PARTSIZE) - 1))
@@ -315,7 +318,7 @@ void CUpDownClient::ProcessFileStatus(char *packet, uint32 size)
         {
             Packet *packet = new Packet(OP_HASHSETREQUEST, 16);
             memcpy(packet->pBuffer, reqfile->GetFileHash(), 16);
-            NewSocket_SendPacketOP(2, OP_HASHSETREQUEST, packet, (wxUint32) this, 0);
+            NewSocket_SendPacketOP(2, OP_HASHSETREQUEST, packet, (uint32_t) this, 0);
             SetDownloadState(DS_REQHASHSET);
             reqfile->hashsetneeded = false;
             m_bHashsetRequested = true;
@@ -326,7 +329,7 @@ void CUpDownClient::ProcessFileStatus(char *packet, uint32 size)
             SetDownloadState(DS_ONQUEUE);
             data = new CSafeMemFile(16);
             data->Write(this->reqfile->GetFileHash(), 16);
-            NewSocket_SendPacketOPdata(2, OP_STARTUPLOADREQ, data, (wxUint32) this, 0);
+            NewSocket_SendPacketOPdata(2, OP_STARTUPLOADREQ, data, (uint32_t) this, 0);
         }
         reqfile->NewSrcPartsInfo();
     }
@@ -335,12 +338,12 @@ void CUpDownClient::ProcessFileStatus(char *packet, uint32 size)
 
 bool CUpDownClient::AddRequestForAnotherFile(CPartFile *file)
 {
-    for (POSITION pos = m_OtherNoNeeded_list.GetHeadPosition() ; pos != 0 ; m_OtherNoNeeded_list.GetNext(pos))
+    for (POSITION pos = m_OtherNoNeeded_list.GetHeadPosition(); pos != 0; m_OtherNoNeeded_list.GetNext(pos))
     {
         if (m_OtherNoNeeded_list.GetAt(pos) == file)
         return false;
     }
-    for (POSITION pos = m_OtherRequests_list.GetHeadPosition() ; pos != 0 ; m_OtherRequests_list.GetNext(pos))
+    for (POSITION pos = m_OtherRequests_list.GetHeadPosition(); pos != 0; m_OtherRequests_list.GetNext(pos))
     {
         if (m_OtherRequests_list.GetAt(pos) == file)
         return false;
@@ -351,7 +354,7 @@ bool CUpDownClient::AddRequestForAnotherFile(CPartFile *file)
     return true;
 }
 
-void CUpDownClient::SetDownloadState(uint8 byNewState)
+void CUpDownClient::SetDownloadState(uint8_t byNewState)
 {
     if (m_nDownloadState != byNewState)
     {
@@ -368,14 +371,14 @@ void CUpDownClient::SetDownloadState(uint8 byNewState)
         if (m_nDownloadState == DS_DOWNLOADING)
         {
             m_nDownloadState = byNewState;
-            for (POSITION pos = m_DownloadBlocks_list.GetHeadPosition() ; pos != 0 ; m_DownloadBlocks_list.GetNext(pos))
+            for (POSITION pos = m_DownloadBlocks_list.GetHeadPosition(); pos != 0; m_DownloadBlocks_list.GetNext(pos))
             {
                 Requested_Block_Struct *cur_block = m_DownloadBlocks_list.GetAt(pos);
                 reqfile->RemoveBlockFromList(cur_block->StartOffset, cur_block->EndOffset);
                 delete m_DownloadBlocks_list.GetAt(pos);
             }
             m_DownloadBlocks_list.RemoveAll();
-            for (POSITION pos = m_PendingBlocks_list.GetHeadPosition() ; pos != 0 ; m_PendingBlocks_list.GetNext(pos))
+            for (POSITION pos = m_PendingBlocks_list.GetHeadPosition(); pos != 0; m_PendingBlocks_list.GetNext(pos))
             {
                 Pending_Block_Struct *pending = m_PendingBlocks_list.GetAt(pos);
                 if (reqfile)
@@ -421,7 +424,7 @@ void CUpDownClient::SetDownloadState(uint8 byNewState)
     }
 }
 
-void CUpDownClient::ProcessHashSet(unsigned char *packet, uint32 size)
+void CUpDownClient::ProcessHashSet(unsigned char *packet, uint32_t size)
 {
     if (reqfile && (!memcmp(packet, reqfile->GetFileHash(), 16)))
     {
@@ -435,7 +438,7 @@ void CUpDownClient::ProcessHashSet(unsigned char *packet, uint32 size)
                 delete data;
                 data = new CSafeMemFile(16);
                 data->Write(this->reqfile->GetFileHash(), 16);
-                NewSocket_SendPacketOPdata(2, OP_STARTUPLOADREQ, data, (wxUint32) this, 1);
+                NewSocket_SendPacketOPdata(2, OP_STARTUPLOADREQ, data, (uint32_t) this, 1);
             }
             else
             {
@@ -456,11 +459,11 @@ void CUpDownClient::SendBlockRequests()
             if (m_PendingBlocks_list.GetCount() < 3) 
             {
                 // Barry - instead of getting 3, just get how many is needed
-                uint16 count = 3 - m_PendingBlocks_list.GetCount();
+                uint16_t count = 3 - m_PendingBlocks_list.GetCount();
                 Requested_Block_Struct **toadd = new Requested_Block_Struct *[count];
                 if (reqfile->GetNextRequestedBlock(this, toadd, &count))
                 {
-                    for (int i = 0 ; i != count ; i++) 
+                    for (int i = 0; i != count; i++) 
                     {
                         m_DownloadBlocks_list.AddTail(toadd[i]);
                     }
@@ -480,7 +483,7 @@ void CUpDownClient::SendBlockRequests()
         }
         if (m_PendingBlocks_list.IsEmpty())
         {
-            NewSocket_SendPacketOPdata(2, OP_CANCELTRANSFER, NULL, (wxUint32) this, 0);
+            NewSocket_SendPacketOPdata(2, OP_CANCELTRANSFER, NULL, (uint32_t) this, 0);
             SetDownloadState(DS_NONEEDEDPARTS);
         }
         else
@@ -488,9 +491,9 @@ void CUpDownClient::SendBlockRequests()
             CMemFile *data = new CMemFile(40);
             data->Write(reqfile->GetFileHash(), 16);
             POSITION pos = m_PendingBlocks_list.GetHeadPosition();
-            uint32 null = 0;
+            uint32_t null = 0;
             Requested_Block_Struct *block;
-            for (uint32 i = 0 ; i != 3 ; i++)
+            for (uint32_t i = 0; i != 3; i++)
             {
                 if (pos)
                 {
@@ -504,13 +507,13 @@ void CUpDownClient::SendBlockRequests()
                 }
             }
             pos = m_PendingBlocks_list.GetHeadPosition();
-            for (uint32 i = 0 ; i != 3 ; i++)
+            for (uint32_t i = 0; i != 3; i++)
             {
                 if (pos)
                 {
                     block = m_PendingBlocks_list.GetAt(pos)->block;
                     m_PendingBlocks_list.GetNext(pos);
-                    uint32 endpos = block->EndOffset + 1;
+                    uint32_t endpos = block->EndOffset + 1;
                     data->Write( &endpos, 4);
                 }
                 else
@@ -518,13 +521,13 @@ void CUpDownClient::SendBlockRequests()
                     data->Write( &null, 4);
                 }
             }
-            NewSocket_SendPacketOPdata(2, OP_REQUESTPARTS, data, (wxUint32) this, 0);
+            NewSocket_SendPacketOPdata(2, OP_REQUESTPARTS, data, (uint32_t) this, 0);
             delete data;
         }
     }
 }
 
-void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed)
+void CUpDownClient::ProcessBlockPacket(char *packet, uint32_t size, bool packed)
 {
     // Ignore if no data required
     if (! (GetDownloadState() == DS_DOWNLOADING || GetDownloadState() == DS_NONEEDEDPARTS))
@@ -534,15 +537,15 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed)
     m_dwLastBlockReceived =::GetTickCount();
     // Read data from packet
     CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
-    uchar fileID[16];
+    unsigned char fileID[16];
     data->Read(fileID, 16);
     // Check that this data is for the correct file
     if (reqfile && (! memcmp(packet, reqfile->GetFileHash(), 16)))
     {
         // Find the start & end positions, and size of this chunk of data
-        uint32 nStartPos;
-        uint32 nEndPos;
-        uint32 nBlockSize = 0;
+        uint32_t nStartPos;
+        uint32_t nEndPos;
+        uint32_t nBlockSize = 0;
         data->Read( &nStartPos, 4);
         if (packed)
         {
@@ -564,7 +567,7 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed)
             nEndPos--;
             // Loop through to find the reserved block that this is within
             Pending_Block_Struct *cur_block;
-            for (POSITION pos = m_PendingBlocks_list.GetHeadPosition() ; pos != NULL ; m_PendingBlocks_list.GetNext(pos))
+            for (POSITION pos = m_PendingBlocks_list.GetHeadPosition(); pos != NULL; m_PendingBlocks_list.GetNext(pos))
             {
                 cur_block = m_PendingBlocks_list.GetAt(pos);
                 if ((cur_block->block->StartOffset <= nStartPos) && (cur_block->block->EndOffset >= nStartPos))
@@ -580,7 +583,7 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed)
                     m_nLastBlockOffset = nStartPos;
                     // Occasionally packets are duplicated, no point writing it twice
                     // This will be 0 in these cases, or the length written otherwise
-                    uint32 lenWritten = 0;
+                    uint32_t lenWritten = 0;
                     // Handle differently depending on whether packed or not
                     if (!packed)
                     {
@@ -595,7 +598,7 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed)
                     else
                     {
                         // Create space to store unzipped data, the size is only an initial guess, will be resized in unzip() if not big enough
-                        uint32 lenUnzipped = (size *2);
+                        uint32_t lenUnzipped = (size *2);
                         // Don't get too big
                         if (lenUnzipped > (GAPBLOCKSIZE + 300))
                         lenUnzipped = (GAPBLOCKSIZE + 300);
@@ -627,9 +630,13 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed)
                         }
                         else
                         {
-                            CString strZipError;
-                            if (cur_block->zStream &&cur_block->zStream->msg)
-                            strZipError.Format(_T(" - %s"), cur_block->zStream->msg);
+//                          wxString strZipError;
+//
+//                          if (cur_block->zStream && cur_block->zStream->msg)
+//                          {
+//                              strZipError.Printf(_T(" - %s"), cur_block->zStream->msg);
+//                          }
+
                             reqfile->RemoveBlockFromList(cur_block->block->StartOffset, cur_block->block->EndOffset);
                             // If we had an zstream error, there is no chance that we could recover from it nor that we
                             // could use the current zstream (which is in error state) any longer.
@@ -680,7 +687,7 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed)
     }
 }
 
-int CUpDownClient::unzip(Pending_Block_Struct *block, BYTE *zipped, uint32 lenZipped, BYTE **unzipped, uint32 *lenUnzipped, bool recursive)
+int CUpDownClient::unzip(Pending_Block_Struct *block, BYTE *zipped, uint32_t lenZipped, BYTE **unzipped, uint32_t *lenUnzipped, bool recursive)
 {
     int err = Z_DATA_ERROR;
     try
@@ -731,7 +738,7 @@ int CUpDownClient::unzip(Pending_Block_Struct *block, BYTE *zipped, uint32 lenZi
         {
             // Output array was not big enough, call recursively until there is enough space
             // What size should we try next
-            uint32 newLength = ( *lenUnzipped) *= 2;
+            uint32_t newLength = ( *lenUnzipped) *= 2;
             if (newLength == 0)
             newLength = lenZipped *2;
             // Copy any data that was successfully unzipped to new array
@@ -767,7 +774,7 @@ int CUpDownClient::unzip(Pending_Block_Struct *block, BYTE *zipped, uint32 lenZi
     return err;
 }
 
-uint32 CUpDownClient::CalculateDownloadRate()
+uint32_t CUpDownClient::CalculateDownloadRate()
 {
     m_AvarageDDR_list.AddTail(m_nDownDataRateMS);
     m_nSumForAvgDownDataRate += m_nDownDataRateMS;
@@ -787,16 +794,16 @@ uint32 CUpDownClient::CalculateDownloadRate()
     }
     if ((::GetTickCount() - m_dwLastBlockReceived) > DOWNLOADTIMEOUT)
     {
-        NewSocket_SendPacketOPdata(2, OP_CANCELTRANSFER, NULL, (wxUint32) this, 1);
+        NewSocket_SendPacketOPdata(2, OP_CANCELTRANSFER, NULL, (uint32_t) this, 1);
         SetDownloadState(DS_ONQUEUE);
     }
     return m_nDownDatarate;
 }
 
-uint16 CUpDownClient::GetAvailablePartCount()
+uint16_t CUpDownClient::GetAvailablePartCount()
 {
-    uint16 result = 0;
-    for (int i = 0 ; i != m_nPartCount ; i++)
+    uint16_t result = 0;
+    for (int i = 0; i != m_nPartCount; i++)
     {
         if (IsPartAvailable(i))
         result++;
@@ -804,13 +811,13 @@ uint16 CUpDownClient::GetAvailablePartCount()
     return result;
 }
 
-void CUpDownClient::SetRemoteQueueRank(uint16 nr)
+void CUpDownClient::SetRemoteQueueRank(uint16_t nr)
 {
     m_nRemoteQueueRank = nr;
     theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
 }
 
-void CUpDownClient::UDPReaskACK(uint16 nNewQR)
+void CUpDownClient::UDPReaskACK(uint16_t nNewQR)
 {
     m_bUDPPending = false;
     SetRemoteQueueRank(nNewQR);
@@ -838,7 +845,7 @@ void CUpDownClient::UDPReaskForDownload()
             if (IsSourceRequestAllowed())
             {
                 m_bUDPPending = true;
-                uint16 packetsize;
+                uint16_t packetsize;
                 if (GetUDPVersion() >= 3)
                 {
                     packetsize = 18;
@@ -852,7 +859,7 @@ void CUpDownClient::UDPReaskForDownload()
                 // #zegzav:completesrc (modify):
                 if (GetUDPVersion() >= 3)
                 {
-                    uint16 completecount = reqfile->m_nCompleteSourcesCount;
+                    uint16_t completecount = reqfile->m_nCompleteSourcesCount;
                     memcpy(response->pBuffer + 16, &completecount, 2);
                 }
                 NewSocket_SendPacketOP(1, OP_REASKFILEPING, response, GetIP(), GetUDPPort());
@@ -867,8 +874,8 @@ void CUpDownClient::ShowDownloadingParts(wxString &partsYN)
     Requested_Block_Struct *cur_block;
     unsigned int x;
     partsYN.Alloc(m_nPartCount + 1);
-    for (x = 0 ; x <= m_nPartCount ; x++) partsYN.SetChar(x, 'N');
-    for (POSITION pos = m_PendingBlocks_list.GetHeadPosition() ; pos != 0 ; m_PendingBlocks_list.GetNext(pos))
+    for (x = 0; x <= m_nPartCount; x++) partsYN.SetChar(x, 'N');
+    for (POSITION pos = m_PendingBlocks_list.GetHeadPosition(); pos != 0; m_PendingBlocks_list.GetNext(pos))
     {
         cur_block = m_PendingBlocks_list.GetAt(pos)->block;
         x = (cur_block->StartOffset / PARTSIZE);
@@ -887,7 +894,7 @@ void CUpDownClient::ShowDownloadingParts(wxString &partsYN)
 void CUpDownClient::UpdateDisplayedInfo(bool force)
 {
     DWORD curTick =::GetTickCount();
-    if (force || curTick - m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE + (uint32)(rand() / (RAND_MAX/1000)))
+    if (force || curTick - m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE + (uint32_t)(rand() / (RAND_MAX/1000)))
     {
         theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
         m_lastRefreshedDLDisplay = curTick;
@@ -1018,7 +1025,7 @@ bool CUpDownClient::SwapToAnotherFile()
     {
         CPartFile *SwapTo = NULL;
         POSITION pos, pos1, pos2;
-        for (pos1 = this->m_OtherRequests_list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
+        for (pos1 = this->m_OtherRequests_list.GetHeadPosition(); (pos2 = pos1) != NULL;)
         {
             this->m_OtherRequests_list.GetNext(pos1);
             CPartFile *cur_file = this->m_OtherRequests_list.GetAt(pos2);
