@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,29 +22,18 @@
 #ifndef DOWNLOADLISTCTRL_H
 #define DOWNLOADLISTCTRL_H
 
-#include "mfc.h"
-#include "types.h"
-//#include "MemDC.h"
-//#include "TitleMenu.h"
-#include <map>
+#include "mfc.h"                            // Needed for CTypedPtrList - audited 4 Nov 2004
+#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl - audited 5 Nov 2004
+
+#include <list>                             // Needed for std::list
+#include <map>                              // Needed for std::multimap
+#include <stdint.h>                         // Needed for uint16_t
+#include <utility>                          // Needed for std::pair
 
-#include "wx/bitmap.h"
-#include "wx/menu.h"
-#include "wx/list.h"
-#include "MuleListCtrl.h" 
 class CPartFile;
 class CUpDownClient;
 
-enum ItemType {FILE_TYPE=1,AVAILABLE_SOURCE=2,UNAVAILABLE_SOURCE=3};
-struct CtrlItem_Struct{
-  ItemType            type;
-  CPartFile* owner;
-  void* value;
-  CtrlItem_Struct* parent;
-  DWORD            dwUpdated;
-  wxBitmap*          status;
-   ~CtrlItem_Struct() {delete status; }
-};
+class CtrlItem_Struct;
 // CDownloadListCtrl
 
 class CDownloadListCtrl : public CMuleListCtrl
@@ -58,7 +47,7 @@ public:
 
 	virtual ~CDownloadListCtrl();
 	//virtual void DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct);
-	uint8 curTab;
+	uint8_t curTab;
 	void	UpdateItem(void* toupdate);
 	void	Init();
 	void InitSort();
@@ -67,8 +56,8 @@ public:
 	void	RemoveSource(CUpDownClient* source,CPartFile* owner);
 	void	RemoveFile(CPartFile* toremove);
 	void	ClearCompleted();
-	//virtual BOOL OnCommand(WPARAM wParam,LPARAM lParam );
-	//virtual BOOL Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID);
+	//virtual bool OnCommand(WPARAM wParam,LPARAM lParam );
+	//virtual bool Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID);
 	void	SetStyle();
 	void	CreateMenues();
 	void	Localize();
@@ -95,8 +84,8 @@ public:
 protected:
 	void OnColResize(wxListEvent& evt);
 
-	void DrawFileItem(wxDC* dc,int nColumn,LPRECT lpRect,CtrlItem_Struct* lpCtrlItem);
-	void DrawSourceItem(wxDC* dc,int nColumn,LPRECT lpRect,CtrlItem_Struct* lpCtrlItem);
+	void DrawFileItem(wxDC* dc,int nColumn,LPRECT lpRect, CtrlItem_Struct* lpCtrlItem);
+	void DrawSourceItem(wxDC* dc,int nColumn,LPRECT lpRect, CtrlItem_Struct* lpCtrlItem);
 	/*
 	void	DrawFileItem(CDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
 	void	DrawSourceItem(CDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
@@ -126,10 +115,12 @@ protected:
 	bool ProcessEvent(wxEvent& evt);
 
 	void setPri(int newpri);
-	void collectSelections(CTypedPtrList<CPtrList,CPartFile*>* selectedList);
+	void collectSelections(std::list<CPartFile *>* selections);
  
 	DECLARE_EVENT_TABLE()
 private:
+    int m_cat_count;
+    void HandleCatClick(wxCommandEvent* event);
 	bool ShowItemInCurrentCat(CPartFile* file,int newsel);
 
 	typedef std::pair<void*,CtrlItem_Struct*> ListItemsPair;
