@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,20 +22,27 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#include "DownloadQueue.h"
+
 #	include "ClientList.h"
-#	include "DownloadQueue.h"
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl - audited 5 Nov 2004
 #include "packets.h"                        // Packet
 #	include "PartFile.h"
+#include "SearchDlg.h"                      // CSearchDlg::ExecuteLinkED2K
 #	include "SearchList.h"
 #include "server.h"                         // CServer
+#include "ServerList.h"                     // Need for CServerList - audited 5 Nov 2004
 #include "ServerSocket.h"                   // CServerConnect
+#include "SharedFileList.h"
+#include "sockets.h"                        // Needed for CServerConnect - audited 6 Nov 2004
 #	include "SysTray.h"
 #	include "TransferWnd.h"
 #	include "updownclient.h"
 #	include "xmuleDlg.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include "ED2KLink.h"                       // CED2KFileLink
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <wx/filename.h>
 #include <wx/listimpl.cpp>
@@ -99,7 +106,7 @@ CDownloadQueue::CDownloadQueue(CPreferences *in_prefs, CSharedFileList *in_share
 void CDownloadQueue::UpdateDisplayedInfo(bool force)
 {
     DWORD curTick =::GetTickCount();
-    if (force || curTick - m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE + (uint32)(rand() / (RAND_MAX/1000)))
+    if (force || curTick - m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE + (uint32_t)(rand() / (RAND_MAX/1000)))
     {
         theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
         m_lastRefreshedDLDisplay = curTick;
@@ -235,7 +242,7 @@ void CDownloadQueue::AddSearchToDownload(CSearchFile *toadd)
     AddDownload(newfile);
 }
 
-void CDownloadQueue::AddSearchToDownload(CString link)
+void CDownloadQueue::AddSearchToDownload(wxString link)
 {
     // Bodo: Why here not, but in
     // Bodo: void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd)?
@@ -257,28 +264,43 @@ void CDownloadQueue::StartNextFile()
     {
         return;
     }
-    CPartFile *pfile = NULL;
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+
+    CPartFile* pfile = NULL;
+
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
-        CPartFile *cur_file = filelist.GetAt(pos);
+        CPartFile* cur_file = filelist.GetAt(pos);
+
         if (cur_file->GetStatus() == PS_PAUSED)
         {
             if (!pfile)
             {
                 pfile = cur_file;
-                if (pfile->GetDownPriority() == PR_HIGH) break;
+
+                if (pfile->GetDownPriority() == PR_HIGH)
+                {
+                    break;
+                }
             }
             else
             {
                 if (cur_file->GetDownPriority() > pfile->GetDownPriority())
                 {
                     pfile = cur_file;
-                    if (pfile->GetDownPriority() == PR_HIGH) break;
+
+                    if (pfile->GetDownPriority() == PR_HIGH)
+                    {
+                        break;
+                    }
                 }
             }
         }
     }
-    if (pfile) pfile->ResumeFile();
+
+    if (pfile)
+    {
+        pfile->ResumeFile();
+    }
 }
 
 void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink *pLink)
@@ -304,7 +326,7 @@ void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink *pLink)
         }
         else
         {
-            CPartFile *partfile = GetFileByID((uchar *) pLink->GetHashKey());
+            CPartFile *partfile = GetFileByID((unsigned char *) pLink->GetHashKey());
             if (partfile) partfile->AddClientSources(pLink->SourcesList, 1);
         }
     }
@@ -321,14 +343,14 @@ void CDownloadQueue::AddDownload(CPartFile *newfile)
     SortByPriority();
     theApp.xmuledlg->transferwnd->downloadlistctrl->AddFile(newfile);
     theApp.xmuledlg->AddLogLine(true, GetResString(IDS_NEWDOWNLOAD), newfile->GetFileName());
-    CString msgTemp;
-    msgTemp.Format(GetResString(IDS_NEWDOWNLOAD) + "\n", newfile->GetFileName());
+    wxString msgTemp;
+    msgTemp = GetResString(IDS_NEWDOWNLOAD) + wxT("\n") + newfile->GetFileName();
     theApp.xmuledlg->ShowNotifier(msgTemp, TBN_DLOAD);
 }
 
-bool CDownloadQueue::IsFileExisting(uchar *fileid)
+bool CDownloadQueue::IsFileExisting(unsigned char *fileid)
 {
-    if (CKnownFile *file = sharedfilelist->GetFileByID((uchar *) fileid))
+    if (CKnownFile *file = sharedfilelist->GetFileByID((unsigned char *) fileid))
     {
         if (file->IsPartFile())
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName());
@@ -336,7 +358,7 @@ bool CDownloadQueue::IsFileExisting(uchar *fileid)
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADED), file->GetFileName());
         return true;
     }
-    else if(file = this->GetFileByID((uchar *) fileid))
+    else if(file = this->GetFileByID((unsigned char *) fileid))
     {
         theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName());
         return true;
@@ -346,10 +368,10 @@ bool CDownloadQueue::IsFileExisting(uchar *fileid)
 
 void CDownloadQueue::Process()
 {
-    uint32 downspeed = 0;
+    uint32_t downspeed = 0;
     if ((theApp.dynprefs->Get<long>("limits-download") != UNLIMITED) && (datarate > 1500))
     {
-        //(uint16)((float)((float)(app_prefs->GetMaxDownload()*1024)/(datarate+1)) * 100);:
+        //(uint16_t)((float)((float)(app_prefs->GetMaxDownload()*1024)/(datarate+1)) * 100);:
         downspeed = (theApp.dynprefs->Get<long>("limits-download") * 1024 * 100) / (datarate + 1);
         if (downspeed < 50)
         downspeed = 50;
@@ -401,7 +423,7 @@ void CDownloadQueue::Process()
     // Check for new links once per second.
     if ((::GetTickCount() - m_nLastED2KLinkCheck) >= 1000)
     {
-        wxString filename = filename.Format("%s/.xMule/ED2KLinks", getenv("HOME"));
+        wxString filename = wxString(getenv("HOME"), *wxConvCurrent) + wxT("/.xMule/ED2KLinks");
         if (wxFile::Exists(filename))
         {
             AddLinksFromFile();
@@ -410,7 +432,7 @@ void CDownloadQueue::Process()
     }
 }
 
-CPartFile *CDownloadQueue::GetFileByID(uchar *filehash)
+CPartFile *CDownloadQueue::GetFileByID(unsigned char *filehash)
 {
     for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
@@ -751,7 +773,7 @@ void CDownloadQueue::StopUDPRequests()
 void CDownloadQueue::SortByPriority()
 {
     POSITION pos1, pos2;
-    uint16 i = 0;
+    uint16_t i = 0;
     for (pos1 = filelist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         filelist.GetNext(pos1);
@@ -784,7 +806,7 @@ void CDownloadQueue::GetDownloadStats(int results[])
     }
 }
 
-CUpDownClient *CDownloadQueue::GetDownloadClientByIP(uint32 dwIP)
+CUpDownClient *CDownloadQueue::GetDownloadClientByIP(uint32_t dwIP)
 {
     for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
@@ -818,26 +840,8 @@ void CDownloadQueue::AddLinksFromFile()
             {
                 link += "/";
             }
-            try
-            {
-                CED2KLink *pLink = CED2KLink::CreateLinkFromUrl(link);
-                if (pLink->GetKind() == CED2KLink::kFile)
-                {
-                    // All seems ok, add it to download queue.
-                    AddFileLinkToDownload(pLink->GetFileLink());
-                }
-                else
-                {
-                    throw wxString(_("Bad link."));
-                }
-                delete pLink;
-            }
-            catch(wxString error)
-            {
-                char buffer[200];
-                sprintf(buffer, GetResString(IDS_ERR_INVALIDLINK), error.GetData());
-                theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_LINKERROR), buffer);
-            }
+
+            CSearchDlg::ExecuteLinkED2K(link);
             // We must double-check here where are we, because GetNextLine moves reading head
             // one line below, and we must make sure that line exists. Thus check if we are
             // at least one line away from end before trying to read next line.
@@ -944,7 +948,7 @@ void CDownloadQueue::ResetCatParts(int cat)
     }
 }
 
-void CDownloadQueue::SetCatPrio(int cat, uint8 newprio)
+void CDownloadQueue::SetCatPrio(int cat, uint8_t newprio)
 {
     for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
     {
@@ -982,6 +986,7 @@ void CDownloadQueue::SetCatStatus(int cat, int newstatus)
             {
             case MP_CANCEL:
                 cur_file->DeleteFile();
+                delete cur_file;
                 reset = true;
                 break;
             case MP_PAUSE:
