@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -139,7 +139,7 @@ CED2KServerLink::CED2KServerLink(const TCHAR *ip, const TCHAR *port)
     unsigned long ul = atoi(port);
     if (ul > 0xFFFF)
     throw GetResString(IDS_ERR_BADPORT);
-    m_port = static_cast < uint16 > (ul);
+    m_port = static_cast < uint16_t > (ul);
     m_defaultName = "Server ";
     m_defaultName += ip;
     m_defaultName += ":";
@@ -216,11 +216,11 @@ CED2KFileLink::CED2KFileLink(const TCHAR *name, const TCHAR *size, const TCHAR *
         //COleDateTime expirationDate;
         wxDateTime expirationDate;
         int nYear, nMonth, nDay;
-        uint16 nCount = 0;
-        uint32 dwID;
-        uint16 nPort;
-        uint32 dwServerIP = 0;
-        uint16 nServerPort = 0;
+        uint16_t nCount = 0;
+        uint32_t dwID;
+        uint16_t nPort;
+        uint32_t dwServerIP = 0;
+        uint16_t nServerPort = 0;
         unsigned long ul;
         int nInvalid = 0;
         pCh = strstr(pCh, _T("sources"));
@@ -259,7 +259,7 @@ CED2KFileLink::CED2KFileLink(const TCHAR *name, const TCHAR *size, const TCHAR *
                 // init to 0, we'll fix this at the end.:
                 SourcesList->Write( &nCount, sizeof(nCount));
                 // for each "ip:port" source string until the end
-                // limit to prevent overflow (uint16 due to CPartFile::AddClientSources)
+                // limit to prevent overflow (uint16_t due to CPartFile::AddClientSources)
 #define MAXSHORT 65535
                 while ( *pCh != 0 &&nCount < MAXSHORT)
                 {
@@ -287,7 +287,7 @@ CED2KFileLink::CED2KFileLink(const TCHAR *name, const TCHAR *size, const TCHAR *
                     dwID = inet_addr(pIP);
                     //tcstoul( pPort, 0, 10 );:
                     ul = atoi(pPort);
-                    nPort = static_cast < uint16 > (ul);
+                    nPort = static_cast < uint16_t > (ul);
                     // skip bad ips / ports
                     if (dwID == INADDR_NONE || dwID < 16777216 ||
                     ul > 0xFFFF || ul == 0)
