@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -20,12 +20,10 @@
 #ifndef ED2KLINK_H
 #define ED2KLINK_H
 
-//#include <tchar.h>
 #include "CMemFile.h"
 typedef char TCHAR;
 
-#include "types.h"
-
+#include <stdint.h>                         // uint16_t
 #include <wx/string.h>
 
 class CED2KLink {
@@ -52,15 +50,15 @@ public:
 	virtual void GetLink(wxString& lnk);
 
     // Accessors
-	uint32 GetIP() const { return m_ip;}
-	uint16 GetPort() const { return m_port;}
+	uint32_t GetIP() const { return m_ip;}
+	uint16_t GetPort() const { return m_port;}
 	void GetDefaultName(wxString& defName) const { defName = m_defaultName; }
 private:
 	CED2KServerLink(); // Not defined
 	CED2KServerLink(const CED2KServerLink&); // Not defined
 	CED2KServerLink& operator=(const CED2KServerLink&); // Not defined
-	uint32 m_ip;
-	uint16 m_port;
+	uint32_t m_ip;
+	uint16_t m_port;
 	wxString m_defaultName;
 };
 
@@ -75,7 +73,7 @@ public:
 	virtual void GetLink(wxString& lnk);
 	const char* GetName() const { return m_name; }
 	long GetSize() const { return atol(m_size); }
-	const uchar* GetHashKey() const { return m_hash;}
+	const unsigned char* GetHashKey() const { return m_hash;}
 	bool HasValidSources() const {return (SourcesList!=NULL); }
 	CMemFile* SourcesList;
 
@@ -85,7 +83,7 @@ private:
 	CED2KFileLink& operator=(const CED2KFileLink&); // Not defined
 	wxString m_name;
 	wxString m_size;
-	uchar m_hash[16];
+	unsigned char m_hash[16];
 };
 
 class CED2KServerListLink : public CED2KLink {
