@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -99,7 +99,7 @@ void CFileDetailDialog::DoDataExchange(CDataExchange *pDX)
     CDialog::DoDataExchange(pDX);
 }
 
-BOOL CFileDetailDialog::OnInitDialog()
+bool CFileDetailDialog::OnInitDialog()
 {
     CDialog::OnInitDialog();
     Localize();
@@ -117,7 +117,7 @@ void CFileDetailDialog::OnClosewnd(wxCommandEvent &evt)
 
 void CFileDetailDialog::UpdateData()
 {
-    CString bufferS;
+    wxString bufferS;
     GetDlgItem(IDC_FNAME, wxControl)->SetLabel(MakeStringEscaped(m_file->GetFileName()));
     GetDlgItem(IDC_METFILE, wxControl)->SetLabel(m_file->GetFullName());
     wxString tmp = GetDlgItem(IDC_FILENAME, wxTextCtrl)->GetValue();
@@ -126,28 +126,28 @@ void CFileDetailDialog::UpdateData()
     GetDlgItem(IDC_FHASH, wxTextCtrl)->SetValue(EncodeBase16(m_file->GetFileHash(), 16));
     GetDlgItem(IDC_FSIZE, wxControl)->SetLabel(CastItoXBytes(m_file->GetFileSize()));
     GetDlgItem(IDC_PFSTATUS, wxControl)->SetLabel(m_file->getPartfileStatus());
-    bufferS.Format("%i(%i)", m_file->GetPartCount(), m_file->GetHashCount());
+    bufferS.Printf("%i(%i)", m_file->GetPartCount(), m_file->GetHashCount());
     GetDlgItem(IDC_PARTCOUNT, wxControl)->SetLabel(bufferS);
     GetDlgItem(IDC_TRANSFERED, wxControl)->SetLabel(CastItoXBytes(m_file->GetTransfered()));
-    bufferS.Format(GetResString(IDS_FD_STATS), CastItoXBytes(m_file->GetLostDueToCorruption()) .GetData(), CastItoXBytes(m_file->GetGainDueToCompression()) .GetData(), m_file->TotalPacketsSavedDueToICH());
+    bufferS.Printf(GetResString(IDS_FD_STATS), CastItoXBytes(m_file->GetLostDueToCorruption()) .GetData(), CastItoXBytes(m_file->GetGainDueToCompression()) .GetData(), m_file->TotalPacketsSavedDueToICH());
     GetDlgItem(IDC_FD_STATS, wxControl)->SetLabel(bufferS);
     GetDlgItem(IDC_COMPLSIZE, wxControl)->SetLabel(CastItoXBytes(m_file->GetCompletedSize()));
-    bufferS.Format("%.2f ", m_file->GetPercentCompleted());
+    bufferS.Printf("%.2f ", m_file->GetPercentCompleted());
     GetDlgItem(IDC_PROCCOMPL, wxControl)->SetLabel(bufferS + GetResString(IDS_PROCDONE));
-    bufferS.Format("%.2f %s", (float) m_file->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
+    bufferS.Printf("%.2f %s", (float) m_file->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
     GetDlgItem(IDC_DATARATE, wxControl)->SetLabel(bufferS);
-    bufferS.Format("%i", m_file->GetSourceCount());
+    bufferS.Printf("%i", m_file->GetSourceCount());
     GetDlgItem(IDC_SOURCECOUNT, wxControl)->SetLabel(bufferS);
-    bufferS.Format("%i", m_file->GetTransferingSrcCount());
+    bufferS.Printf("%i", m_file->GetTransferingSrcCount());
     GetDlgItem(IDC_SOURCECOUNT2, wxControl)->SetLabel(bufferS);
-    bufferS.Format("%i (%.1f%%)", m_file->GetAvailablePartCount(), (float)((m_file->GetAvailablePartCount() *100) / m_file->GetPartCount()));
+    bufferS.Printf("%i (%.1f%%)", m_file->GetAvailablePartCount(), (float)((m_file->GetAvailablePartCount() *100) / m_file->GetPartCount()));
     GetDlgItem(IDC_PARTAVAILABLE, wxControl)->SetLabel(bufferS);
-    if (m_file->lastseencomplete == 0) bufferS.Format(GetResString(IDS_UNKNOWN) .MakeLower());
+    if (m_file->lastseencomplete == 0) bufferS.Printf(GetResString(IDS_UNKNOWN) .MakeLower());
     else
     {
         char tmps[80];
         strftime(tmps, sizeof(tmps), "%A, %x, %X", localtime( &m_file->lastseencomplete));
-        //.Format( "%s",m_file->lastseencomplete.Format( "%A, %x, %X"));:
+        //.Printf( "%s",m_file->lastseencomplete.Printf( "%A, %x, %X"));:
         bufferS = tmps;
     }
     GetDlgItem(IDC_LASTSEENCOMPL, wxControl)->SetLabel(bufferS);
@@ -216,7 +216,7 @@ void CFileDetailDialog::FillSourcenameList()
     //info.flags = LVFI_STRING;
     int itempos;
     int namecount;
-    CString nameCountStr;
+    wxString nameCountStr;
     pmyListCtrl = (wxListCtrl *) GetDlgItem(IDC_LISTCTRLFILENAMES, wxListCtrl);
     if (pmyListCtrl->GetColumnCount() < 2)
     {
@@ -224,7 +224,7 @@ void CFileDetailDialog::FillSourcenameList()
         pmyListCtrl->InsertColumn(0, GetResString(IDS_DL_FILENAME), LVCFMT_LEFT, 340);
         pmyListCtrl->InsertColumn(1, GetResString(IDS_DL_SOURCES), LVCFMT_LEFT, 60);
     }
-    CString strText;
+    wxString strText;
     pmyListCtrl->DeleteAllItems();
 
     for (pos1 = m_file->srclist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
@@ -249,7 +249,7 @@ void CFileDetailDialog::FillSourcenameList()
             {
                 namecount = (pmyListCtrl->GetItemData(itempos));
                 namecount++;
-                nameCountStr.Format("%i", namecount);
+                nameCountStr.Printf("%i", namecount);
                 pmyListCtrl->SetItem(itempos, 1, nameCountStr);
                 pmyListCtrl->SetItemData(itempos, namecount);
             }
@@ -263,7 +263,7 @@ void CFileDetailDialog::FillSourcenameList()
 #if 0
 void CFileDetailDialog::OnBnClickedButtonrename()
 {
-    CString NewFileName;
+    wxString NewFileName;
     GetDlgItem(IDC_FILENAME)->GetWindowText(NewFileName);
     m_file->SetFileName(NewFileName.GetBuffer());
     m_file->SavePartFile();
@@ -341,7 +341,7 @@ void CFileDetailDialog::OnBnClickedButtonStrip(wxCommandEvent &evt)
             }
         }
     }
-    GetDlgItem(IDC_FILENAME, wxTextCtrl)->SetValue(MakeStringEscaped(CString(filename.GetData())));
+    GetDlgItem(IDC_FILENAME, wxTextCtrl)->SetValue(MakeStringEscaped(wxString(filename.GetData())));
 }
 
 // added by quekky
