@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -23,9 +23,9 @@
 #define FILEDETAILDLG_H 1
 
 #include "resource.h"
-#include "types.h"
 #include "wintypes.h"
 
+#include <stdint.h>                         // uint16_t
 #include <wx/dialog.h>
 #include <wx/timer.h>
 
@@ -40,7 +40,7 @@ class CFileDetailDialog : public wxDialog //CDialog
 public:
 	CFileDetailDialog(wxWindow* parent,CPartFile* file);   // standard constructor
 	virtual ~CFileDetailDialog();
-	//virtual BOOL OnInitDialog();
+	//virtual bool OnInitDialog();
 	void Localize();
 // Dialog Data
 	enum { IDD = IDD_FILEDETAILS };
@@ -60,7 +60,7 @@ protected:
 private:
 	void UpdateData();
 	CPartFile* m_file;
-	//uint32 m_timer;
+	//uint32_t m_timer;
 	wxTimer m_timer;
 	void OnClosewnd(wxCommandEvent& evt);
 	//afx_msg void OnBnClickedButtonrename();	// Tarod [Juanjo]
