@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (c) 2002 Merkur (merkur-@users.sourceforge.net / http://www.xmule-project.net)
@@ -26,6 +26,10 @@
 #	include "xmule.h"
 #endif
 
+#include "CFile.h"                          // CFile
+#include "wintypes.h"
+#include "updownclient.h"
+
 CFriend::CFriend(void)
 {
     m_dwLastSeen = 0;
@@ -39,7 +43,7 @@ CFriend::CFriend(void)
 }
 
 //Added this to work with the IRC.. Probably a better way to do it.. But wanted this in the release..
-CFriend::CFriend(uchar tm_abyUserhash[16], uint32 tm_dwLastSeen, uint32 tm_dwLastUsedIP, uint32 tm_nLastUsedPort, uint32 tm_dwLastChatted, wxString tm_strName, uint32 tm_dwHasHash)
+CFriend::CFriend(unsigned char tm_abyUserhash[16], uint32_t tm_dwLastSeen, uint32_t tm_dwLastUsedIP, uint32_t tm_nLastUsedPort, uint32_t tm_dwLastChatted, wxString tm_strName, uint32_t tm_dwHasHash)
 {
     m_dwLastSeen = tm_dwLastSeen;
     m_dwLastUsedIP = tm_dwLastUsedIP;
@@ -93,10 +97,10 @@ void CFriend::LoadFromFile(CFile *file)
         if (4 != file->Read( &m_dwLastChatted, 4))
         throw CInvalidPacket();
         m_dwHasHash = 1;
-        uint32 tagcount;
+        uint32_t tagcount;
         if (4 != file->Read( &tagcount, 4))
         throw CInvalidPacket();
-        for (uint32 j = 0 ; j < tagcount ; j++)
+        for (uint32_t j = 0 ; j < tagcount ; j++)
         {
             try
             {
@@ -140,7 +144,7 @@ void CFriend::WriteToFile(CFile *file)
     file->Write( &m_nLastUsedPort, 2);
     file->Write( &m_dwLastSeen, 4);
     file->Write( &m_dwLastChatted, 4);
-    uint32 tagcount = 0;
+    uint32_t tagcount = 0;
     if (!m_strName.IsEmpty())
     tagcount++;
     file->Write( &tagcount, 4);
