@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -29,8 +29,12 @@
 #	include "ClientDetailDialog.h"
 #	include "ClientList.h"
 #	include "Friend.h"
+#include "FriendList.h"                     // FriendList
 #	include "FriendListCtrl.h"
+#include "ListenSocket.h"                   // CClientReqSocket - audited 5 Nov 2004
 #include "opcodes.h"                        // MP_DETAIL
+#include "otherfunctions.h"                 // GetTickCount - audited 5 Nov 2004
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
 #	include "wintypes.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
@@ -97,7 +101,7 @@ void CFriendListCtrl::Localize()
     CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
     HDITEM hdi;
     hdi.mask = HDI_TEXT;
-    CString strRes;
+    wxString strRes;
     strRes = GetResString(IDS_QL_USERNAME);
     hdi.pszText = strRes.GetBuffer();
     pHeaderCtrl->SetItem(0, &hdi);
@@ -107,7 +111,7 @@ void CFriendListCtrl::Localize()
 
 void CFriendListCtrl::AddFriend(CFriend *toadd)
 {
-    uint32 itemnr = GetItemCount();
+    uint32_t itemnr = GetItemCount();
     //itemnr = InsertItem(LVIF_TEXT|LVIF_PARAM|LVIF_IMAGE,itemnr,toadd->m_strName.GetBuffer(),0,0,1,(LPARAM)toadd);
     itemnr = InsertItem(itemnr, toadd->m_strName.GetData());
     SetItemData(itemnr, (long) toadd);
@@ -119,7 +123,7 @@ void CFriendListCtrl::RemoveFriend(CFriend *toremove)
     //LVFINDINFO find;
     //find.flags = LVFI_PARAM;
     //find.lParam = (LPARAM)toremove;
-    sint32 result = FindItem( - 1, (long) toremove);
+    int32_t result = FindItem( - 1, (long) toremove);
     if (result != ( - 1))
     DeleteItem(result);
 }
@@ -129,13 +133,13 @@ void CFriendListCtrl::RefreshFriend(CFriend *toupdate)
     //LVFINDINFO find;
     //find.flags = LVFI_PARAM;
     //find.lParam = (LPARAM)toupdate;
-    sint32 itemnr = FindItem( - 1, (long) toupdate);
-    CString temp;
-    temp.Format("%s", toupdate->m_strName.GetData());
+    int32_t itemnr = FindItem( - 1, (long) toupdate);
+    wxString temp;
+    temp.Printf("%s", toupdate->m_strName.GetData());
     SetItem(itemnr, 0, temp);
     if (itemnr == ( - 1))
     return;
-    uint8 image;
+    uint8_t image;
     if (!toupdate->m_LinkedClient)
     image = 0;
     else if(toupdate->m_LinkedClient->socket &&toupdate->m_LinkedClient->socket->IsConnected())
