@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -51,7 +51,7 @@ protected:
 	void	RemoveFriend(CFriend* toremove);
 	void	RefreshFriend(CFriend* toupdate);
 #if 0
-	BOOL	OnCommand(WPARAM wParam,LPARAM lParam );
+	bool	OnCommand(WPARAM wParam,LPARAM lParam );
 	void	OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult);
 #endif
 	virtual bool ProcessEvent(wxEvent& evt);
