@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Tiku ( )
@@ -23,9 +23,9 @@
 #define HTTP_DOWNLOADDLG_H
 
 #include "wintypes.h"
-#include "types.h"
 #include "updownclient.h"
 
+#include <stdint.h>                         // uint32_t
 #include <wx/dialog.h>
 #include <wx/process.h>
 
