@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -30,7 +30,7 @@
 #	include "xmuleDlg.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 CIPFilter::CIPFilter()
 {
@@ -43,7 +43,7 @@ CIPFilter::~CIPFilter()
     RemoveAllIPs();
 }
 
-void CIPFilter::AddBannedIPRange(uint32 IPfrom, uint32 IPto, uint8 filter, CString desc)
+void CIPFilter::AddBannedIPRange(uint32_t IPfrom, uint32_t IPto, uint8_t filter, wxString desc)
 {
     IPRange_Struct *newFilter = new IPRange_Struct();
     IPRange_Struct *search;
@@ -73,8 +73,8 @@ int CIPFilter::LoadFromFile()
 {
     wxString sbuffer, sbuffer2, sbuffer3, sbuffer4;
     int pos, filtercounter;
-    uint32 ip1, ip2;
-    uint8 filter;
+    uint32_t ip1, ip2;
+    uint8_t filter;
     char buffer[1024];
     int lenBuf = 1024;
     filtercounter = 0;
@@ -98,7 +98,7 @@ int CIPFilter::LoadFromFile()
             sbuffer3 = sbuffer2.Left(pos) .Trim();
             sbuffer4 = sbuffer2.Right(sbuffer2.Length() - pos - 1) .Trim();
             ip1 = ip2 = 0;
-            CString temp;
+            wxString temp;
             bool skip = false;
             unsigned int s3[4];
             unsigned int s4[4];
@@ -112,8 +112,8 @@ int CIPFilter::LoadFromFile()
             }
             for (int i = 0 ; i < 4 ; i++)
             {
-                ip1 |= (uint32)(s3[i] << (8 * (3 - i)));
-                ip2 |= (uint32)(s4[i] << (8 * (3 - i)));
+                ip1 |= (uint32_t)(s3[i] << (8 * (3 - i)));
+                ip2 |= (uint32_t)(s4[i] << (8 * (3 - i)));
             }
 #if 0
             for (int i = 0 ; i < 4 ; i++)
@@ -143,10 +143,10 @@ int CIPFilter::LoadFromFile()
             {
                 //sbuffer3.Tokenize(".",counter);:
                 temp = Tokenize(sbuffer3, ".", counter);
-                ip1 |= (uint32)(atoi(temp) << (8 * (3 - i)));
+                ip1 |= (uint32_t)(atoi(temp) << (8 * (3 - i)));
                 //sbuffer4.Tokenize(".",counter);:
                 temp = Tokenize(sbuffer4, ".", counter);
-                ip2 |= (uint32)(atoi(temp) << (8 * (3 - i)));
+                ip2 |= (uint32_t)(atoi(temp) << (8 * (3 - i)));
             }
 #endif
             // filter
@@ -180,7 +180,7 @@ int CIPFilter::LoadFromFile()
             sbuffer2 = sbuffer.Right(sbuffer.Length() - pos2 - 1);
             if (sbuffer2.GetChar(sbuffer2.Length() - 1) == 10) sbuffer2.Remove(sbuffer2.Length() - 1);
             // add a filter
-            AddBannedIPRange(ip1, ip2, filter, CString(sbuffer2.GetData()));
+            AddBannedIPRange(ip1, ip2, filter, wxString(sbuffer2.GetData()));
             filtercounter++;
         }
         fclose(readFile);
@@ -204,15 +204,15 @@ void CIPFilter::RemoveAllIPs()
     }
 }
 
-bool CIPFilter::IsFiltered(uint32 IP2test)
+bool CIPFilter::IsFiltered(uint32_t IP2test)
 {
     if (iplist.GetCount() == 0) return false;
     //CSingleLock(&m_Mutex,TRUE); // will be unlocked on exit
     IPRange_Struct *search;
-    uint32 IP2test_ = (uint8)(IP2test >> 24) | (uint8)(IP2test >> 16) << 8 | (uint8)(IP2test >> 8) << 16 | (uint8)(IP2test) << 24;
-    uint16 lo = 0;
-    uint16 hi = iplist.GetCount() - 1;
-    uint16 mi;
+    uint32_t IP2test_ = (uint8_t)(IP2test >> 24) | (uint8_t)(IP2test >> 16) << 8 | (uint8_t)(IP2test >> 8) << 16 | (uint8_t)(IP2test) << 24;
+    uint16_t lo = 0;
+    uint16_t hi = iplist.GetCount() - 1;
+    uint16_t mi;
     while (true)
     {
         mi = ((hi - lo) /2) + lo;
