@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,17 +22,16 @@
 #ifndef _IPFILTER_H
 #define _IPFILTER_H
 
-#include "wintypes.h"
-#include "mfc.h"
-#include "types.h"
-#include "ListenSocket.h"
+#include "mfc.h"                            // CArray wxString - audited 4 Nov 2004
 
-struct IPRange_Struct{
-   uint32           IPstart;
-   uint32           IPend;
-   uint8			filter;
-   CString			description;
-   ~IPRange_Struct() {  }
+#include <stdint.h>                         // uint32_t
+
+struct IPRange_Struct
+{
+    uint32_t  IPstart;
+    uint32_t  IPend;
+    uint8_t   filter;
+    wxString  description;
 };
 
 class CIPFilter
@@ -40,15 +39,15 @@ class CIPFilter
 public:
 	CIPFilter();
 	~CIPFilter();
-	void	AddBannedIPRange(uint32 IPfrom,uint32 IPto,uint8 filter, CString desc);
+	void	AddBannedIPRange(uint32_t IPfrom,uint32_t IPto,uint8_t filter, wxString desc);
 	void	RemoveAllIPs();
 	int		LoadFromFile();
 	void	SaveToFile();
-	bool	IsFiltered(uint32 IP2test);
-	CString GetLastHit()				{ return lasthit;}
-	uint16	BanCount()					{ return iplist.GetCount(); }
+	bool	IsFiltered(uint32_t IP2test);
+	wxString GetLastHit()				{ return lasthit;}
+	uint16_t	BanCount()					{ return iplist.GetCount(); }
 private:
-	CString lasthit;
+	wxString lasthit;
 	//CMutex m_Mutex;
 	CArray<IPRange_Struct*,IPRange_Struct*> iplist;
 };
