@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -40,12 +40,12 @@ public:
 	bool	Init();
 	void	Save();
 	void	Clear();
-	CKnownFile*	FindKnownFile(char* filename,uint32 in_date,uint32 in_size);
+	CKnownFile*	FindKnownFile(char* filename,uint32_t in_date,uint32_t in_size);
 
 
-	uint16 requested;
-	uint32 transfered;
-	uint16 accepted;
+	uint16_t requested;
+	uint32_t transfered;
+	uint16_t accepted;
 
 private:
 	wxMutex	list_mut;
