@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -30,12 +30,14 @@
 #	include "ListenSocket.h"
 #include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP
 #	include "opcodes.h"
+#include "otherstructs.h"                   // Requested_Block_Struct - audited 5 Nov 2004
 #include "packets.h"                        // Packet
 #include "Preferences.h"                    // CPreferences::shareddirlist
 #include "SafeFile.h"                       // CSafeMemFile
 #include "server.h"                         // CServer
 #include "ServerList.h"                     // CServerList
 #	include "SharedFileList.h"
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
 #	include "updownclient.h"
 #	include "UploadQueue.h"
 #	include "wintypes.h"
@@ -44,7 +46,7 @@
 #	include "PartFile.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #ifndef ID_SOKETTI
 #define ID_SOKETTI 7772
@@ -232,7 +234,7 @@ void CClientReqSocket::Safe_Delete()
     Destroy();
 }
 
-bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
+bool CClientReqSocket::ProcessPacket(char *packet, uint32_t size, uint8_t opcode)
 {
     NewSocket_DebugPP(client,opcode, size, (unsigned char *) packet);
     switch (opcode)
@@ -314,7 +316,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
                     {
                         client->SetWaitStartTime();
                     }
-                    uchar reqfileid[16];
+                    unsigned char reqfileid[16];
                     md4cpy(reqfileid, packet);
                     CKnownFile *reqfile = theApp.sharedfiles->GetFileByID(reqfileid);
                     if (!reqfile)
@@ -344,10 +346,10 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
                         {
                             client->SetCommentDirty();
                         }
-                        client->SetUploadFileID((uchar *) packet);
+                        client->SetUploadFileID((unsigned char *) packet);
                         CMemFile *data = new CMemFile();
                         data->Write(reqfile->GetFileHash(), 16);
-                        uint16 namelength = (uint16) strlen(reqfile->GetFileName());
+                        uint16_t namelength = (uint16_t) strlen(reqfile->GetFileName());
                         data->Write( &namelength, 2);
                         data->Write(reqfile->GetFileName(), namelength);
                         client->ProcessUpFileStatus(packet, size);
@@ -367,7 +369,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
             if (size >= 16)
             {
                 // if that client do not have my file maybe has another different
-                CPartFile *reqfile = theApp.downloadqueue->GetFileByID((uchar *) packet);
+                CPartFile *reqfile = theApp.downloadqueue->GetFileByID((unsigned char *) packet);
                 if (!reqfile)
                 break;
                 // we try to swap to another file ignoring no needed parts files
@@ -408,7 +410,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
         {
             theApp.downloadqueue->AddDownDataOverheadFileRequest(size);
             CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
-            uint32 rank;
+            uint32_t rank;
             data->Read( &rank, 4);
             client->SetRemoteQueueRank(rank);
             delete data;
@@ -428,7 +430,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
         {
             theApp.downloadqueue->AddDownDataOverheadFileRequest(size);
             CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
-            uchar reqfilehash[16];
+            unsigned char reqfilehash[16];
             data->Read(reqfilehash, 16);
             Requested_Block_Struct *reqblock1 = new Requested_Block_Struct;
             Requested_Block_Struct *reqblock2 = new Requested_Block_Struct;
@@ -498,7 +500,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
             {
                 if (!client->GetWaitStartTime())
                 client->SetWaitStartTime();
-                CKnownFile* reqfile = theApp.sharedfiles->GetFileByID((uchar *)packet);
+                CKnownFile* reqfile = theApp.sharedfiles->GetFileByID((unsigned char *)packet);
                 if (!reqfile)
                 {
                     // send file request no such file packet (0x48)
@@ -516,14 +518,14 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
                     if (memcmp(client->GetUploadFileID(), packet, 16) != 0)
                     client->SetCommentDirty();
                     //send filestatus
-                    client->SetUploadFileID((uchar *) packet);
+                    client->SetUploadFileID((unsigned char *) packet);
                     CMemFile *data = new CMemFile();
                     data->Write(reqfile->GetFileHash(), 16);
                     if (reqfile->IsPartFile())
                     ((CPartFile *) reqfile)->WritePartStatus(data);
                     else
                     {
-                        uint32 null = 0;
+                        uint32_t null = 0;
                         data->Write( &null, 3);
                     }
                     Packet *packet = new Packet(data);
@@ -569,7 +571,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
     case OP_MESSAGE:
         {
             theApp.downloadqueue->AddDownDataOverheadOther(size);
-            uint16 length;
+            uint16_t length;
             memcpy( &length, packet, 2);
             char *message = new char[length + 1];
             memcpy(message, packet + 2, length);
@@ -614,7 +616,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
             else theApp.xmuledlg->AddLogLine(true, _("User %s (%u) requested your sharedfiles-list->%s"),
             client->GetUserName(), client->GetUserID(), _("denied"));
             // now create the memfile for the packet
-            uint32 iTotalCount = list.GetCount();
+            uint32_t iTotalCount = list.GetCount();
             CSafeMemFile tempfile(80);
             tempfile.Write( &iTotalCount, 4);
             while (list.GetCount())
@@ -641,21 +643,21 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
                 theApp.xmuledlg->AddLogLine(true, _("User %s (%u) requested your shareddirectories-list->%s"),
                 client->GetUserName(), client->GetUserID(), _("accepted"));
                 CSafeMemFile tempfile(80);
-                uint32 uDirs = theApp.glob_prefs->shareddir_list.GetCount();
+                uint32_t uDirs = theApp.glob_prefs->shareddir_list.GetCount();
                 tempfile.Write( &uDirs, 4);
-                for (uint32 iDir = 0 ; iDir < uDirs ; iDir++)
+                for (uint32_t iDir = 0 ; iDir < uDirs ; iDir++)
                 {
-                    CString strDir(theApp.glob_prefs->shareddir_list[iDir]);
-                    uint16 cnt = strDir.GetLength();
+                    wxString strDir(theApp.glob_prefs->shareddir_list[iDir]);
+                    uint16_t cnt = strDir.length();
                     tempfile.Write( &cnt, 2);
                     tempfile.Write(strDir.c_str(), cnt);
                 }
                 // and the incoming folders
                 for (int ix = 0 ; ix < theApp.glob_prefs->GetCatCount() ; ix++)
                 {
-                    CString strDir;
-                    strDir = CString(theApp.glob_prefs->GetCategory(ix)->incomingpath);
-                    uint16 cnt = strDir.GetLength();
+                    wxString strDir;
+                    strDir = wxString(theApp.glob_prefs->GetCategory(ix)->incomingpath);
+                    uint16_t cnt = strDir.length();
                     tempfile.Write( &cnt, 2);
                     tempfile.Write(strDir.c_str(), cnt);
                 }
@@ -674,10 +676,10 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
     case OP_ASKSHAREDFILESDIR:
         {
             theApp.downloadqueue->AddDownDataOverheadOther(size);
-            CSafeMemFile data((uchar *) packet, size, 0);
+            CSafeMemFile data((unsigned char *) packet, size, 0);
             if (size > 1)
             {
-                uint16 cnt;
+                uint16_t cnt;
                 data.Read( &cnt, 2);
                 if ((size - 2) >= cnt)
                 {
@@ -691,10 +693,10 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
                         CTypedPtrList < CPtrList, CKnownFile *> list;
                         theApp.sharedfiles->GetSharedFilesByDirectory(strReqDir, list);
                         CSafeMemFile tempfile(80);
-                        uint16 cnt = strlen(strReqDir);
+                        uint16_t cnt = strlen(strReqDir);
                         tempfile.Write( &cnt, 2);
                         tempfile.Write(strReqDir, cnt);
-                        uint32 uFiles = list.GetCount();
+                        uint32_t uFiles = list.GetCount();
                         tempfile.Write( &uFiles, 4);
                         while (list.GetCount())
                         {
@@ -720,13 +722,13 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
         theApp.downloadqueue->AddDownDataOverheadOther(size);
         if (client->GetFileListRequested() == 1)
         {
-            CSafeMemFile data((uchar *) packet, size, 0);
-            uint32 uDirs;
+            CSafeMemFile data((unsigned char *) packet, size, 0);
+            uint32_t uDirs;
             if (data.Read( &uDirs, 4) == 4)
             {
-                for (uint32 iDir = 0 ; iDir != uDirs ; iDir++)
+                for (uint32_t iDir = 0 ; iDir != uDirs ; iDir++)
                 {
-                    uint16 cnt;
+                    uint16_t cnt;
                     data.Read( &cnt, 2);
                     if ((size - 4) >= cnt)
                     {
@@ -753,8 +755,8 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
             theApp.downloadqueue->AddDownDataOverheadOther(size);
             if (client->GetFileListRequested() > 0)
             {
-                CSafeMemFile data((uchar *) packet, size, 0);
-                uint16 cnt;
+                CSafeMemFile data((unsigned char *) packet, size, 0);
+                uint16_t cnt;
                 if (data.Read( &cnt, 2) == 2)
                 {
                     if ((size - 2) >= cnt)
@@ -783,7 +785,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32 size, uint8 opcode)
     return true;
 }
 
-bool CClientReqSocket::ProcessExtPacket(char *packet, uint32 size, uint8 opcode)
+bool CClientReqSocket::ProcessExtPacket(char *packet, uint32_t size, uint8_t opcode)
 {
     NewSocket_DebugPP(client,opcode, size, (unsigned char *) packet);
     switch (opcode)
@@ -808,7 +810,7 @@ if(client) {
         }
     case OP_SECIDENTSTATE:
         {
-            client->ProcessSecIdentStatePacket((uchar *) packet, size);
+            client->ProcessSecIdentStatePacket((unsigned char *) packet, size);
             if (client->GetSecureIdentState() == IS_SIGNATURENEEDED)
             {
                 client->SendSignaturePacket();
@@ -824,13 +826,13 @@ if(client) {
         {
             if (!client->IsBanned())
             {
-                client->ProcessPublicKeyPacket((uchar *) packet, size);
+                client->ProcessPublicKeyPacket((unsigned char *) packet, size);
             }
             break;
         }
     case OP_SIGNATURE:
         {
-            client->ProcessSignaturePacket((uchar *) packet, size);
+            client->ProcessSignaturePacket((unsigned char *) packet, size);
             break;
         }
     case OP_COMPRESSEDPART:
@@ -843,7 +845,7 @@ if(client) {
             theApp.downloadqueue->AddDownDataOverheadOther(size);
             if (size == 12)
             {
-                uint16 newrank;
+                uint16_t newrank;
                 memcpy( &newrank, packet + 0, 2);
                 client->SetRemoteQueueFull(false);
                 client->SetRemoteQueueRank(newrank);
@@ -858,9 +860,9 @@ if(client) {
                 if (size == 16)
                 {
                     //first check shared file list, then download list
-                    CKnownFile *file = theApp.sharedfiles->GetFileByID((uchar *) packet);
+                    CKnownFile *file = theApp.sharedfiles->GetFileByID((unsigned char *) packet);
                     if (!file)
-                    file = theApp.downloadqueue->GetFileByID((uchar *) packet);
+                    file = theApp.downloadqueue->GetFileByID((unsigned char *) packet);
                     if (file)
                     {
                         DWORD dwTimePassed =::GetTickCount() - client->GetLastSrcReqTime() + CONNECTION_LATENCY;
@@ -891,9 +893,9 @@ if(client) {
         {
             theApp.downloadqueue->AddDownDataOverheadSourceExchange(size);
             CSafeMemFile data((BYTE *) packet, size);
-            uchar hash[16];
+            unsigned char hash[16];
             data.Read(hash, 16);
-            CKnownFile *file = theApp.downloadqueue->GetFileByID((uchar *) packet);
+            CKnownFile *file = theApp.downloadqueue->GetFileByID((unsigned char *) packet);
             if (file)
             {
                 if (file->IsPartFile())
@@ -917,9 +919,9 @@ if(client) {
  CUpDownClient* vuclient = theApp.clientlist->VUGetRandomClient();
  if (vuclient){
  Packet* answer = new Packet(OP_VERIFYUPSANSWER,6,OP_EMULEPROT);
- uint32 ip = vuclient->GetIP();
+ uint32_t ip = vuclient->GetIP();
  memcpy(answer->pBuffer,ip,4);
- uint16 udpport = vuclient->GetUDPPort();
+ uint16_t udpport = vuclient->GetUDPPort();
  memcpy(answer->pBuffer,ip,4);
  theApp.uploadqueue->AddUpDataRateMSOverhead(packet->size);
  printf("::ProcessExtPacket OP_VERIFYUPSREQ --> OP_VERIFYUPSANSWER %02x size=%ld\n",opcode,size);
@@ -938,8 +940,8 @@ if(client) {
 
 void CClientReqSocket::OnInit()
 {
-    uint8 tv = 1;
-    //SetSockOpt(SO_DONTLINGER,&tv,sizeof(BOOL));
+    uint8_t tv = 1;
+    //SetSockOpt(SO_DONTLINGER,&tv,sizeof(bool));
 }
 
 void CClientReqSocket::OnLost(int nErrorCode)
@@ -1183,7 +1185,7 @@ void CListenSocket::AddConnection()
 bool CListenSocket::TooManySockets(bool bIgnoreInterval)
 {
     if (GetOpenSockets() > theApp.dynprefs->Get<long>("max-connections")
-/*->*/  || (m_OpenSocketsInterval > theApp.glob_prefs->GetMaxConperFive() 
+/*->*/  || (m_OpenSocketsInterval > theApp.dynprefs->Get<long>("max-per-5") 
 /*->*/  && !bIgnoreInterval))
     {
         return true;
