@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,15 +22,14 @@
 #ifndef MAPKEY_H
 #define MAPKEY_H
 
-#include "types.h"
-#include "wintypes.h"
+#include "mfc.h"                            // Needed for HashKey - audited 5 Nov 2004
 
-#include <wx/object.h>
-#include "mfc.h"
+#include <stdint.h>                         // Needed for uint32_t
+#include <wx/object.h>                      // Needed for wxObject
 
 class CCKey : public wxObject{
 public:
-	CCKey(uchar* key = 0)		{m_key = key;}
+	CCKey(unsigned char* key = 0)		{m_key = key;}
 	CCKey(const CCKey& k1)		{m_key = k1.m_key;}
 
 	friend bool operator<(const CCKey& k1,const CCKey&k2)
@@ -41,11 +40,11 @@ public:
 	CCKey& operator=(const CCKey& k1)						{m_key = k1.m_key; return *this; }
 	friend bool operator==(const CCKey& k1,const CCKey& k2)	{return !memcmp(k1.m_key,k2.m_key,16);}
 	
-	uchar* m_key;
+	unsigned char* m_key;
 };
 
 template<> inline unsigned int HashKey(CCKey key){
-   uint32 hash = 1;
+   uint32_t hash = 1;
    for (int i = 0;i != 16;i++)
 	   hash += (key.m_key[i]+1)*((i*i)+1);
    return hash;
