@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -192,11 +192,11 @@ END_MESSAGE_MAP()
 
 /////////////////////////////////////////////////////////////////////////////
 #if 0
-BOOL COScopeCtrl::Create(DWORD dwStyle, const RECT &rect,
+bool COScopeCtrl::Create(DWORD dwStyle, const RECT &rect,
 CWnd *pParentWnd, UINT nID)
 {
-    BOOL result;
-    static CString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
+    bool result;
+    static wxString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
     result = CWnd::CreateEx(WS_EX_CLIENTEDGE | WS_EX_STATICEDGE,
     className, NULL, dwStyle,
     rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
@@ -490,9 +490,9 @@ m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
  m_dcGrid.SetTextAlign (TA_RIGHT|TA_TOP) ;
  if( m_str.XMax.IsEmpty() ){
  if( m_nTrendPoints<0 )
- strTemp.Format ("%d", m_nPlotWidth/m_nShiftPixels) ;
+ strTemp.Printf ("%d", m_nPlotWidth/m_nShiftPixels) ;
  else
- strTemp.Format ("%d", m_nTrendPoints-1 ) ;
+ strTemp.Printf ("%d", m_nTrendPoints-1 ) ;
  } else
  strTemp = m_str.XMax;
  m_dcGrid.TextOut (m_rectPlot.right, m_rectPlot.bottom+4, strTemp) ;
