@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -59,7 +59,7 @@ END_EVENT_TABLE()
 #	include "xmule.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <wx/checkbox.h>
 #include <wx/notebook.h>
