@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -107,10 +107,10 @@ void CPPgSourcesDropping::LoadSettings(void)
     {
         CheckDlgButton(IDC_ENABLE_AUTO_HQRS, false);
     }
-    CString strBuffer;
-    strBuffer.Format("%d", app_prefs->prefs->HighQueueRanking);
+    wxString strBuffer;
+    strBuffer.Printf("%d", app_prefs->prefs->HighQueueRanking);
     GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->SetValue(strBuffer);
-    strBuffer.Format("%d", app_prefs->prefs->AutoDropTimer);
+    strBuffer.Printf("%d", app_prefs->prefs->AutoDropTimer);
     GetDlgItem(IDC_AUTO_DROP_TIMER, wxTextCtrl)->SetValue(strBuffer);
 }
 
@@ -121,9 +121,9 @@ void CPPgSourcesDropping::OnApply()
     app_prefs->prefs->SwapNoNeededSources = (GetDlgItem(IDC_AUTO_NNS_EXTENDED_RADIO, wxRadioBox)->GetSelection() == 0);
     app_prefs->prefs->DropFullQueueSources = GetDlgItem(IDC_ENABLE_AUTO_FQS, wxCheckBox)->GetValue();
     app_prefs->prefs->DropHighQueueRankingSources = GetDlgItem(IDC_ENABLE_AUTO_HQRS, wxCheckBox)->GetValue();
-    CString strBuffer;
+    wxString strBuffer;
     /* Get the Queue Ranking from dialog. */
-    strBuffer.Format("%d", app_prefs->prefs->HighQueueRanking);
+    strBuffer.Printf("%d", app_prefs->prefs->HighQueueRanking);
     if (GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->GetValue())
     {
         buffer = GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->GetValue();
@@ -145,7 +145,7 @@ void CPPgSourcesDropping::OnApply()
         }
     }
     /* Get the Auto Drop Timer from Dialog */
-    strBuffer.Format("%d", app_prefs->prefs->AutoDropTimer);
+    strBuffer.Printf("%d", app_prefs->prefs->AutoDropTimer);
     if (GetDlgItem(IDC_AUTO_DROP_TIMER, wxTextCtrl)->GetValue())
     {
         buffer = GetDlgItem(IDC_AUTO_DROP_TIMER, wxTextCtrl)->GetValue();
