@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -25,17 +25,15 @@
 #	include "PPgTweaks.h"
 #	include "otherfunctions.h"
 #include "Preferences.h"                    // CPreferences
-#	include "types.h"
 #	include "xmule.h"
 #endif
 
+#include <stdint.h>                         // uint32_t
+#include <wx/checkbox.h>
+#include <wx/notebook.h>
 #include <wx/slider.h>
 #include <wx/textctrl.h>
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
-
-#include <wx/notebook.h>
-#include <wx/checkbox.h>
+#include <wx/xrc/xmlres.h>
 
 #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
@@ -103,8 +101,8 @@ void CPPgTweaks::LoadSettings(void)
 {
     if (1)
     {
-        CString strBuffer;
-        strBuffer.Format("%d", app_prefs->GetMaxConperFive());
+        wxString strBuffer;
+        strBuffer.Printf("%d", app_prefs->GetMaxConperFive());
         GetDlgItem(IDC_MAXCON5SEC, wxTextCtrl)->SetValue(strBuffer);
     }
     if (app_prefs->prefs->m_bVerbose)
@@ -162,7 +160,7 @@ bool CPPgTweaks::OnApply()
     else
     app_prefs->prefs->showRatesInTitle = false;
     // Barry
-    app_prefs->prefs->autotakeed2klinks = (int8) IsDlgButtonChecked(IDC_AUTOTAKEED2KLINKS);
+    app_prefs->prefs->autotakeed2klinks = (int8_t) IsDlgButtonChecked(IDC_AUTOTAKEED2KLINKS);
     app_prefs->prefs->m_iFileBufferSize = m_iFileBufferSize;
     app_prefs->prefs->m_iQueueSize = m_iQueueSize;
     //	LoadSettings();
@@ -182,19 +180,19 @@ void CPPgTweaks::OnHScroll(wxScrollEvent &evt)
     //SetModified(TRUE);
     wxSlider *slider = (wxSlider *) evt.GetEventObject();
     //CSliderCtrl* slider =(CSliderCtrl*)pScrollBar;
-    CString temp;
+    wxString temp;
     if (slider == XRCCTRL( *this, "IDC_FILEBUFFERSIZE", wxSlider))
     {
         //GetDlgItem(IDC_FILEBUFFERSIZE)) {
         m_iFileBufferSize = evt.GetPosition();
-        temp.Format(GetResString(IDS_FILEBUFFERSIZE), m_iFileBufferSize *15000);
+        temp.Printf(GetResString(IDS_FILEBUFFERSIZE), m_iFileBufferSize *15000);
         GetDlgItem(IDC_FILEBUFFERSIZE_STATIC, wxControl)->SetLabel(temp);
     }
     else if(slider == XRCCTRL( *this, "IDC_QUEUESIZE", wxSlider))
     {
         //GetDlgItem(IDC_QUEUESIZE)) {
         m_iQueueSize = evt.GetPosition();
-        temp.Format(GetResString(IDS_QUEUESIZE), m_iQueueSize *100);
+        temp.Printf(GetResString(IDS_QUEUESIZE), m_iQueueSize *100);
         GetDlgItem(IDC_QUEUESIZE_STATIC, wxControl)->SetLabel(temp);
     }
 }
@@ -209,10 +207,10 @@ void CPPgTweaks::Localize(void)
         GetDlgItem(IDC_UPDATEQUEUE, wxControl)->SetLabel(GetResString(IDS_UPDATEQUEUE));
         GetDlgItem(IDC_AUTOTAKEED2KLINKS, wxControl)->SetLabel(GetResString(IDS_AUTOTAKEED2KLINKS));
         GetDlgItem(IDC_VERBOSE, wxControl)->SetLabel(GetResString(IDS_VERBOSE));
-        CString temp;
-        temp.Format(GetResString(IDS_FILEBUFFERSIZE), m_iFileBufferSize *15000);
+        wxString temp;
+        temp.Printf(GetResString(IDS_FILEBUFFERSIZE), m_iFileBufferSize *15000);
         GetDlgItem(IDC_FILEBUFFERSIZE_STATIC, wxControl)->SetLabel(temp);
-        temp.Format(GetResString(IDS_QUEUESIZE), m_iQueueSize *100);
+        temp.Printf(GetResString(IDS_QUEUESIZE), m_iQueueSize *100);
         GetDlgItem(IDC_QUEUESIZE_STATIC, wxControl)->SetLabel(temp);
         GetDlgItem(IDC_SHOWRATEONTITLE, wxControl)->SetLabel(GetResString(IDS_SHOWRATEONTITLE));
     }
