@@ -2,7 +2,7 @@
 //
 // Clean Up, Fix some things and partly rewrite this File: Plaenky 
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -38,21 +38,24 @@
 #	include "xmule-headers.h"
 #else
 #	include "Preferences.h"
-#	include "wintypes.h"
 #	include "opcodes.h"
 #	include "otherfunctions.h"
 #	include "ini2.h"
 #	include "stdlib.h"
 #	include "stdio.h"
 #	include "resource.h"
+#include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
-#include <string>                           // Needed for std::string
-#include <time.h>
-#include <stdlib.h>
+#include <cstdlib>
+#include <ctime>
+#include <fstream>                          // Needed for std::ofstream std::endl
+#include <iomanip>                          // std::hex std::setprecision
 #include <locale.h>
+#include <sstream>                          // Needed for std::stringstream
+#include <string>                           // Needed for std::string
 #include <wx/filename.h>
 
 #define ELEMENT_COUNT(X) (sizeof(X) / sizeof(X[0]))
@@ -74,12 +77,17 @@
 extern long long atoll(char *s);
 #endif /* __FreeBSD__ */
 
-
+using std::endl;
+using std::hex;
+using std::ifstream;
+using std::ios;
+using std::ofstream;
+using std::stringstream;
 
 CPreferences::CPreferences()
 {
     // we need random numbers sometimes:
-    srand((uint32) time(0));
+    srand((uint32_t) time(0));
     // Define prefs 
     prefs = new Preferences_Struct;
     memset(prefs, 0, sizeof(Preferences_Struct));
@@ -211,7 +219,7 @@ void CPreferences::CreateUserHash()
 {
     for (int i = 0 ; i != 8 ; i++)
     {
-        uint16 random = rand();
+        uint16_t random = rand();
         memcpy( &userhash[i*2], &random, 2);
     }
     // mark as emule client. that will be need in later version
@@ -233,16 +241,10 @@ int CPreferences::GetRecommendedMaxConnections()
 
 WORD CPreferences::GetWindowsVersion()
 {
-    static bool bWinVerAlreadyDetected = false;
-    if (!bWinVerAlreadyDetected)
-    {
-        bWinVerAlreadyDetected = true;
-        m_wWinVer = DetectWinVersion();
-    }
-    return m_wWinVer;
+    return 1;
 }
 
-uint16 CPreferences::GetDefaultMaxConperFive()
+uint16_t CPreferences::GetDefaultMaxConperFive()
 {
     return MAXCONPER5SEC;
 }
@@ -285,7 +287,7 @@ void CPreferences::ResetStatsColor(int index)
 void CPreferences::SavePreferences(void)
 {
     wxString buffer;
-    CString buffer2;
+    wxString buffer2;
     wxString full_path(getenv("HOME"), *wxConvCurrent);
     full_path += "/";
     CIni ini(full_path, "eMule");
@@ -311,7 +313,7 @@ void CPreferences::SavePreferences(void)
     ini.WriteInt("DeadServerRetry",                 theApp.dynprefs->Get<long>("server-connect-tries"));
     ini.WriteInt("SplitterbarPosition", prefs->splitterbarPosition + 2);
     ini.WriteInt("StatsAverageMinutes",             theApp.dynprefs->Get<long>("graph-average"));
-    ini.WriteInt("MaxConnectionsPerFiveSeconds", prefs->MaxConperFive);
+    ini.WriteInt("MaxConnectionsPerFiveSeconds",    theApp.dynprefs->Get<long>("max-per-5"));
     ini.WriteInt("Check4NewVersionDelay", prefs->versioncheckdays);
     ini.WriteBool("Reconnect",                      theApp.dynprefs->Get<bool>("reconnect-on-loss"));
     ini.WriteBool("Scoresystem",                    theApp.dynprefs->Get<bool>("priority-system"));
@@ -332,7 +334,7 @@ void CPreferences::SavePreferences(void)
     ini.WriteBool("OnlineSignature",                theApp.dynprefs->Get<bool>("online-signature"));
     ini.WriteBool("StartupMinimized",               theApp.dynprefs->Get<bool>("start-minimized"));
     ini.WriteBool("SafeServerConnect",              theApp.dynprefs->Get<bool>("use-safe-connect"));
-    ini.WriteBool("ShowRatesOnTitle", prefs->showRatesInTitle);
+    ini.WriteBool("ShowRatesOnTitle",               theApp.dynprefs->Get<bool>("xfer-on-title"));
     ini.WriteBool("IndicateRatings", prefs->indicateratings);
     ini.WriteBool("WatchClipboard4ED2kFilelinks", prefs->watchclipboard);
     ini.WriteBool("AutoConnectStaticOnly",          theApp.dynprefs->Get<bool>("auto-static"));
@@ -371,14 +373,14 @@ void CPreferences::SavePreferences(void)
     ini.WriteBool("SmartIdCheck",                   theApp.dynprefs->Get<bool>("smart-lowid-check"));
     ini.WriteBool("Verbose", prefs->m_bVerbose);
     ini.WriteBool("PreviewPrio",                    theApp.dynprefs->Get<bool>("last-chunk-first"));
-    ini.WriteBool("UpdateQueueListPref", prefs->m_bupdatequeuelist);
+    ini.WriteBool("UpdateQueueListPref",            theApp.dynprefs->Get<bool>("realtime-queue"));
     ini.WriteBool("ManualHighPrio",                 theApp.dynprefs->Get<bool>("add-server-high"));
     ini.WriteBool("FullChunkTransfers",             theApp.dynprefs->Get<bool>("transfer-full-chunks"));
     ini.WriteBool("StartNextFile",                  theApp.dynprefs->Get<bool>("start-next-file"));
     ini.WriteBool("ShowOverhead",                   theApp.dynprefs->Get<bool>("show-overhead"));
     ini.WriteBool("VideoPreviewBackupped", prefs->moviePreviewBackup);
-    ini.WriteInt("FileBufferSizePref", prefs->m_iFileBufferSize);
-    ini.WriteInt("QueueSizePref", prefs->m_iQueueSize);
+    ini.WriteInt("FileBufferSizePref",              theApp.dynprefs->Get<long>("file-buffer-size"));
+    ini.WriteInt("QueueSizePref",                   theApp.dynprefs->Get<long>("upload-queue-size"));
     ini.WriteBool("UAPPref",                        theApp.dynprefs->Get<bool>("auto-priority-share"));
     ini.WriteInt("AllcatType", prefs->allcatType);
     ini.WriteBool("ShowAllNotCats", prefs->showAllNotCats);
@@ -440,12 +442,12 @@ void CPreferences::SavePreferences(void)
     for (int i = 0 ; i < 13 ; i++)
     {
         buffer.Printf("%lu", (unsigned long) GetStatsColor(i));
-        buffer2.Format("StatColor%i", i);
+        buffer2.Printf("StatColor%i", i);
         ini.WriteString(buffer2, buffer, "eMule");
     }
     buffer.Printf("%llu", (unsigned long long) prefs->totalDownloadedBytes);
     ini.WriteString("TotalDownloadedBytes", buffer, "Statistics");
-    buffer.Format("%llu", (unsigned long long) prefs->totalUploadedBytes);
+    buffer.Printf("%llu", (unsigned long long) prefs->totalUploadedBytes);
     ini.WriteString("TotalUploadedBytes", buffer, "Statistics");
     ini.WriteInt("DesktopMode", theApp.dynprefs->Get<long>("systray-integration"));
     ini.WriteString("Password", GetWSPass(), "WebServer");
@@ -467,7 +469,7 @@ bool CPreferences::LoadPreferences(void)
 {
     bool error = false;
     bool NoColor = true;    
-    CString buffer2;
+    wxString buffer2;
     char buffer[200];
     //Open File for Test
     wxString full_path(getenv("HOME"), *wxConvCurrent);
@@ -478,54 +480,52 @@ bool CPreferences::LoadPreferences(void)
     // Use CIni anyway to load or to create the values
     CIni ini(full_path, "eMule");
 
-    theApp.dynprefs->Add("nickname", ini.GetString("Nick", "http://www.xmule.ws/"));
-    theApp.dynprefs->Add("incoming-directory", ini.GetString("IncomingDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Incoming").c_str())));
-    MakeFoldername(const_cast<char *>(theApp.dynprefs->Get<wxString>("incoming-directory").c_str()));
-    theApp.dynprefs->Add("temp-directory", ini.GetString("TempDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Temp").c_str())));
-    MakeFoldername(const_cast<char *>(theApp.dynprefs->Get<wxString>("temp-directory").c_str()));
-    theApp.dynprefs->Add("limits-upload", static_cast<long>(ini.GetInt("MaxUpload", UNLIMITED)));
-    theApp.dynprefs->Add("limits-download", static_cast<long>(ini.GetInt("MaxDownload", UNLIMITED)));
-    theApp.dynprefs->Add("max-connections", static_cast<long>(ini.GetInt("MaxConnections", 500)));
-    theApp.dynprefs->Add("remove-dead-server", static_cast<long>(ini.GetInt("RemoveDeadServer", 2)));
-    theApp.dynprefs->Add("tcp-port", static_cast<long>(ini.GetInt("Port", 4662)));
-    theApp.dynprefs->Add("udp-port", static_cast<long>(ini.GetInt("UDPPort", theApp.dynprefs->Get<long>("tcp-port") + 10)));
-    theApp.dynprefs->Add("max-sources", static_cast<long>(ini.GetInt("MaxSourcesPerFile", 400)));
+    theApp.dynprefs->Add("nickname",               ini.GetString("Nick", "http://www.xmule.ws/"));
+    theApp.dynprefs->Add("incoming-directory",     ini.GetString("IncomingDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Incoming").c_str())));
+    theApp.dynprefs->Add("temp-directory",         ini.GetString("TempDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Temp").c_str())));
+    theApp.dynprefs->Add("limits-upload",          static_cast<long>(ini.GetInt("MaxUpload", UNLIMITED)));
+    theApp.dynprefs->Add("limits-download",        static_cast<long>(ini.GetInt("MaxDownload", UNLIMITED)));
+    theApp.dynprefs->Add("max-connections",        static_cast<long>(ini.GetInt("MaxConnections", 500)));
+    theApp.dynprefs->Add("remove-dead-server",     static_cast<long>(ini.GetInt("RemoveDeadServer", 2)));
+    theApp.dynprefs->Add("tcp-port",               static_cast<long>(ini.GetInt("Port", 4662)));
+    theApp.dynprefs->Add("udp-port",               static_cast<long>(ini.GetInt("UDPPort", theApp.dynprefs->Get<long>("tcp-port") + 10)));
+    theApp.dynprefs->Add("max-sources",            static_cast<long>(ini.GetInt("MaxSourcesPerFile", 400)));
     prefs->languageID = ini.GetWORD("Language", 0);
-    theApp.dynprefs->Add("see-share", static_cast<long>(ini.GetInt("SeeShare", 2)));
+    theApp.dynprefs->Add("see-share",              static_cast<long>(ini.GetInt("SeeShare", 2)));
     prefs->m_iToolDelayTime = ini.GetInt("ToolTipDelay", 1);
-    theApp.dynprefs->Add("graph-delay", static_cast<long>(ini.GetInt("StatGraphsInterval", 3)));
-    theApp.dynprefs->Add("tree-delay", static_cast<long>(ini.GetInt("statsInterval", 5)));
-    theApp.dynprefs->Add("capacities-download", static_cast<long>(ini.GetInt("DownloadCapacity", 96)));
-    theApp.dynprefs->Add("capacities-upload", static_cast<long>(ini.GetInt("UploadCapacity", 16)));
+    theApp.dynprefs->Add("graph-delay",            static_cast<long>(ini.GetInt("StatGraphsInterval", 3)));
+    theApp.dynprefs->Add("tree-delay",             static_cast<long>(ini.GetInt("statsInterval", 5)));
+    theApp.dynprefs->Add("capacities-download",    static_cast<long>(ini.GetInt("DownloadCapacity", 96)));
+    theApp.dynprefs->Add("capacities-upload",      static_cast<long>(ini.GetInt("UploadCapacity", 16)));
     theApp.dynprefs->Add("server-connect-retries", static_cast<long>(ini.GetInt("DeadServerRetry", 1)));
     prefs->splitterbarPosition = ini.GetInt("SplitterbarPosition", 75);
-    theApp.dynprefs->Add("graph-average", static_cast<long>(ini.GetInt("StatsAverageMinutes", 5)));
-    prefs->MaxConperFive = ini.GetInt("MaxConnectionsPerFiveSeconds", GetDefaultMaxConperFive());
-    theApp.dynprefs->Add("reconnect-on-loss", ini.GetBool("Reconnect", true));
-    theApp.dynprefs->Add("priority-system", ini.GetBool("Scoresystem", true));
-    theApp.dynprefs->Add("enable-ich", ini.GetBool("ICH", true));
-    theApp.dynprefs->Add("autoupdate-server", ini.GetBool("Serverlist", false));    
+    theApp.dynprefs->Add("graph-average",          static_cast<long>(ini.GetInt("StatsAverageMinutes", 5)));
+    theApp.dynprefs->Add("max-per-5",              static_cast<long>(ini.GetInt("MaxConnectionsPerFiveSeconds", GetDefaultMaxConperFive())));
+    theApp.dynprefs->Add("reconnect-on-loss",      ini.GetBool("Reconnect", true));
+    theApp.dynprefs->Add("priority-system",        ini.GetBool("Scoresystem", true));
+    theApp.dynprefs->Add("enable-ich",             ini.GetBool("ICH", true));
+    theApp.dynprefs->Add("autoupdate-server",      ini.GetBool("Serverlist", false));    
     snprintf(prefs->m_szLRUServermetURL, sizeof prefs->m_szLRUServermetURL, "%s", ini.GetString("LRUServermetURL") .GetData());
     prefs->updatenotify = ini.GetBool("UpdateNotify", false);
-    theApp.dynprefs->Add("minimize-to-tray", ini.GetBool("MinToTray", false));
-    theApp.dynprefs->Add("add-server-server", ini.GetBool("AddServersFromServer", true));
-    theApp.dynprefs->Add("add-server-client", ini.GetBool("AddServersFromClient", true));
-    theApp.dynprefs->Add("show-splashscreen", ini.GetBool("Splashscreen", true));
-    theApp.dynprefs->Add("bring-to-front", ini.GetBool("BringToFront", true));
-    theApp.dynprefs->Add("download-doubleclick", ini.GetBool("TransferDoubleClick", true));
-    theApp.dynprefs->Add("beep-on-errors", ini.GetBool("BeepOnError", true));
-    theApp.dynprefs->Add("prompt-on-exit", ini.GetBool("ConfirmExit", false));
-    theApp.dynprefs->Add("filter-bad-ip", ini.GetBool("FilterBadIPs", true));
-    theApp.dynprefs->Add("autoconnect", ini.GetBool("Autoconnect", false));
-    prefs->showRatesInTitle = ini.GetBool("ShowRatesOnTitle", false);
-    theApp.dynprefs->Add("online-signature", ini.GetBool("OnlineSignature", false));
-    theApp.dynprefs->Add("start-minimized", ini.GetBool("StartupMinimized", false));
-    theApp.dynprefs->Add("use-safe-connect", ini.GetBool("SafeServerConnect", false));
+    theApp.dynprefs->Add("minimize-to-tray",       ini.GetBool("MinToTray", false));
+    theApp.dynprefs->Add("add-server-server",      ini.GetBool("AddServersFromServer", true));
+    theApp.dynprefs->Add("add-server-client",      ini.GetBool("AddServersFromClient", true));
+    theApp.dynprefs->Add("show-splashscreen",      ini.GetBool("Splashscreen", true));
+    theApp.dynprefs->Add("bring-to-front",         ini.GetBool("BringToFront", true));
+    theApp.dynprefs->Add("download-doubleclick",   ini.GetBool("TransferDoubleClick", true));
+    theApp.dynprefs->Add("beep-on-errors",         ini.GetBool("BeepOnError", true));
+    theApp.dynprefs->Add("prompt-on-exit",         ini.GetBool("ConfirmExit", false));
+    theApp.dynprefs->Add("filter-bad-ip",          ini.GetBool("FilterBadIPs", true));
+    theApp.dynprefs->Add("autoconnect",            ini.GetBool("Autoconnect", false));
+    theApp.dynprefs->Add("xfer-on-title",          ini.GetBool("ShowRatesOnTitle", false));
+    theApp.dynprefs->Add("online-signature",       ini.GetBool("OnlineSignature", false));
+    theApp.dynprefs->Add("start-minimized",        ini.GetBool("StartupMinimized", false));
+    theApp.dynprefs->Add("use-safe-connect",       ini.GetBool("SafeServerConnect", false));
     prefs->filterlevel = ini.GetInt("FilterLevel", 127);
-    theApp.dynprefs->Add("auto-static", ini.GetBool("AutoConnectStaticOnly", false));
+    theApp.dynprefs->Add("auto-static",            ini.GetBool("AutoConnectStaticOnly", false));
     prefs->autotakeed2klinks = ini.GetBool("AutoTakeED2KLinks", true);
-    theApp.dynprefs->Add("add-paused", ini.GetBool("AddNewFilesPaused", false));
-    theApp.dynprefs->Add("progress-bar-style", static_cast<long>(ini.GetInt("3DDepth", 0)));
+    theApp.dynprefs->Add("add-paused",             ini.GetBool("AddNewFilesPaused", false));
+    theApp.dynprefs->Add("progress-bar-style",     static_cast<long>(ini.GetInt("3DDepth", 0)));
     prefs->useDownloadNotifier = ini.GetBool("NotifyOnDownload", false);
     prefs->useChatNotifier = ini.GetBool("NotifyOnChat", false);
     prefs->useLogNotifier = ini.GetBool("NotifyOnLog", false);
@@ -548,19 +548,19 @@ bool CPreferences::LoadPreferences(void)
     prefs->m_bircacceptlinks = ini.GetBool("IRCAcceptLinks", false);
     prefs->m_bircignoreinfomessage = ini.GetBool("IRCIgnoreInfoMessage", false);
     prefs->m_bircignoreemuleprotoinfomessage = ini.GetBool("IRCIgnoreEmuleProtoInfoMessage", true);
-    theApp.dynprefs->Add("smart-lowid-check", ini.GetBool("SmartIdCheck", true));
+    theApp.dynprefs->Add("smart-lowid-check",      ini.GetBool("SmartIdCheck", true));
     prefs->m_bVerbose = ini.GetBool("Verbose", false);
-    theApp.dynprefs->Add("last-chunk-first", ini.GetBool("PreviewPrio", false));
-    prefs->m_bupdatequeuelist = ini.GetBool("UpdateQueueListPref", false);
-    theApp.dynprefs->Add("add-server-high", ini.GetBool("ManualHighPrio", false));
-    theApp.dynprefs->Add("transfer-full-chunks", ini.GetBool("FullChunkTransfers", true));
-    theApp.dynprefs->Add("start-next-file", ini.GetBool("StartNextFile", false));
-    theApp.dynprefs->Add("show-overhead", ini.GetBool("ShowOverhead", false));
+    theApp.dynprefs->Add("last-chunk-first",       ini.GetBool("PreviewPrio", false));
+    theApp.dynprefs->Add("realtime-queue",         ini.GetBool("UpdateQueueListPref", false));
+    theApp.dynprefs->Add("add-server-high",        ini.GetBool("ManualHighPrio", false));
+    theApp.dynprefs->Add("transfer-full-chunks",   ini.GetBool("FullChunkTransfers", true));
+    theApp.dynprefs->Add("start-next-file",        ini.GetBool("StartNextFile", false));
+    theApp.dynprefs->Add("show-overhead",          ini.GetBool("ShowOverhead", false));
     prefs->moviePreviewBackup = ini.GetBool("VideoPreviewBackupped", true);
-    prefs->m_iFileBufferSize = ini.GetInt("FileBufferSizePref", 16);
-    prefs->m_iQueueSize = ini.GetInt("QueueSizePref", 50);
+    theApp.dynprefs->Add("file-buffer-size",       static_cast<long>(ini.GetInt("FileBufferSizePref", 16)));
+    theApp.dynprefs->Add("upload-queue-size",      static_cast<long>(ini.GetInt("QueueSizePref", 50)));
     prefs->versioncheckdays = ini.GetInt("Check4NewVersionDelay", 5);
-    theApp.dynprefs->Add("auto-priority-share", ini.GetBool("UAPPref", true));
+    theApp.dynprefs->Add("auto-priority-share",    ini.GetBool("UAPPref", true));
     prefs->indicateratings = ini.GetBool("IndicateRatings", true);
     prefs->allcatType = ini.GetInt("AllcatType", 0);
     prefs->showAllNotCats = ini.GetBool("ShowAllNotCats", false);
@@ -628,7 +628,7 @@ bool CPreferences::LoadPreferences(void)
     
     for (int i = 0 ; i < 13 ; i++)
     {
-         buffer2.Format("StatColor%i", i);
+         buffer2.Printf("StatColor%i", i);
          sprintf(buffer, "%s", ini.GetString(buffer2, "0", "eMule") .c_str());
          if ((prefs->statcolors[i] = atoll(buffer))) NoColor = false;
     }
@@ -672,24 +672,35 @@ bool CPreferences::Load_Adresses(void)
     sprintf(full_path, "%sadresses.dat", static_cast<const char *>(theApp.dynprefs->Get<wxString>("app-directory").c_str()));
     FILE *sdirfile = fopen(full_path, "r");
     delete[] full_path;
+
     if (sdirfile)
     {
         char buffer[MAX_PATH];
+
         while (!feof(sdirfile))
         {
             memset(buffer, 0, sizeof(buffer));
             fgets(buffer, sizeof(buffer) - 1, sdirfile);
             char *ptr = strchr(buffer, '\n');
-            if (ptr) *ptr = 0;
+
+            if (ptr)
+            {
+                *ptr = 0;
+            }
+
             if (strlen(buffer) > 1)
-            adresses_list.Append(new CString(buffer));
+            {
+                addresses_list.push_back(wxString(buffer, *wxConvCurrent));
+            }
         }
+
         fclose(sdirfile);
     }
     else
     {
         error = true;
     }
+
     return error;
 }
 
@@ -754,81 +765,107 @@ bool CPreferences::Save_Shared_Dirs(void)
 bool CPreferences::SaveCats(void)
 {
     bool error = false;
-    FILE *category_fd;    
+    ofstream fout;
     wxString buffer;
     wxString catinif(theApp.dynprefs->Get<wxString>("app-directory") + wxT("Category.dat"));
+
     if (GetCatCount() > 0)
     {
-         category_fd = fopen(catinif, "w");
-	 if (category_fd != NULL)
-	 {
-	     fprintf(category_fd, "%d ", catMap.GetCount() - 1);
-             for (int ix = 1 ; ix < catMap.GetCount() ; ix++)
-             { 
-  	          fprintf(category_fd,"%s\n",catMap.GetAt(ix)->title);              
-                  fprintf(category_fd,"%s\n",catMap.GetAt(ix)->incomingpath);
-                  fprintf(category_fd,"%s\n",catMap.GetAt(ix)->comment);
-                  fprintf(category_fd,"0x%lx\n", catMap.GetAt(ix)->color);
-                  fprintf(category_fd,"%.3u\n", catMap.GetAt(ix)->prio + 1);
-	     }
-             fclose(category_fd);
-         } 
-         else
-	 {
-	     error = true;
-         }
+        fout.open(catinif.c_str());
+
+        if (fout.good() == true)
+        {
+            fout << catMap.GetCount() - 1 << " ";
+
+            for (int ix = 1; ix < catMap.GetCount(); ++ix)
+            { 
+                fout << catMap.GetAt(ix)->title << endl;
+                fout << catMap.GetAt(ix)->incomingpath << endl;
+
+                if (catMap.GetAt(ix)->comment != "")
+                {
+                    fout << catMap.GetAt(ix)->comment << endl;
+                }
+                else
+                {
+                    fout << "-1" << endl;
+                }
+
+                fout << "0x" << std::hex << catMap.GetAt(ix)->color << endl;
+                fout << std::setprecision(3) << std::fixed << catMap.GetAt(ix)->prio + 1 << endl;
+            }
+
+            fout.close();
+        } 
+        else
+        {
+            error = true;
+        }
     }
     return error;
 }
-
+#include <iostream>
+using std::cout;
 bool CPreferences::LoadCats(void)
 {
     bool error = false;
     int max;
     char buffer[2051];
     char *dummy;
-    FILE *category_fd; 
+
     // default cat
-    Category_Struct *newcat = new Category_Struct;
-    sprintf(newcat->title, "");
-    sprintf(newcat->incomingpath, "");
-    sprintf(newcat->comment, "");
+    Category_Struct* newcat = new Category_Struct;
     newcat->prio = 0;
     newcat->color = 0;
     AddCat(newcat);
     // Load cats
     wxString catinif(theApp.dynprefs->Get<wxString>("app-directory") + wxT("Category.dat"));
-    category_fd = fopen(catinif, "r");
-    if (category_fd != NULL)
+
+    ifstream fin(catinif.c_str());
+    
+    if (fin.good() == true)
     {
-	   fscanf(category_fd, "%d ", &max);
-           for (int i = 1 ; i <= max ; i++)
-           {
-                  Category_Struct *newcat = new Category_Struct;
-  	          fgets(buffer, 66, category_fd);
-                  sprintf(newcat->title, "");
-                  strncat(newcat->title, buffer, strlen(buffer) - 1);          
-                  fgets(buffer, 2050, category_fd);                                  
-                  sprintf(newcat->incomingpath, "");
-                  strncat(newcat->incomingpath, buffer, strlen(buffer) - 1);
-                  fgets(buffer, 258, category_fd);
-                  sprintf(newcat->comment, "");
-                  strncat(newcat->comment, buffer, strlen(buffer) - 1);
-                  fgets(buffer, 15, category_fd);
-                  newcat->color = (uint32)strtoul(buffer, &dummy, 0);
-                  fgets(buffer, 5, category_fd);
-                  newcat->prio = (uint8) atoi(buffer) - 1;
-                  AddCat(newcat);
-                  if (!wxFileName::DirExists(newcat->incomingpath)) 
-                  {
-                      mkdir(newcat->incomingpath, 0777);
-		  }
-           }
-           fclose(category_fd);
+        fin >> max;
+
+        std::string temp;
+
+        for (int i = 1; i <= max; ++i)
+        {
+            Category_Struct* newcat = new Category_Struct;
+
+            fin >> temp;
+            newcat->title = wxString(temp.c_str(), *wxConvCurrent);
+
+            fin >> temp;
+            newcat->incomingpath = wxString(temp.c_str(), *wxConvCurrent);
+
+            fin >> temp;
+
+            if (temp == "-1")
+            {
+                newcat->comment = "";
+            }
+            else
+            {
+                newcat->comment = wxString(temp.c_str(), *wxConvCurrent);
+            }
+
+            fin >> std::hex >> newcat->color;
+            fin >> std::dec >> newcat->prio;
+
+            AddCat(newcat);
+
+            if (!wxFileName::DirExists(newcat->incomingpath)) 
+            {
+                wxMkdir(newcat->incomingpath, 0777);
+            }
+        }
+
+        fin.close();
     } 
     else
     {
-	   error = true;
+       error = true;
     }
     return error;
 }
@@ -997,7 +1034,7 @@ void CPreferences::SetColumnWidth(const short int t, int index, int width)
     }
 }
 
-BOOL CPreferences::GetColumnHidden(Table t, int index) const
+bool CPreferences::GetColumnHidden(Table t, int index) const
 {
     switch (t)
     {
@@ -1019,7 +1056,7 @@ BOOL CPreferences::GetColumnHidden(Table t, int index) const
     return FALSE;
 }
 
-void CPreferences::SetColumnHidden(Table t, int index, BOOL bHidden)
+void CPreferences::SetColumnHidden(Table t, int index, bool bHidden)
 {
     switch (t)
     {
