@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -26,7 +26,6 @@
 #include "PPgDirectories.h"                 // Needed for CPPgDirectories
 #include "PPgNotify.h"                      // Needed for CPPgNotify
 #include "PPgSourcesDropping.h"             // Needed for CPPgSourcesDropping
-#include "PPgTweaks.h"                      // Needed for CPPgTweaks
 #include "Preferences.h"                    // CPreferences
 #include "xmule.h"                          // Needed for theApp
 
@@ -41,8 +40,13 @@ BEGIN_EVENT_TABLE(CPreferencesDlg, wxDialog)
     EVT_BUTTON(wxCANCEL, CPreferencesDlg::OnBtnCancel)
 END_EVENT_TABLE()
 
-CPreferencesDlg::CPreferencesDlg(wxWindow *parent, CPreferences *prefs)
+CPreferencesDlg::CPreferencesDlg(wxWindow *parent, CPreferences* prefs)
 : wxDialog(parent, 9999, _("Preferences"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE |wxSYSTEM_MENU)
+{
+    OnInit(prefs);
+}
+
+void CPreferencesDlg::OnInit(CPreferences* prefs)
 {
     //SetFont(wxFont(8,wxSWISS,wxNORMAL,wxNORMAL));
     // here comes brave new resource system
@@ -51,7 +55,6 @@ CPreferencesDlg::CPreferencesDlg(wxWindow *parent, CPreferences *prefs)
     // load pages
     m_wndDirectories = new CPPgDirectories(book);
     m_wndNotify = new CPPgNotify(book);
-    m_wndTweaks = new CPPgTweaks(book);
     // Creating Sources Dropping window:
     m_wndSourcesDropping = new CPPgSourcesDropping(book);
     // Creating GUI Tweaks window:
@@ -82,7 +85,6 @@ int CPreferencesDlg::ShowModal()
     // setup pages
     m_wndDirectories->LoadSettings();
     m_wndNotify->LoadSettings();
-    m_wndTweaks->LoadSettings();
     // Load settings in Dropping Sources window:
     m_wndSourcesDropping->LoadSettings();
     // and then do the show
@@ -98,7 +100,6 @@ void CPreferencesDlg::OnBtnOk(wxCommandEvent&evt)
     // apply all pages
     m_wndDirectories->OnApply();
     m_wndNotify->OnApply();
-    m_wndTweaks->OnApply();
     // OnApply in Sources Dropping:
     m_wndSourcesDropping->OnApply();
     // Save Preferences & Shared Directories
@@ -119,6 +120,5 @@ void CPreferencesDlg::SetPrefs(CPreferences* in_prefs)
     app_prefs = in_prefs;
     m_wndDirectories->SetPrefs(in_prefs);
     m_wndNotify->SetPrefs(in_prefs);
-    m_wndTweaks->SetPrefs(in_prefs);
     m_wndSourcesDropping->SetPrefs(in_prefs);  // Setting preferences to Sources Dropping
 }
