@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -29,7 +29,6 @@ class CPPgDirectories;
 class CPPgFiles;
 class CPPgStats;
 class CPPgNotify;
-class CPPgTweaks;
 class CPPgSourcesDropping;
 class CPreferences;
 
@@ -49,9 +48,9 @@ protected:
 private:
     DECLARE_EVENT_TABLE()
 
+    void OnInit(CPreferences *prefs);
     CPPgDirectories* m_wndDirectories;
     CPPgNotify* m_wndNotify;
-    CPPgTweaks* m_wndTweaks;
     CPPgSourcesDropping* m_wndSourcesDropping;
     CPreferences* app_prefs;
 
