@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -49,9 +49,9 @@ wxThread::ExitCode CPreviewThread::Entry()
     /*try*/
     {
         srcFile = m_pPartfile->m_hpartfile.Duplicate();
-        uint32 nSize = m_pPartfile->GetFileSize();
-        wxString strExtension = CString(strrchr(m_pPartfile->GetFileName(), '.'));
-        wxString strPreviewName = CString(theApp.glob_prefs->GetTempDir()) + CString("\\") + CString(m_pPartfile->GetFileName()) .Mid(0, 5) + CString("_preview") + strExtension;
+        uint32_t nSize = m_pPartfile->GetFileSize();
+        wxString strExtension = wxString(strrchr(m_pPartfile->GetFileName(), '.'));
+        wxString strPreviewName = wxString(theApp.glob_prefs->GetTempDir()) + wxString("\\") + wxString(m_pPartfile->GetFileName()) .Mid(0, 5) + wxString("_preview") + strExtension;
         bool bFullSized = true;
         if (!strExtension.CompareNoCase(".mpg") || !strExtension.CompareNoCase(".mpeg"))
         bFullSized = false;
@@ -61,14 +61,14 @@ wxThread::ExitCode CPreviewThread::Entry()
         destFile.SetLength(nSize);
         destFile.SeekToBegin();
         BYTE abyBuffer[4096];
-        uint32 nRead;
+        uint32_t nRead;
         while (destFile.GetPosition() + 4096 < PARTSIZE *2)
         {
             nRead = srcFile->Read(abyBuffer, 4096);
             destFile.Write(abyBuffer, nRead);
         }
         srcFile->Seek( - (PARTSIZE *2), CFile::end);
-        uint32 nToGo = PARTSIZE *2;
+        uint32_t nToGo = PARTSIZE *2;
         if (bFullSized)
         destFile.Seek( - (PARTSIZE *2), CFile::end);
         do
