@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -25,22 +25,30 @@
 #	include "xmule-headers.h"
 #else
 #	include "ChatWnd.h"
+#include "ClientCredits.h"                  // CClientCredits
 #	include "ClientDetailDialog.h"
 #	include "FriendList.h"
 #	include "KnownFile.h"
 #	include "muuli_wdr.h"
-#	include "otherfunctions.h"
 #	include "opcodes.h"
+#	include "otherfunctions.h"
+#include "otherstructs.h"                   // ServerMet_Struct - audited 5 Nov 2004
+#include "PartFile.h"                       // Needed for PR_VERYHIGH - audited 5 Nov 2004
 #include "Preferences.h"                    // CPreferences::List Settings
 #	include "QueueListCtrl.h"
 #	include "SharedFileList.h"
 #	include "TransferWnd.h"
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
 #	include "UploadQueue.h"
 #	include "wintypes.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
 #endif
 
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+
+#include <wx/menu.h>                        // Needed for wxMenu
+
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
 // images
@@ -59,9 +67,9 @@
 
 //IMPLEMENT_DYNAMIC(CQueueListCtrl, CMuleListCtrl)
 BEGIN_EVENT_TABLE(CQueueListCtrl, CMuleListCtrl)
-EVT_RIGHT_DOWN(CQueueListCtrl::OnNMRclick)
-EVT_LIST_COL_CLICK(ID_QUEUELIST, CQueueListCtrl::OnColumnClick)
-EVT_TIMER(2349, CQueueListCtrl::OnTimer)
+    EVT_RIGHT_DOWN(CQueueListCtrl::OnNMRclick)
+    EVT_LIST_COL_CLICK(ID_QUEUELIST, CQueueListCtrl::OnColumnClick)
+    EVT_TIMER(2349, CQueueListCtrl::OnTimer)
 END_EVENT_TABLE()
 
 CQueueListCtrl::CQueueListCtrl()
@@ -209,7 +217,7 @@ void CQueueListCtrl::Localize()
     hdi.mask = HDI_TEXT;
     if (pHeaderCtrl->GetItemCount() != 0)
     {
-        CString strRes;
+        wxString strRes;
         strRes = GetResString(IDS_QL_USERNAME);
         hdi.pszText = strRes.GetBuffer();
         pHeaderCtrl->SetItem(0, &hdi);
@@ -252,7 +260,7 @@ void CQueueListCtrl::Localize()
 
 void CQueueListCtrl::AddClient(CUpDownClient *client)
 {
-    uint32 itemnr = GetItemCount();
+    uint32_t itemnr = GetItemCount();
     itemnr = InsertItem(itemnr, client->GetUserName());
     SetItemData(itemnr, (long) client);
     wxListItem myitem;
@@ -264,14 +272,14 @@ void CQueueListCtrl::AddClient(CUpDownClient *client)
 
 void CQueueListCtrl::RemoveClient(CUpDownClient *client)
 {
-    sint32 itemnr = FindItem( - 1, (long) client);
+    int32_t itemnr = FindItem( - 1, (long) client);
     if (itemnr != ( - 1))
     DeleteItem(itemnr);
 }
 
 void CQueueListCtrl::RefreshClient(CUpDownClient *client)
 {
-    sint16 result = FindItem( - 1, (long) client);
+    int16_t result = FindItem( - 1, (long) client);
     if (result != - 1)
     {
         long first, last;
@@ -343,7 +351,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
     cur_rec.top = rect.y;
     cur_rec.right = rect.x + rect.width;
     cur_rec.bottom = rect.y + rect.height;
-    CString Sbuffer;
+    wxString Sbuffer;
     //	char buffer[100];
     CKnownFile *file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
@@ -369,12 +377,12 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
             {
             case 0:
                 {
-                    uint8 image;
+                    uint8_t image;
                     if (client->IsFriend())
                     image = 4;
                     else if(client->ExtProtocolAvailable())
                     {
-                        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                         image = 3;
                         else
                         image = 1;
@@ -383,21 +391,21 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                     {
                         if (client->GetClientSoft() == SO_MLDONKEY || client->GetClientSoft() == SO_NEW_MLDONKEY)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 6;
                             else
                             image = 5;
                         }
                         else if(client->GetClientSoft() == SO_EDONKEYHYBRID)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 8;
                             else
                             image = 7;
                         }
                         else
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 2;
                             else
                             image = 0;
@@ -412,7 +420,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                                         };
                     //imagelist.Draw(dc,image, point, ILD_NORMAL);
                     imagelist.Draw(image, *dc, cur_rec.left, cur_rec.top + 1, wxIMAGELIST_DRAW_TRANSPARENT);
-                    Sbuffer.Format("%s", client->GetUserName());
+                    Sbuffer.Printf("%s", client->GetUserName());
                     cur_rec.left += 20;
                     dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
                     cur_rec.left -= 20;
@@ -420,7 +428,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                 }
             case 1:
                 if (file)
-                Sbuffer.Format("%s", file->GetFileName());
+                Sbuffer.Printf("%s", file->GetFileName());
                 else
                 Sbuffer = "?";
                 break;
@@ -430,19 +438,19 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                     switch (file->GetUpPriority())
                     {
                     case PR_VERYHIGH:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIORELEASE) .GetData());
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIORELEASE) .GetData());
                         break;
                     case PR_HIGH:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIOHIGH) .GetData());
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIOHIGH) .GetData());
                         break;
                     case PR_LOW:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIOLOW) .GetData());
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIOLOW) .GetData());
                         break;
                     case PR_VERYLOW:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIOVERYLOW) .GetData());
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIOVERYLOW) .GetData());
                         break;
                     default:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIONORMAL) .GetData());
+                        Sbuffer.Printf("%s", GetResString(IDS_PRIONORMAL) .GetData());
                         break;
                     }
                 }
@@ -450,25 +458,25 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                 Sbuffer = "?";
                 break;
             case 3:
-                Sbuffer.Format("%.1f", (float) client->GetScore(false, false, true));
+                Sbuffer.Printf("%.1f", (float) client->GetScore(false, false, true));
                 break;
             case 4:
-                Sbuffer.Format("%i", client->GetScore(false));
+                Sbuffer.Printf("%i", client->GetScore(false));
                 break;
             case 5:
-                Sbuffer.Format("%i", client->GetAskedCount());
+                Sbuffer.Printf("%i", client->GetAskedCount());
                 break;
             case 6:
-                Sbuffer.Format("%s", CastSecondsToHM((::GetTickCount() - client->GetLastUpRequest()) /1000) .GetData());
+                Sbuffer.Printf("%s", CastSecondsToHM((::GetTickCount() - client->GetLastUpRequest()) /1000) .GetData());
                 break;
             case 7:
-                Sbuffer.Format("%s", CastSecondsToHM((::GetTickCount() - client->GetWaitStartTime()) /1000) .GetData());
+                Sbuffer.Printf("%s", CastSecondsToHM((::GetTickCount() - client->GetWaitStartTime()) /1000) .GetData());
                 break;
             case 8:
                 if (client->IsBanned())
-                Sbuffer.Format("%s", GetResString(IDS_YES) .GetData());
+                Sbuffer.Printf("%s", GetResString(IDS_YES) .GetData());
                 else
-                Sbuffer.Format("%s", GetResString(IDS_NO) .GetData());
+                Sbuffer.Printf("%s", GetResString(IDS_NO) .GetData());
                 break;
             case 9:
                 if (client->GetUpPartCount())
@@ -606,19 +614,19 @@ int CQueueListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
     switch (lParamSort)
     {
     case 0:
-        return CString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
+        return wxString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
     case 100:
-        return CString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
+        return wxString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
     case 1:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
+        return wxString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
         return 0;
     case 101:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
+        return wxString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
@@ -669,9 +677,12 @@ int CQueueListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
 void CQueueListCtrl::OnTimer(wxTimerEvent &evt)
 {
     // Don't do anything if the app is shutting down - can cause unhandled exceptions
-    if (!theApp.xmuledlg->IsRunning() || !theApp.glob_prefs->GetUpdateQueueList())
-    return;
-    CUpDownClient *update = theApp.uploadqueue->GetNextClient(NULL);
+    if (!theApp.xmuledlg->IsRunning() || theApp.dynprefs->Get<bool>("realtime-queue") == false)
+	{
+		return;
+	}
+
+	CUpDownClient *update = theApp.uploadqueue->GetNextClient(NULL);
     while (update)
     {
         theApp.xmuledlg->transferwnd->queuelistctrl->RefreshClient(update);
@@ -684,8 +695,11 @@ void CQueueListCtrl::OnTimer(wxTimerEvent &evt)
 void CQueueListCtrl::QueueUpdateTimer()
 {
     // Don't do anything if the app is shutting down - can cause unhandled exceptions
-    if (!theApp.xmuledlg->IsRunning() || !theApp.glob_prefs->GetUpdateQueueList())
-    return;
+    if (!theApp.xmuledlg->IsRunning() || theApp.dynprefs->Get<bool>("realtime-queue") == false)
+	{
+		return;
+	}
+
     CUpDownClient *update = theApp.uploadqueue->GetNextClient(NULL);
     while (update)
     {
