@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This file was a part of eMule
@@ -52,7 +52,7 @@
 #include "ServerList.h"           // Needed for CServerList
 #include "sockets.h"              // Needed for CServerConnect
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #define ID_SEARCHTIMER 55219
 
@@ -265,13 +265,13 @@ void slfield_get(wxString basestring, int fieldnumber, wxString &field)
             }
             else
             {
-                column++;
+                ++column;
                 startpos = endpos + 1;
-                endpos++;
+                ++endpos;
             }
             break;
         default:
-            endpos++;
+            ++endpos;
             break;
         }
     }
@@ -286,7 +286,7 @@ void insertresult(int smaskcurrent, wxString item_new)
     itemindex_new = 1;
     while ((sresultindex[itemindex_new]) && (itemindex_new < 32760))
     {
-        itemindex_new++;
+        ++itemindex_new;
     }
     if (itemindex_new < 32760)
     {
@@ -300,7 +300,7 @@ void insertresult(int smaskcurrent, wxString item_new)
             sresultdefs[itemindex_new] = item_new;
             sresultprevious[itemindex_last] = itemindex_last;
             sresultnext[itemindex_last] = itemindex_last;
-            smaskresults[smaskcurrent]++;
+            ++smaskresults[smaskcurrent];
         }
         else
         {
@@ -332,7 +332,7 @@ void insertresult(int smaskcurrent, wxString item_new)
                 sresultprevious[itemindex_new] = itemindex_last;
                 sresultnext[itemindex_last] = itemindex_new;
                 sresultprevious[sresultnext[itemindex_new]] = itemindex_new;
-                smaskresults[smaskcurrent]++;
+                ++smaskresults[smaskcurrent];
             }
             // End of if(itemindex_last < 1)
         }
@@ -655,13 +655,12 @@ printf("glspacket2\n");
     }
 }
 
-void CSearchDlg::ExecuteLinkED2K()
+void CSearchDlg::ExecuteLinkED2K(wxString ed2k)
 {
     bool result = false;
-    wxString ed2k, ed2klink;
+    wxString ed2klink;
     int p1 = 0, p2 = 0, l = 0;
     CED2KLink *pLink;
-    ed2k = sdinput[5]->GetValue() .Trim();
     ed2k.Replace("%20", " ");
     l = ed2k.Len();
     while (p2 < l)
@@ -944,7 +943,7 @@ void CSearchDlg::ButtonStartLink(wxCommandEvent &event)
 #elifdef __XMULE2__
         theApp.xmuledlg->StartFast(sdinput[5]);
 #else
-        ExecuteLinkED2K();
+        ExecuteLinkED2K(sdinput[5]->GetValue().Trim());
 #endif
         sdinput[5]->Clear();
         break;
@@ -1800,7 +1799,8 @@ void get_md4(unsigned char *&md4, unsigned char *&pck, int &pcksize)
         int i = 0;
         while (i < 16)
         {
-            md4[i] = pck[i++];
+            md4[i] = pck[i];
+            ++i;
         }
         pck += 16;
         pcksize -= 16;
@@ -1818,7 +1818,8 @@ void get_ip(wxUint32 &ip, unsigned char *&pck, int &pcksize)
         int i = 0;
         while (i < 4)
         {
-            ip = (ip << 8) + pck[i++];
+            ip = (ip << 8) + pck[i];
+            ++i;
         }
         pck += 4;
         pcksize -= 4;
@@ -1836,7 +1837,8 @@ void get_po(wxUint32 &port, unsigned char *&pck, int &pcksize)
         int i = 0;
         while (i < 2)
         {
-            port = (port << 8) + pck[1 - i++];
+            port = (port << 8) + pck[1 - i];
+            ++i;
         }
         pck += 2;
         pcksize -= 2;
@@ -1854,7 +1856,8 @@ void get_tagc(wxUint32 &tagcounter, unsigned char *&pck, int &pcksize)
         int i = 0;
         while (i < 4)
         {
-            tagcounter += (tagcounter << 8) + (wxChar) pck[3 - i++];
+            tagcounter += (tagcounter << 8) + (wxChar) pck[3 - i];
+            ++i;
         }
         pck += 4;
         pcksize -= 4;
@@ -1913,19 +1916,28 @@ void get_tag(unsigned char *&pck, int &pcksize)
                                 case 1:
                                     file_name = "";
                                     while (i < metatag_stringlength &&i < pcksize)
-                                    file_name += (wxChar) pck[i++];
+                                    {
+                                        file_name += (wxChar) pck[i];
+                                        ++i;
+                                    }
                                     break;
                                     //(file):
                                 case 3:
                                     file_typename = "";
                                     while (i < metatag_stringlength &&i < pcksize)
-                                    file_typename += (wxChar) pck[i++];
+                                    {
+                                        file_typename += (wxChar) pck[i];
+                                        ++i;
+                                    }
                                     break;
                                     //(file)extension:
                                 case 4:
                                     file_extension = "";
                                     while (i < metatag_stringlength &&i < pcksize)
-                                    file_extension += (wxChar) pck[i++];
+                                    {
+                                        file_extension += (wxChar) pck[i];
+                                        ++i;
+                                    }
                                     break;
                                     //Artist+Album:
                                 case 65:
@@ -1935,13 +1947,19 @@ void get_tag(unsigned char *&pck, int &pcksize)
                                     case 108:
                                         file_album = "";
                                         while (i < metatag_stringlength &&i < pcksize)
-                                        file_album += (wxChar) pck[i++];
+                                        {
+                                            file_album += (wxChar) pck[i];
+                                            ++i;
+                                        }
                                         break;
                                         //Artist:
                                     case 114:
                                         file_artist = "";
                                         while (i < metatag_stringlength &&i < pcksize)
-                                        file_artist += (wxChar) pck[i++];
+                                        {
+                                            file_artist += (wxChar) pck[i];
+                                            ++i;
+                                        }
                                         break;
                                         //unknown:
                                     default:
@@ -1956,25 +1974,37 @@ void get_tag(unsigned char *&pck, int &pcksize)
                                 case 70:
                                     file_folder = "";
                                     while (i < metatag_stringlength &&i < pcksize)
-                                    file_folder += (wxChar) pck[i++];
+                                    {
+                                        file_folder += (wxChar) pck[i];
+                                        ++i;
+                                    }
                                     break;
                                     //Titel:
                                 case 84:
                                     file_title = "";
                                     while (i < metatag_stringlength &&i < pcksize)
-                                    file_title += (wxChar) pck[i++];
+                                    {
+                                        file_title += (wxChar) pck[i];
+                                        ++i;
+                                    }
                                     break;
                                     //div3/codec:
                                 case 99:
                                     file_codec = "";
                                     while (i < metatag_stringlength &&i < pcksize)
-                                    file_codec += (wxChar) pck[i++];
+                                    {
+                                        file_codec += (wxChar) pck[i];
+                                        ++i;
+                                    }
                                     break;
                                     //1:42/length:
                                 case 108:
                                     file_length = "";
                                     while (i < metatag_stringlength &&i < pcksize)
-                                    file_length += (wxChar) pck[i++];
+                                    {
+                                        file_length += (wxChar) pck[i];
+                                        ++i;
+                                    }
                                     break;
                                 default:
 #if defined(__DEBUG__)
@@ -2096,8 +2126,8 @@ void get_tag(unsigned char *&pck, int &pcksize)
                 printf("\nmtagtype=%d sptagl=%d sptagt=%d \n", metatagtype, sptaglength, sptagtype);
                 pdump("CSDLG::SearchEnd mtag-8: ", pcklast, pcksizelast);
 #endif
-                pck++;
-                pcksize--;
+                ++pck;
+                --pcksize;
                 break;
             }
         }
@@ -2124,7 +2154,7 @@ void put_tag(unsigned char *&slistentry_ed2k, int &startpos, int tagtype)
         {
             slistentry_ed2k[3 - i + startpos] = file_clientip &255;
             file_clientip = file_clientip >> 8;
-            i++;
+            ++i;
         }
         startpos += 4;
         break;
@@ -2133,50 +2163,57 @@ void put_tag(unsigned char *&slistentry_ed2k, int &startpos, int tagtype)
         startpos = 20;
         while (i < 2)
         {
-            slistentry_ed2k[startpos++] = file_clientport &255;
+            slistentry_ed2k[startpos] = file_clientport &255;
             file_clientport = file_clientport >> 8;
-            i++;
+            ++i;
+            ++startpos;
         }
         break;
         //file_name:
     case 2:
         startpos = 26;
-        slistentry_ed2k[startpos++] = 2;
-        slistentry_ed2k[startpos++] = 1;
-        slistentry_ed2k[startpos++] = 0;
-        slistentry_ed2k[startpos++] = 1;
+        slistentry_ed2k[startpos] = 2;
+        slistentry_ed2k[startpos + 1] = 1;
+        slistentry_ed2k[startpos + 2] = 0;
+        slistentry_ed2k[startpos + 3] = 1;
+        startpos += 4;
         while (i < (int) file_name.Len())
         {
-            slistentry_ed2k[startpos + 2 + i] = ((const char *) file_name) [i++];
+            slistentry_ed2k[startpos + 2 + i] = ((const char *) file_name)[i];
+            ++i;
         }
-        slistentry_ed2k[startpos++] = i;
-        slistentry_ed2k[startpos++] = 0;
-        startpos += i;
+        slistentry_ed2k[startpos] = i;
+        slistentry_ed2k[startpos + 2] = 0;
+        startpos += i + 2;
         break;
         //file_size:
     case 3:
-        slistentry_ed2k[startpos++] = 3;
-        slistentry_ed2k[startpos++] = 1;
-        slistentry_ed2k[startpos++] = 0;
-        slistentry_ed2k[startpos++] = 2;
+        slistentry_ed2k[startpos] = 3;
+        slistentry_ed2k[startpos + 1] = 1;
+        slistentry_ed2k[startpos + 2] = 0;
+        slistentry_ed2k[startpos + 3] = 2;
+        startpos += 4;
         while (i < 4)
         {
-            slistentry_ed2k[startpos++] = file_size &255;
+            slistentry_ed2k[startpos + 1] = file_size &255;
             file_size = file_size >> 8;
-            i++;
+            ++i;
+            ++startpos;
         }
         break;
         //file_availability:
     case 4:
-        slistentry_ed2k[startpos++] = 3;
-        slistentry_ed2k[startpos++] = 1;
-        slistentry_ed2k[startpos++] = 0;
-        slistentry_ed2k[startpos++] = 15;
+        slistentry_ed2k[startpos] = 3;
+        slistentry_ed2k[startpos + 1] = 1;
+        slistentry_ed2k[startpos + 2] = 0;
+        slistentry_ed2k[startpos + 3] = 15;
+        startpos += 4;
         while (i < 4)
         {
-            slistentry_ed2k[startpos++] = file_availability &255;
+            slistentry_ed2k[startpos] = file_availability &255;
             file_availability = file_availability >> 8;
-            i++;
+            ++i;
+            ++startpos;
         }
         break;
         //Byte01..16:file_id=md4_hash:
@@ -2184,7 +2221,8 @@ void put_tag(unsigned char *&slistentry_ed2k, int &startpos, int tagtype)
         startpos = 0;
         while (startpos < 16)
         {
-            c = ((const char *) file_id) [i++];
+            c = ((const char *) file_id) [i];
+            ++i;
             if (c >= 'a' &&c <= 'f')
             {
                 slistentry_ed2k[startpos] = c - 'a' + 10;
@@ -2197,7 +2235,8 @@ void put_tag(unsigned char *&slistentry_ed2k, int &startpos, int tagtype)
             {
                 slistentry_ed2k[startpos] = c - '0';
             }
-            c = ((const char *) file_id) [i++];
+            c = ((const char *) file_id) [i];
+            ++i;
             slistentry_ed2k[startpos] = slistentry_ed2k[startpos] << 4;
             if (c >= 'a' &&c <= 'f')
             {
@@ -2211,7 +2250,7 @@ void put_tag(unsigned char *&slistentry_ed2k, int &startpos, int tagtype)
             {
                 slistentry_ed2k[startpos] += c - '0';
             }
-            startpos++;
+            ++startpos;
             // End of while(startpos < 16):
         }
         break;
@@ -2220,9 +2259,10 @@ void put_tag(unsigned char *&slistentry_ed2k, int &startpos, int tagtype)
         startpos = 22;
         while (i < 4)
         {
-            slistentry_ed2k[startpos++] = file_tagc &255;
+            slistentry_ed2k[startpos] = file_tagc &255;
             file_tagc = file_tagc >> 8;
-            i++;
+            ++i;
+            ++startpos;
         }
         break;
         // End of switch(tagtype):
@@ -2278,7 +2318,7 @@ void CSearchDlg::ShowSearchResults()
                         default:
                             break;
                         }
-                        endpos++;
+                        ++endpos;
                     }
                     // Show 1 Search Result
                     startpos = 0;
@@ -2295,7 +2335,7 @@ void CSearchDlg::ShowSearchResults()
                                 //clientip:
                             case 0:
                                 //clientport:
-                            case 1: column++;
+                            case 1: ++column;
                                 break;
                             case 2:
                                 if (endpos > startpos)
@@ -2335,7 +2375,7 @@ void CSearchDlg::ShowSearchResults()
                                     }
                                     item.SetTextColour( *colorarray[col_dummy]);
                                 }
-                                item.SetColumn(column++-2);
+                                item.SetColumn(column++ - 2);
                                 item.SetText(linebuffer);
                                 (void) lsresults->InsertItem(item);
                                 lsresults->SetItemData(i, itemindex);
@@ -2351,7 +2391,7 @@ void CSearchDlg::ShowSearchResults()
                                 {
                                     linebuffer.Printf(wxT(" "));
                                 }
-                                item.SetColumn(column++-2);
+                                item.SetColumn(column++ - 2);
                                 item.SetText(linebuffer);
                                 lsresults->SetItem(item);
                                 break;
@@ -2363,12 +2403,12 @@ void CSearchDlg::ShowSearchResults()
                             break;
                         }
                         // End of switch(((const char *) sresultdefs[itemindex]) [endpos])
-                        endpos++;
+                        ++endpos;
                     }
                     // End of while(((const char *) sresultdefs[itemindex]) [endpos])
                     itemindex = sresultnext[itemindex];
                     //next item:
-                    i++;
+                    ++i;
                 }
                 //End of do
                 while ((int) itemindex != smasknext[smaskcurrent]);
@@ -2445,12 +2485,12 @@ void CSearchDlg::ShowSearchMasks()
                 default:
                     break;
                 }
-                endpos++;
+                ++endpos;
             }
-            i++;
+            ++i;
         }
         //next item:
-        itemindex++;
+        ++itemindex;
     }
     srtab_lock = 0;
 }
@@ -2461,7 +2501,7 @@ void CSearchDlg::SearchEnd(char *packet, wxUint32 packetsize, wxUint32 nServerIP
     wxString slistentry;
     unsigned char *pck, *pcklast;
     int lsmaskr = 0, pcksize, i;
-    srtab_deep++;
+    ++srtab_deep;
     pck = (unsigned char *) packet;
     pcksize = packetsize;
     if (!nServerPort)
@@ -2506,13 +2546,19 @@ void CSearchDlg::SearchEnd(char *packet, wxUint32 packetsize, wxUint32 nServerIP
             get_po(file_clientport, pck, pcksize);
             //tagcounter:
             get_tagc(file_tagc, pck, pcksize);
-            for (i = 0 ; i < 16 ; i++) file_id += wxString::Format("%02x", file_md4[i]);
+
+            for (i = 0 ; i < 16 ; ++i)
+            {
+                file_id += wxString::Format("%02x", file_md4[i]);
+            }
+
             while (file_tagc)
             {
                 //tagcounter:
                 if (pcksize) get_tag(pck, pcksize);
                 --file_tagc;
             }
+
             if (file_name.Len())
             {
                 file_type = GetFTIDbyName(file_name);
@@ -2642,9 +2688,9 @@ wxString CSearchDlg::CreateWebQuery()
         break;
     }
 #if 0
-    //CString tosearch;
+    //wxString tosearch;
     GetDlgItem(IDC_SWEB)->GetWindowText(tosearch);
-    tosearch = CString(URLEncode(tosearch) .GetData());
+    tosearch = wxString(URLEncode(tosearch) .GetData());
     tosearch.Replace("%20", "+");
     query += "&pattern=";
     query += tosearch;
