@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -33,7 +33,7 @@
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
 
-bool IsValidClientIPPort(uint32 nIP, uint16 nPort)
+bool IsValidClientIPPort(uint32_t nIP, uint16_t nPort)
 {
     // this filters most of the false data:
     return nIP != 0 &&nPort != 0 && ((nIP) != nPort)
@@ -160,7 +160,7 @@ CSearchFile::CSearchFile(char *in_data, wxUint32 nSearchID)
     m_bPreviewPossible = false;
 }
 
-CSearchFile::CSearchFile(CFile *in_data, uint32 nSearchID, uint32 nServerIP, uint16 nServerPort, LPCTSTR pszDirectory)
+CSearchFile::CSearchFile(CFile *in_data, uint32_t nSearchID, uint32_t nServerIP, uint16_t nServerPort, LPCTSTR pszDirectory)
 {
     m_nSearchID = nSearchID;
     in_data->Read( &m_abyFileHash, 16);
@@ -171,7 +171,7 @@ CSearchFile::CSearchFile(CFile *in_data, uint32 nSearchID, uint32 nServerIP, uin
         m_nClientID = 0;
         m_nClientPort = 0;
     }
-    uint32 tagcount;
+    uint32_t tagcount;
     in_data->Read( &tagcount, 4);
     for (unsigned int i = 0 ; i != tagcount ;++i)
     {
@@ -204,7 +204,7 @@ CSearchFile::CSearchFile(CFile *in_data, uint32 nSearchID, uint32 nServerIP, uin
     m_bPreviewPossible = false;
 }
 
-CSearchFile::CSearchFile(uint32 nSearchID, const uchar *pucFileHash, uint32 uFileSize, char *pszFileName, int iFileType, int iAvailability)
+CSearchFile::CSearchFile(uint32_t nSearchID, const unsigned char *pucFileHash, uint32_t uFileSize, char *pszFileName, int iFileType, int iAvailability)
 {
     m_nSearchID = nSearchID;
     md4cpy(m_abyFileHash, pucFileHash);
@@ -227,12 +227,15 @@ CSearchFile::CSearchFile(uint32 nSearchID, const uchar *pucFileHash, uint32 uFil
 CSearchFile::~CSearchFile()
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
-    safe_delete(taglist[i]);
+    {
+        delete taglist[i];
+    }
+
     taglist.RemoveAll();
     taglist.SetSize(0);
 }
 
-uint32 CSearchFile::GetIntTagValue(uint8 tagname)
+uint32_t CSearchFile::GetIntTagValue(uint8_t tagname)
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
     {
@@ -242,7 +245,7 @@ uint32 CSearchFile::GetIntTagValue(uint8 tagname)
     return 0;
 }
 
-char *CSearchFile::GetStrTagValue(uint8 tagname)
+char *CSearchFile::GetStrTagValue(uint8_t tagname)
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
     {
@@ -252,7 +255,7 @@ char *CSearchFile::GetStrTagValue(uint8 tagname)
     return 0;
 }
 
-uint32 CSearchFile::AddSources(uint32 count)
+uint32_t CSearchFile::AddSources(uint32_t count)
 {
     for (int i = 0 ; i != taglist.GetSize() ; i++)
     {
@@ -265,7 +268,7 @@ uint32 CSearchFile::AddSources(uint32 count)
     return 0;
 }
 
-uint32 CSearchFile::GetSourceCount()
+uint32_t CSearchFile::GetSourceCount()
 {
     return GetIntTagValue(FT_SOURCES);
 }
