@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -42,7 +42,7 @@
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <arpa/inet.h>                      // Needed for sockaddr_in
 
@@ -136,7 +136,7 @@ void CServerSocket::OnConnect(int nErrorCode)
             {
                 struct sockaddr_in sockAddr;
                 memset( &sockAddr, 0, sizeof(sockAddr));
-                uint32 nSockAddrLen = sizeof(sockAddr);
+                uint32_t nSockAddrLen = sizeof(sockAddr);
                 wxIPV4address tmpaddr;
                 GetPeer(tmpaddr);
                 sockAddr.sin_addr.s_addr = GAddress_INET_GetHostAddress(tmpaddr.GetAddress());
@@ -151,14 +151,24 @@ void CServerSocket::OnConnect(int nErrorCode)
             // hmm?? argument list too big
             m_bIsDeleting = true;
             SetConnectionState(CS_SERVERDEAD);
-            serverconnect->DestroySocket(this);
+
+            if (serverconnect)
+            {
+                serverconnect->DestroySocket(this);
+            }
+
             break;
         }
     default:
         {
             m_bIsDeleting = true;
             SetConnectionState(CS_FATALERROR);
-            serverconnect->DestroySocket(this);
+
+
+            if (serverconnect)
+            {
+                serverconnect->DestroySocket(this);
+            }
             break;
         }
     }
@@ -170,7 +180,7 @@ void CServerSocket::OnInput(int nErrorCode)
 #if defined(__DEBUG__)
     //printf("CServerSocket::OnInput errno=%ld nErrorCode=%ld\n", errno, nErrorCode);
 #endif
-    if (connectionstate != CS_CONNECTED && !this->serverconnect->IsConnecting())
+    if (connectionstate != CS_CONNECTED && this->serverconnect && !this->serverconnect->IsConnecting())
     {
         serverconnect->DestroySocket(this);
     }
@@ -180,7 +190,7 @@ void CServerSocket::OnInput(int nErrorCode)
     }
 }
 
-bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
+bool CServerSocket::ProcessPacket(char *packet, int32_t size, int8_t opcode)
 {
 //printf("====> CServerSocket::ProcessPacket opcode=0x%02x size=%u\n",opcode,size);
     CServer *update;
@@ -196,18 +206,18 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
                 char *buffer = new char[size - 1];
                 memcpy(buffer, &packet[2], size - 2);
                 buffer[size - 2] = 0;
-                CString message(buffer);
+                wxString message(buffer);
                 if (message.Find("[emDynIP: ") != ( - 1) &&message.Find("]") != ( - 1) &&message.Find("[emDynIP: ") < message.Find("]"))
                 {
-                    CString dynip = message.Mid(message.Find("[emDynIP: ") + 10, message.Find("]") - (message.Find("[emDynIP: ") + 10));
+                    wxString dynip = message.Mid(message.Find("[emDynIP: ") + 10, message.Find("]") - (message.Find("[emDynIP: ") + 10));
                     dynip.Trim(" ");
-                    if (dynip.GetLength() &&dynip.GetLength() < 51)
+                    if (dynip.empty() == false && dynip.length() < 51)
                     {
-                        CServer *eserver = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
+                        CServer* eserver = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
                         if (eserver)
                         {
-                            eserver->SetDynIP((char *) dynip.GetBuffer());
-                            cur_server->SetDynIP((char *) dynip.GetBuffer());
+                            eserver->SetDynIP((char *)dynip.c_str());
+                            cur_server->SetDynIP((char *)dynip.c_str());
                             theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(eserver);
                         }
                     }
@@ -224,12 +234,12 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
 #endif
             if (size >= sizeof(LoginAnswer_Struct))
             {
-                static uint8 state = 0;
+                static uint8_t state = 0;
                 if (cur_server)
                 {
                     if (size >= 8)
                     {
-                        cur_server->SetTCPFlags(*((uint32*)(packet + 4)));
+                        cur_server->SetTCPFlags(*((uint32_t*)(packet + 4)));
                     }
                     else
                     {
@@ -271,7 +281,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
                     }
                 }
                 // Added by sivka [Tarod/sivka -auto reconnect on LowID]
-                if ((la->clientid < 16777216) &&
+                if ((la->clientid < 16777216) && serverconnect &&
                 //theApp.glob_prefs->ReconnectLowID() &&
                 (serverconnect->GetLowIDTries() < 3))
                 {
@@ -318,7 +328,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
             //printf("CServerSocket::ProcessPacket OP_FOUNDSOURCES %02x size=%ld\n", opcode, size);
 #endif
             CMemFile *sources = new CMemFile((BYTE *) packet, size);
-            uchar fileid[16];
+            unsigned char fileid[16];
             sources->Read(fileid, 16);
             if (CPartFile *file = theApp.downloadqueue->GetFileByID(fileid))
             file->AddSources(sources, cur_server->GetIP(), cur_server->GetPort());
@@ -333,9 +343,9 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
             // FIXME some statuspackets have a different size->why? structur?
             if (size > 7)
             {
-                uint32 cur_user;
+                uint32_t cur_user;
                 memcpy( &cur_user, packet, 4);
-                uint32 cur_files;
+                uint32_t cur_files;
                 memcpy( &cur_files, packet + 4, 4);
                 update = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
                 if (update)
@@ -358,7 +368,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
             {
                 char *buffer = new char[size - 29];
                 CServer *update = theApp.serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
-                uint16 num, num2;
+                uint16_t num, num2;
                 // 1st 30 char contain only server address & fillers:
                 memcpy(buffer, &packet[30], size - 30);
                 // length of server_name:
@@ -396,12 +406,12 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
                 CSafeMemFile *servers = new CSafeMemFile((BYTE *) packet, size);
                 unsigned char count;
                 // (servercount*(4bytes ip + 2bytes port) + 1byte servercount):
-                if ((1 != servers->Read( &count, 1)) || ((int32)(count *6 + 1) > size))
+                if ((1 != servers->Read( &count, 1)) || ((int32_t)(count *6 + 1) > size))
                 count = 0;
                 int addcount = 0;
                 while (count)
                 {
-                    uint32 ip;
+                    uint32_t ip;
                     unsigned short port;
                     if (4 != servers->Read( &ip, 4))
                     break;
@@ -431,9 +441,9 @@ bool CServerSocket::ProcessPacket(char *packet, int32 size, int8 opcode)
 #endif
             if (size == 6)
             {
-                uint32 dwIP;
+                uint32_t dwIP;
                 memcpy( &dwIP, packet, 4);
-                uint16 nPort;
+                uint16_t nPort;
                 memcpy( &nPort, packet + 4, 2);
                 CUpDownClient *client = theApp.clientlist->FindClientByIP(dwIP, nPort);
                 if (client)
@@ -469,6 +479,9 @@ void CServerSocket::ConnectToServer(CServer *server)
     wxIPV4address addr;
     addr.Hostname(server->GetAddress());
     addr.Service(server->GetPort());
+
+    SetConnectionState(CS_CONNECTING);
+
     if (!this->Connect(addr, FALSE))
     {
         //this->GetLastError();:
@@ -481,7 +494,6 @@ void CServerSocket::ConnectToServer(CServer *server)
         }
     }
     info = server->GetListName();
-    SetConnectionState(CS_CONNECTING);
 }
 
 void CServerSocket::OnLost(int nErrorCode)
@@ -496,7 +508,7 @@ void CServerSocket::PacketReceived(Packet *packet)
 {
     if (packet->prot == OP_PACKEDPROT)
     {
-        uint32 uComprSize = packet->size;
+        uint32_t uComprSize = packet->size;
         if (!packet->UnPackPacket(260000))
         {
             theApp.downloadqueue->AddDownDataOverheadServer(packet->size);
@@ -530,10 +542,14 @@ void CServerSocket::OnClose(int nErrorCode)
     {
         SetConnectionState(CS_NOTCONNECTED);
     }
-    serverconnect->DestroySocket(this);
+
+    if (serverconnect)
+    {
+        serverconnect->DestroySocket(this);
+    }
 }
 
-void CServerSocket::SetConnectionState(sint8 newstate)
+void CServerSocket::SetConnectionState(int8_t newstate)
 {
     connectionstate = newstate;
     if (newstate < 1)
