@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -24,20 +24,19 @@
 #ifndef SERVERSOCKET_H
 #define SERVERSOCKET_H
 
-#include "wintypes.h"
-#include "types.h"
-#include "sockets.h"
-#include "server.h"
-#include "EMSocket.h"
+#include "EMSocket.h"                       // CEMSocket - audited 5 Nov 2004
+
+#include <stdint.h>                         // uint32_t
+
+class CPreferences;
+class CServer;
+class Packet;
+class wxEvtHandler;
 
 #ifndef ID_SOKETTI
 #define ID_SOKETTI 7772
 #endif
 
-class CPreferences;
-class Packet;
-class wxEvtHandler;
-
 class CServerSocket : public CEMSocket
 {
   DECLARE_DYNAMIC_CLASS(CServerSocket)
@@ -49,8 +48,8 @@ public:
 	~CServerSocket();
 
 	void	ConnectToServer(CServer* server);
-	sint8	GetConnectionState()	{return connectionstate;} 
-	CString info;
+	int8_t	GetConnectionState()	{return connectionstate;} 
+    wxString info;
 
  public:
 	void	OnConnect(int nErrorCode);
@@ -60,14 +59,14 @@ public:
 	void	PacketReceived(Packet* packet);
 
 private:
-	bool	ProcessPacket(char* packet, int32 size,int8 opcode);
-	void	SetConnectionState(sint8 newstate);
+	bool	ProcessPacket(char* packet, int32_t size,int8_t opcode);
+	void	SetConnectionState(int8_t newstate);
 	CServerConnect*	serverconnect; 
-	sint8	connectionstate;
+	int8_t	connectionstate;
 	CServer*	cur_server;
 	bool	headercomplete;
-	int32	sizetoget;
-	int32	sizereceived;
+	int32_t	sizetoget;
+	int32_t	sizereceived;
 	char*	rbuffer;
 	bool	m_bIsDeleting;//true: socket is already in deletion phase, don't destroy it in ::StopConnectionTry
     wxEvtHandler* m_event_handler;
