@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -35,20 +35,26 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
-#include "packets.h"                        // Packet
-#include "SharedFileList.h"                 // Needed for this Interface's Prototype
-#include "xmule.h"                          // Needed for theApp
-#include "KnownFileList.h"                  // Needed for CKnownFile::FindKnownFile
-#include "SharedFilesCtrl.h"                // Needed for CSharedFileList::ShowFile
-#	include "AddFileThread.h"
+#include "SharedFileList.h"                 // Needed for Module's Prototype(s)
+
+#include "AddFileThread.h"                  // Needed for CAddFileThread - audited 4 Nov 2004
+#include "CMemFile.h"                       // CMemFile - audited 5 Nov 2004
 #	include "DownloadQueue.h"
+#include "KnownFileList.h"                  // Needed for CKnownFile::FindKnownFile
 #	include "muuli_wdr.h"
+#include "otherfunctions.h"                 // Needed for GetResString - audited 5 Nov 2004
+#include "packets.h"                        // Packet
+#include "PartFile.h"                       // Needed for PR_NORMAL - audited 5 Nov 2004
 #include "Preferences.h"                    // CPreferences::GetCatCount
+#include "server.h"                         // Needed for CServer - audited 5 Nov 2004
+#include "SharedFilesCtrl.h"                // Needed for CSharedFileList::ShowFile
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
 #	include "UploadQueue.h"
+#include "xmule.h"                          // Needed for theApp
 #	include "xmuleDlg.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <wx/msgdlg.h>                      // Needed for wxMessageBox
 #include <time.h>
@@ -117,7 +123,7 @@ void CSharedFileList::FindSharedFiles()
     {
         AddFilesFromDirectory((char *) app_prefs->shareddir_list.Item(ii) .GetData());
     }
-    uint32 newFiles = CAddFileThread::GetCount();
+    uint32_t newFiles = CAddFileThread::GetCount();
     if (!newFiles)
     {
         theApp.xmuledlg->AddLogLine(false, GetResString(IDS_SHAREDFOUND), m_Files_map.size());
@@ -128,30 +134,33 @@ void CSharedFileList::FindSharedFiles()
     }
 }
 
-void CSharedFileList::AddFilesFromDirectory(char *directory)
+void CSharedFileList::AddFilesFromDirectory(const wxString& directory)
 {
-    char *searchpath = new char[strlen(directory) + 3];
+    wxString searchpath = directory;
+    
     // Kry - Add slash only if it's not already in string to avoid double-slash
-    if (directory[strlen(directory) - 1] != '/')
+    if (directory[directory.length() - 1] != wxT('/'))
     {
-        sprintf(searchpath, "%s/*", directory);
+        searchpath += wxT("/*");
     }
     else
     {
-        sprintf(searchpath, "%s*", directory);
+        searchpath += wxT("*");
     }
-    wxString fname =::wxFindFirstFile(searchpath, wxFILE);
-    delete[] searchpath;
-    if (fname.IsEmpty())
+
+    wxString fname = wxFindFirstFile(searchpath, wxFILE);
+
+    if (fname.IsEmpty() == true)
     {
         return;
     }
-    while (!fname.IsEmpty())
+
+    while (fname.IsEmpty() == false)
     {
         wxFileName fName(fname);
         wxDateTime accTime, modTime, crtTime;
         fName.GetTimes( &accTime, &modTime, &crtTime);
-        uint32 fdate = modTime.GetTicks();
+        uint32_t fdate = modTime.GetTicks();
         int koko;
         struct stat sbf;
         stat(fname.GetData(), &sbf);
@@ -179,7 +188,7 @@ void CSharedFileList::AddFilesFromDirectory(char *directory)
             //not in knownfilelist - start adding thread to hash file
             CAddFileThread::AddFile(directory, fName.GetFullName() .GetData());
         }
-        fname =::wxFindNextFile();
+        fname = wxFindNextFile();
     }
 }
 
@@ -211,7 +220,7 @@ void CSharedFileList::SafeAddKFile(CKnownFile *toadd, bool bOnlyAdd)
         return;
     }
     CMemFile *files = new CMemFile(100);
-    uint32 filecount = 1;
+    uint32_t filecount = 1;
     files->Write( &filecount, 4);
     CreateOfferedFilePacket(toadd, files);
     Packet *packet = new Packet(files);
@@ -239,6 +248,7 @@ void CSharedFileList::RemoveFile(CKnownFile *toremove)
 {
     output->RemoveFile(toremove);
     m_Files_map.erase(CCKey(toremove->GetFileHash()));
+    delete toremove;
 }
 
 #define GetDlgItem(X) (wxStaticCast(wxWindow::FindWindowById((X)),wxButton))
@@ -271,7 +281,7 @@ void CSharedFileList::SendListToServer()
     if (m_Files_map.empty() || !server->IsConnected())
     return;
     CMemFile *files = new CMemFile();
-    uint32 filecount = m_Files_map.size();
+    uint32_t filecount = m_Files_map.size();
     files->Write( &filecount, 4);
     for (CKnownFileMap::iterator pos = m_Files_map.begin() ;
     pos != m_Files_map.end() ; pos++)
@@ -327,9 +337,9 @@ void CSharedFileList::CreateOfferedFilePacket(CKnownFile *cur_file, CMemFile *fi
     //TODO add tags for documents mp3 etc
 }
 
-uint64 CSharedFileList::GetDatasize()
+uint64_t CSharedFileList::GetDatasize()
 {
-    uint64 fsize;
+    uint64_t fsize;
     fsize = 0;
     for (CKnownFileMap::iterator pos = m_Files_map.begin() ;
     pos != m_Files_map.end() ; pos++)
@@ -339,7 +349,7 @@ uint64 CSharedFileList::GetDatasize()
     return fsize;
 }
 
-CKnownFile *CSharedFileList::GetFileByID(uchar *filehash)
+CKnownFile *CSharedFileList::GetFileByID(unsigned char *filehash)
 {
     CCKey tkey(filehash);
     if (m_Files_map.find(tkey) != m_Files_map.end())
@@ -348,7 +358,7 @@ CKnownFile *CSharedFileList::GetFileByID(uchar *filehash)
     return 0;
 }
 
-short CSharedFileList::GetFilePriorityByID(uchar *filehash)
+short CSharedFileList::GetFilePriorityByID(unsigned char *filehash)
 {
     CKnownFile *tocheck = GetFileByID(filehash);
     if (tocheck)
