@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -25,6 +25,7 @@
 #	include "CommentDialog.h"
 #	include "muuli_wdr.h"
 #	include "otherfunctions.h"
+#include "PartFile.h"                       // Needed for PR_NORMAL - audited 5 Nov 2004
 #include "Preferences.h"                    // CPreferences::List Settings
 #	include "SharedFilesCtrl.h"
 #	include "SharedFilesWnd.h"
@@ -32,7 +33,7 @@
 #	include "xmuleDlg.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <wx/msgdlg.h>                      // Needed for wxMessageBox
 #include <wx/stattext.h>                    // wxStaticText
@@ -182,7 +183,7 @@ void CSharedFilesCtrl::Localize()
     CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
     HDITEM hdi;
     hdi.mask = HDI_TEXT;
-    CString strRes;
+    wxString strRes;
     strRes = GetResString(IDS_DL_FILENAME);
     hdi.pszText = strRes.GetBuffer();
     pHeaderCtrl->SetItem(0, &hdi);
@@ -240,9 +241,9 @@ void CSharedFilesCtrl::RemoveFile(CKnownFile *toRemove)
     ShowFilesCount();
 }
 
-void CSharedFilesCtrl::UpdateFile(CKnownFile *file, uint32 itemnr)
+void CSharedFilesCtrl::UpdateFile(CKnownFile *file, uint32_t itemnr)
 {
-    CString buffer;
+    wxString buffer;
     SetItemData(itemnr, (long) file);
     SetItem(itemnr, 1, CastItoXBytes(file->GetFileSize()));
     // added by InterCeptor (show filetype) 11.11.02:
@@ -309,14 +310,14 @@ void CSharedFilesCtrl::UpdateFile(CKnownFile *file, uint32 itemnr)
     SetItemText(itemnr,4,"Public Shared");*/
     SetItem(itemnr, 4, GetResString(IDS_FSTATUS_PUBLIC));
     //	buffer[0] = 0;
-    //	for (uint16 i = 0;i != 16;i++) // hmm I wonder if there is a standard function for this
+    //	for (uint16_t i = 0;i != 16;i++) // hmm I wonder if there is a standard function for this
     //		sprintf(buffer,"%s%02X",buffer,file->GetFileHash()[i]);
     SetItem(itemnr, 5, EncodeBase16(file->GetFileHash(), 16));
-    buffer.Format("%u (%u)", file->statistic.GetRequests(), file->statistic.GetAllTimeRequests());
+    buffer.Printf("%u (%u)", file->statistic.GetRequests(), file->statistic.GetAllTimeRequests());
     SetItem(itemnr, 6, buffer);
-    buffer.Format("%u (%u)", file->statistic.GetAccepts(), file->statistic.GetAllTimeAccepts());
+    buffer.Printf("%u (%u)", file->statistic.GetAccepts(), file->statistic.GetAllTimeAccepts());
     SetItem(itemnr, 7, buffer);
-    buffer.Format("%s (%s)", CastItoXBytes(file->statistic.GetTransfered()) .GetData(), CastItoXBytes(file->statistic.GetAllTimeTransfered()) .GetData());
+    buffer.Printf("%s (%s)", CastItoXBytes(file->statistic.GetTransfered()) .GetData(), CastItoXBytes(file->statistic.GetAllTimeTransfered()) .GetData());
     SetItem(itemnr, 8, buffer);
 #if 0
     char buffer[50];
@@ -345,7 +346,7 @@ void CSharedFilesCtrl::UpdateFile(CKnownFile *file, uint32 itemnr)
     SetItem(itemnr, 4, GetResString(IDS_FSTATUS_PUBLIC));
     buffer[0] = 0;
     // hmm I wonder if there is a standard function for this:
-    for (uint16 i = 0 ; i != 16 ; i++)
+    for (uint16_t i = 0 ; i != 16 ; i++)
     sprintf(buffer, "%s%02X", buffer, file->GetFileHash() [i]);
     SetItem(itemnr, 5, buffer);
     sprintf(buffer, "%u (%u)", file->statistic.GetRequests(), file->statistic.GetAllTimeRequests());
@@ -364,7 +365,7 @@ void CSharedFilesCtrl::ShowFile(CKnownFile *file)
     ShowFile(file, GetItemCount());
 }
 
-void CSharedFilesCtrl::ShowFile(CKnownFile *file, uint32 itemnr)
+void CSharedFilesCtrl::ShowFile(CKnownFile *file, uint32_t itemnr)
 {
     //InsertItem(LVIF_TEXT|LVIF_PARAM,itemnr,file->GetFileName(),0,0,0,(LPARAM)file);
     int newitem = InsertItem(itemnr, file->GetFileName());
@@ -394,7 +395,7 @@ void CSharedFilesCtrl::OnContextMenu(CWnd *pWnd, CPoint point)
 
 #endif
 
-//BOOL CSharedFilesCtrl::OnCommand(WPARAM wParam, LPARAM lParam)
+//bool CSharedFilesCtrl::OnCommand(WPARAM wParam, LPARAM lParam)
 bool CSharedFilesCtrl::ProcessEvent(wxEvent &evt)
 {
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
@@ -678,10 +679,10 @@ int CSharedFilesCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
         return item1->statistic.GetTransfered() == item2->statistic.GetTransfered() ?0: (item2->statistic.GetTransfered() > item1->statistic.GetTransfered() ?1: - 1);
         //folder asc:
     case 10:
-        return strcasecmp((CString) item1->GetPath(), (CString) item2->GetPath());
+        return strcasecmp((wxString) item1->GetPath(), (wxString) item2->GetPath());
         //folder desc:
     case 30:
-        return strcasecmp((CString) item2->GetPath(), (CString) item1->GetPath());
+        return strcasecmp((wxString) item2->GetPath(), (wxString) item1->GetPath());
         //all requests asc:
     case 106:
         return item1->statistic.GetAllTimeRequests() - item2->statistic.GetAllTimeRequests();
@@ -710,7 +711,7 @@ void CSharedFilesCtrl::UpdateItem(CKnownFile *toupdate)
     //LVFINDINFO find;
     //find.flags = LVFI_PARAM;
     //find.lParam = (LPARAM)toupdate;
-    sint16 result = FindItem( - 1, (long) toupdate);
+    int16_t result = FindItem( - 1, (long) toupdate);
     if (result != - 1)
     {
         UpdateFile(toupdate, result);
