@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -48,8 +48,8 @@ public:
 
 protected:
 	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-	//virtual BOOL OnInitDialog();
-	//virtual BOOL	PreTranslateMessage(MSG* pMsg);
+	//virtual bool OnInitDialog();
+	//virtual bool	PreTranslateMessage(MSG* pMsg);
 	//DECLARE_MESSAGE_MAP()
 	DECLARE_EVENT_TABLE()
 
@@ -69,7 +69,7 @@ private:
 	wxGauge* pop_bartrans;
 
 	wxFont bold;
-	uchar shownFileHash[16];
+	unsigned char shownFileHash[16];
 	wxStaticBitmap m_ctrlStatisticsFrm;
 };
 #endif
