@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -67,7 +67,7 @@ public:
 // Attributes
 public:
 protected:
-	BOOL		m_bIsPressed;
+	bool		m_bIsPressed;
 	int			m_nType;
 	int			m_nX, m_nY;
 	int			m_nMin, m_nMax;
@@ -103,7 +103,7 @@ protected:
 	//{{AFX_MSG(CSplitterControl)
 	afx_msg void	OnPaint();
 	afx_msg void	OnMouseMove(UINT nFlags, CPoint point);
-	afx_msg BOOL	OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
+	afx_msg bool	OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
 	afx_msg void	OnLButtonDown(UINT nFlags, CPoint point);
 	afx_msg void	OnLButtonUp(UINT nFlags, CPoint point);
 	//}}AFX_MSG
