@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -25,14 +25,18 @@
 #	include "ClientList.h"
 #	include "ColorFrameCtrl.h"
 #	include "DownloadQueue.h"
+#include "ListenSocket.h"                   // CListenSocket - audited 5 Nov 2004
 #	include "muuli_wdr.h"
 #include "Preferences.h"                    // CPreferences::GetStatsColor
+#include "ServerList.h"                     // Need for CServerList - audited 5 Nov 2004
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
 #	include "StatisticsDlg.h"
 #	include "UploadQueue.h"
 #	include "xmule.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <map>                              // std::map
 #include <wx/settings.h>
@@ -282,7 +286,7 @@ void CStatisticsDlg::SetupLegend(int ResIdx, int ElmtIdx, int legendNr)
 void CStatisticsDlg::SetCurrentRate(float uploadrate, float downloadrate)
 {
     // Update scaling of the active connections graph
-    static uint32 savedMaxConns;
+    static uint32_t savedMaxConns;
     if (savedMaxConns != theApp.dynprefs->Get<long>("max-connections"))
     {
         savedMaxConns = theApp.dynprefs->Get<long>("max-connections");
@@ -361,7 +365,7 @@ float CStatisticsDlg::GetMaxConperFiveModifier()
     float SpikeSize = theApp.listensocket->GetOpenSockets() - averageconnections;
     if (SpikeSize < 1)
     return 1;
-    float SpikeTolerance = 25 * (float) theApp.glob_prefs->GetMaxConperFive() / (float) 10;
+    float SpikeTolerance = 25.0 * static_cast<float>(theApp.dynprefs->Get<long>("max-per-5")) / 10.0;
     if (SpikeSize > SpikeTolerance)
     return 0;
     float Modifier = (1 - (SpikeSize/SpikeTolerance));
@@ -381,115 +385,115 @@ void CStatisticsDlg::RecordRate()
 
 void CStatisticsDlg::ShowStatistics()
 {
-    CString cbuffer;
-    CString cbuffer2;
+    wxString cbuffer;
+    wxString cbuffer2;
     bool resize;
     DWORD running;
     int myStats[11];
     float DownAvgRate;
     resize = false;
     theApp.downloadqueue->GetDownloadStats(myStats);
-    uint64 DownOHTotal = theApp.downloadqueue->GetDownDataOverheadFileRequest() + theApp.downloadqueue->GetDownDataOverheadSourceExchange() + theApp.downloadqueue->GetDownDataOverheadServer() + theApp.downloadqueue->GetDownDataOverheadOther();
-    uint64 DownOHTotalPackets = theApp.downloadqueue->GetDownDataOverheadFileRequestPackets() + theApp.downloadqueue->GetDownDataOverheadSourceExchangePackets() + theApp.downloadqueue->GetDownDataOverheadServerPackets() + theApp.downloadqueue->GetDownDataOverheadOtherPackets();
-    cbuffer.Format("Uptime: ");
+    uint64_t DownOHTotal = theApp.downloadqueue->GetDownDataOverheadFileRequest() + theApp.downloadqueue->GetDownDataOverheadSourceExchange() + theApp.downloadqueue->GetDownDataOverheadServer() + theApp.downloadqueue->GetDownDataOverheadOther();
+    uint64_t DownOHTotalPackets = theApp.downloadqueue->GetDownDataOverheadFileRequestPackets() + theApp.downloadqueue->GetDownDataOverheadSourceExchangePackets() + theApp.downloadqueue->GetDownDataOverheadServerPackets() + theApp.downloadqueue->GetDownDataOverheadOtherPackets();
+    cbuffer.Printf("Uptime: ");
     stattree->SetItemText(h_uptime, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_DDATA), CastItoXBytes(theApp.stat_sessionReceivedBytes) .GetData(), CastItoXBytes(theApp.stat_sessionReceivedBytes + theApp.glob_prefs->GetTotalDownloaded()) .GetData());
+    cbuffer.Printf(GetResString(IDS_STATS_DDATA), CastItoXBytes(theApp.stat_sessionReceivedBytes) .GetData(), CastItoXBytes(theApp.stat_sessionReceivedBytes + theApp.glob_prefs->GetTotalDownloaded()) .GetData());
     stattree->SetItemText(down1, cbuffer);
-    cbuffer.Format(GetResString(IDS_TOVERHEAD), CastItoXBytes(DownOHTotal) .GetData(), CastItoIShort(DownOHTotalPackets) .GetData());
+    cbuffer.Printf(GetResString(IDS_TOVERHEAD), CastItoXBytes(DownOHTotal) .GetData(), CastItoIShort(DownOHTotalPackets) .GetData());
     stattree->SetItemText(down2, cbuffer);
-    cbuffer.Format(GetResString(IDS_FROVERHEAD), CastItoXBytes(theApp.downloadqueue->GetDownDataOverheadFileRequest()) .GetData(), CastItoIShort(theApp.downloadqueue->GetDownDataOverheadFileRequestPackets()) .GetData());
+    cbuffer.Printf(GetResString(IDS_FROVERHEAD), CastItoXBytes(theApp.downloadqueue->GetDownDataOverheadFileRequest()) .GetData(), CastItoIShort(theApp.downloadqueue->GetDownDataOverheadFileRequestPackets()) .GetData());
     stattree->SetItemText(down3, cbuffer);
-    cbuffer.Format(GetResString(IDS_SSOVERHEAD), CastItoXBytes(theApp.downloadqueue->GetDownDataOverheadSourceExchange()) .GetData(), CastItoIShort(theApp.downloadqueue->GetDownDataOverheadSourceExchangePackets()) .GetData());
+    cbuffer.Printf(GetResString(IDS_SSOVERHEAD), CastItoXBytes(theApp.downloadqueue->GetDownDataOverheadSourceExchange()) .GetData(), CastItoIShort(theApp.downloadqueue->GetDownDataOverheadSourceExchangePackets()) .GetData());
     stattree->SetItemText(down4, cbuffer);
-    cbuffer.Format(GetResString(IDS_SOVERHEAD), CastItoXBytes(theApp.downloadqueue->GetDownDataOverheadServer()) .GetData(), CastItoIShort(theApp.downloadqueue->GetDownDataOverheadServerPackets()) .GetData());
+    cbuffer.Printf(GetResString(IDS_SOVERHEAD), CastItoXBytes(theApp.downloadqueue->GetDownDataOverheadServer()) .GetData(), CastItoIShort(theApp.downloadqueue->GetDownDataOverheadServerPackets()) .GetData());
     stattree->SetItemText(down5, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_FOUNDSRC), myStats[0]);
+    cbuffer.Printf(GetResString(IDS_STATS_FOUNDSRC), myStats[0]);
     stattree->SetItemText(down6, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_ACTDL), myStats[1]);
+    cbuffer.Printf(GetResString(IDS_STATS_ACTDL), myStats[1]);
     stattree->SetItemText(down7, cbuffer);
-    uint64 UpOHTotal = theApp.uploadqueue->GetUpDataOverheadFileRequest() + theApp.uploadqueue->GetUpDataOverheadSourceExchange() + theApp.uploadqueue->GetUpDataOverheadServer() + theApp.uploadqueue->GetUpDataOverheadOther();
-    uint64 UpOHTotalPackets = theApp.uploadqueue->GetUpDataOverheadFileRequestPackets() + theApp.uploadqueue->GetUpDataOverheadSourceExchangePackets() + theApp.uploadqueue->GetUpDataOverheadServerPackets() + theApp.uploadqueue->GetUpDataOverheadOtherPackets();
-    cbuffer.Format(GetResString(IDS_STATS_UDATA), CastItoXBytes(theApp.stat_sessionSentBytes) .GetData(), CastItoXBytes(theApp.stat_sessionSentBytes + theApp.glob_prefs->GetTotalUploaded()) .GetData());
+    uint64_t UpOHTotal = theApp.uploadqueue->GetUpDataOverheadFileRequest() + theApp.uploadqueue->GetUpDataOverheadSourceExchange() + theApp.uploadqueue->GetUpDataOverheadServer() + theApp.uploadqueue->GetUpDataOverheadOther();
+    uint64_t UpOHTotalPackets = theApp.uploadqueue->GetUpDataOverheadFileRequestPackets() + theApp.uploadqueue->GetUpDataOverheadSourceExchangePackets() + theApp.uploadqueue->GetUpDataOverheadServerPackets() + theApp.uploadqueue->GetUpDataOverheadOtherPackets();
+    cbuffer.Printf(GetResString(IDS_STATS_UDATA), CastItoXBytes(theApp.stat_sessionSentBytes) .GetData(), CastItoXBytes(theApp.stat_sessionSentBytes + theApp.glob_prefs->GetTotalUploaded()) .GetData());
     stattree->SetItemText(up1, cbuffer);
-    cbuffer.Format(GetResString(IDS_TOVERHEAD), CastItoXBytes(UpOHTotal) .GetData(), CastItoIShort(UpOHTotalPackets) .GetData());
+    cbuffer.Printf(GetResString(IDS_TOVERHEAD), CastItoXBytes(UpOHTotal) .GetData(), CastItoIShort(UpOHTotalPackets) .GetData());
     stattree->SetItemText(up2, cbuffer);
-    cbuffer.Format(GetResString(IDS_FROVERHEAD), CastItoXBytes(theApp.uploadqueue->GetUpDataOverheadFileRequest()) .GetData(), CastItoIShort(theApp.uploadqueue->GetUpDataOverheadFileRequestPackets()) .GetData());
+    cbuffer.Printf(GetResString(IDS_FROVERHEAD), CastItoXBytes(theApp.uploadqueue->GetUpDataOverheadFileRequest()) .GetData(), CastItoIShort(theApp.uploadqueue->GetUpDataOverheadFileRequestPackets()) .GetData());
     stattree->SetItemText(up3, cbuffer);
-    cbuffer.Format(GetResString(IDS_SSOVERHEAD), CastItoXBytes(theApp.uploadqueue->GetUpDataOverheadSourceExchange()) .GetData(), CastItoIShort(theApp.uploadqueue->GetUpDataOverheadSourceExchangePackets()) .GetData());
+    cbuffer.Printf(GetResString(IDS_SSOVERHEAD), CastItoXBytes(theApp.uploadqueue->GetUpDataOverheadSourceExchange()) .GetData(), CastItoIShort(theApp.uploadqueue->GetUpDataOverheadSourceExchangePackets()) .GetData());
     stattree->SetItemText(up4, cbuffer);
-    cbuffer.Format(GetResString(IDS_SOVERHEAD), CastItoXBytes(theApp.uploadqueue->GetUpDataOverheadServer()) .GetData(), CastItoIShort(theApp.uploadqueue->GetUpDataOverheadServerPackets()) .GetData());
+    cbuffer.Printf(GetResString(IDS_SOVERHEAD), CastItoXBytes(theApp.uploadqueue->GetUpDataOverheadServer()) .GetData(), CastItoIShort(theApp.uploadqueue->GetUpDataOverheadServerPackets()) .GetData());
     stattree->SetItemText(up5, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_ACTUL), theApp.uploadqueue->GetUploadQueueLength());
+    cbuffer.Printf(GetResString(IDS_STATS_ACTUL), theApp.uploadqueue->GetUploadQueueLength());
     stattree->SetItemText(up6, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_WAITINGUSERS), theApp.uploadqueue->GetWaitingUserCount());
+    cbuffer.Printf(GetResString(IDS_STATS_WAITINGUSERS), theApp.uploadqueue->GetWaitingUserCount());
     stattree->SetItemText(up7, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_SUCCUPCOUNT), theApp.uploadqueue->GetSuccessfullUpCount());
+    cbuffer.Printf(GetResString(IDS_STATS_SUCCUPCOUNT), theApp.uploadqueue->GetSuccessfullUpCount());
     stattree->SetItemText(up8, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_FAILUPCOUNT), theApp.uploadqueue->GetFailedUpCount());
+    cbuffer.Printf(GetResString(IDS_STATS_FAILUPCOUNT), theApp.uploadqueue->GetFailedUpCount());
     stattree->SetItemText(up9, cbuffer);
     running = theApp.uploadqueue->GetAverageUpTime();
-    cbuffer.Format(GetResString(IDS_STATS_AVEUPTIME), CastSecondsToHM(running) .GetData());
+    cbuffer.Printf(GetResString(IDS_STATS_AVEUPTIME), CastSecondsToHM(running) .GetData());
     stattree->SetItemText(up10, cbuffer);
     if (theApp.stat_transferStarttime > 0)
     {
-        cbuffer.Format(GetResString(IDS_STATS_AVGDL), GetAvgDownloadRate(AVG_SESSION));
+        cbuffer.Printf(GetResString(IDS_STATS_AVGDL), GetAvgDownloadRate(AVG_SESSION));
         stattree->SetItemText(con1, cbuffer);
-        cbuffer.Format(GetResString(IDS_STATS_AVGUL), GetAvgUploadRate(AVG_SESSION));
+        cbuffer.Printf(GetResString(IDS_STATS_AVGUL), GetAvgUploadRate(AVG_SESSION));
         stattree->SetItemText(con2, cbuffer);
         DownAvgRate = GetAvgDownloadRate(AVG_SESSION);
         if (maxDownavg < DownAvgRate) maxDownavg = DownAvgRate;
-        cbuffer.Format(GetResString(IDS_STATS_MAXAVGDL), maxDownavg);
+        cbuffer.Printf(GetResString(IDS_STATS_MAXAVGDL), maxDownavg);
         stattree->SetItemText(con12, cbuffer);
-        cbuffer.Format(GetResString(IDS_STATS_MAXDL), maxDown);
+        cbuffer.Printf(GetResString(IDS_STATS_MAXDL), maxDown);
         stattree->SetItemText(con13, cbuffer);
     }
-    if (theApp.stat_reconnects > 0) cbuffer.Format(GetResString(IDS_STATS_RECONNECTS), theApp.stat_reconnects - 1);
-    else cbuffer.Format(GetResString(IDS_STATS_RECONNECTS), 0);
+    if (theApp.stat_reconnects > 0) cbuffer.Printf(GetResString(IDS_STATS_RECONNECTS), theApp.stat_reconnects - 1);
+    else cbuffer.Printf(GetResString(IDS_STATS_RECONNECTS), 0);
     stattree->SetItemText(con3, cbuffer);
-    if (theApp.stat_transferStarttime == 0) cbuffer.Format(GetResString(IDS_STATS_WAITTRANSF));
+    if (theApp.stat_transferStarttime == 0) cbuffer.Printf(GetResString(IDS_STATS_WAITTRANSF));
     else
     {
         running = (GetTickCount() - theApp.stat_transferStarttime) /1000;
-        cbuffer.Format(GetResString(IDS_TRANSFERTIME), CastSecondsToHM(running) .GetData());
+        cbuffer.Printf(GetResString(IDS_TRANSFERTIME), CastSecondsToHM(running) .GetData());
     }
     stattree->SetItemText(con4, cbuffer);
     if (theApp.Start_time > 0)
     {
         running = (GetTickCount() - theApp.Start_time) /1000;
-        cbuffer.Format("Uptime: %s", CastSecondsToHM(running) .GetData());
+        cbuffer.Printf("Uptime: %s", CastSecondsToHM(running) .GetData());
         stattree->SetItemText(h_uptime, cbuffer);
     }
-    if (theApp.stat_serverConnectTime == 0) cbuffer.Format(GetResString(IDS_STATS_WAITCONN));
+    if (theApp.stat_serverConnectTime == 0) cbuffer.Printf(GetResString(IDS_STATS_WAITCONN));
     else
     {
         running = (GetTickCount() - theApp.stat_serverConnectTime) /1000;
-        cbuffer.Format(GetResString(IDS_STATS_CONNECTEDSINCE), CastSecondsToHM(running) .GetData());
+        cbuffer.Printf(GetResString(IDS_STATS_CONNECTEDSINCE), CastSecondsToHM(running) .GetData());
     }
     stattree->SetItemText(con5, cbuffer);
     if (theApp.stat_sessionReceivedBytes > 0 &&theApp.stat_sessionSentBytes > 0)
     if (theApp.stat_sessionReceivedBytes < theApp.stat_sessionSentBytes)
     {
-        cbuffer.Format("%s %.2f : 1", GetResString(IDS_STATS_RATIO) .GetData(), (float) theApp.stat_sessionSentBytes/theApp.stat_sessionReceivedBytes);
+        cbuffer.Printf("%s %.2f : 1", GetResString(IDS_STATS_RATIO) .GetData(), (float) theApp.stat_sessionSentBytes/theApp.stat_sessionReceivedBytes);
         stattree->SetItemText(tran0, cbuffer);
     }
     else
     {
-        cbuffer.Format("%s 1 : %.2f", GetResString(IDS_STATS_RATIO) .GetData(), (float) theApp.stat_sessionReceivedBytes/theApp.stat_sessionSentBytes);
+        cbuffer.Printf("%s 1 : %.2f", GetResString(IDS_STATS_RATIO) .GetData(), (float) theApp.stat_sessionReceivedBytes/theApp.stat_sessionSentBytes);
         stattree->SetItemText(tran0, cbuffer);
     }
     // shared files stats
-    cbuffer.Format(GetResString(IDS_SHAREDFILESCOUNT), theApp.sharedfiles->GetCount());
+    cbuffer.Printf(GetResString(IDS_SHAREDFILESCOUNT), theApp.sharedfiles->GetCount());
     stattree->SetItemText(shar1, cbuffer);
-    uint64 allsize = theApp.sharedfiles->GetDatasize();
-    cbuffer.Format(GetResString(IDS_SF_SIZE), CastItoXBytes(allsize) .GetData());
+    uint64_t allsize = theApp.sharedfiles->GetDatasize();
+    cbuffer.Printf(GetResString(IDS_SF_SIZE), CastItoXBytes(allsize) .GetData());
     stattree->SetItemText(shar2, cbuffer);
     if (theApp.sharedfiles->GetCount() != 0)
-    cbuffer2.Format("%s", CastItoXBytes((uint64) allsize/theApp.sharedfiles->GetCount()) .GetData());
+    cbuffer2.Printf("%s", CastItoXBytes((uint64_t) allsize/theApp.sharedfiles->GetCount()) .GetData());
     else
     {
         cbuffer2 = "-";
     }
-    cbuffer.Format(GetResString(IDS_SF_AVERAGESIZE), cbuffer2.GetData());
+    cbuffer.Printf(GetResString(IDS_SF_AVERAGESIZE), cbuffer2.GetData());
     stattree->SetItemText(shar3, cbuffer);
     // get clientversion-counts
     // statsclientstatus : original idea and code by xrmb
@@ -497,42 +501,42 @@ void CStatisticsDlg::ShowStatistics()
     std::map<uint16_t, uint32_t> clientVersionEDonkeyHybrid;
     std::map<uint8_t, uint32_t> clientVersionEMule;
 
-    uint32 totalclient;
+    uint32_t totalclient;
     theApp.clientlist->GetStatistics(totalclient, myStats, &clientVersionEDonkey, &clientVersionEDonkeyHybrid, &clientVersionEMule);
     totalclient -= myStats[0];
     if (!totalclient)
     totalclient = 1;
-    cbuffer.Format(_("eMule: %i (%1.1f%%)"), myStats[2], (double) 100 *myStats[2]/totalclient);
+    cbuffer.Printf(_("eMule: %i (%1.1f%%)"), myStats[2], (double) 100 *myStats[2]/totalclient);
     stattree->SetItemText(cli1, cbuffer);
-    //	cbuffer.Format(_("LMule: %i (%1.1f%%)"),myStats[8],(double)100*myStats[8]/totalclient);stattree->SetItemText(cli10, cbuffer);
-    cbuffer.Format(_("xMule: %i (%1.1f%%)"), myStats[6], (double) 100 *myStats[6]/totalclient);
+    //	cbuffer.Printf(_("LMule: %i (%1.1f%%)"),myStats[8],(double)100*myStats[8]/totalclient);stattree->SetItemText(cli10, cbuffer);
+    cbuffer.Printf(_("xMule: %i (%1.1f%%)"), myStats[6], (double) 100 *myStats[6]/totalclient);
     stattree->SetItemText(cli8, cbuffer);
-    cbuffer.Format(_("eDonkeyHybrid: %i (%1.1f%%)"), myStats[4], (double) 100 *myStats[4]/totalclient);
+    cbuffer.Printf(_("eDonkeyHybrid: %i (%1.1f%%)"), myStats[4], (double) 100 *myStats[4]/totalclient);
     stattree->SetItemText(cli2, cbuffer);
-    cbuffer.Format(_("eDonkey: %i (%1.1f%%)"), myStats[1], (double) 100 *myStats[1]/totalclient);
+    cbuffer.Printf(_("eDonkey: %i (%1.1f%%)"), myStats[1], (double) 100 *myStats[1]/totalclient);
     stattree->SetItemText(cli3, cbuffer);
-    cbuffer.Format(_("cDonkey: %i (%1.1f%%)"), myStats[5], (double) 100 *myStats[5]/totalclient);
+    cbuffer.Printf(_("cDonkey: %i (%1.1f%%)"), myStats[5], (double) 100 *myStats[5]/totalclient);
     stattree->SetItemText(cli4, cbuffer);
-    cbuffer.Format(_("Old MLDonkey: %i (%1.1f%%)"), myStats[3], (double) 100 *myStats[3]/totalclient);
+    cbuffer.Printf(_("Old MLDonkey: %i (%1.1f%%)"), myStats[3], (double) 100 *myStats[3]/totalclient);
     stattree->SetItemText(cli5, cbuffer);
-    cbuffer.Format(_("New MLDonkey: %i (%1.1f%%)"), myStats[7], (double) 100 *myStats[7]/totalclient);
+    cbuffer.Printf(_("New MLDonkey: %i (%1.1f%%)"), myStats[7], (double) 100 *myStats[7]/totalclient);
     stattree->SetItemText(cli9, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_UNKNOWNCLIENT) .GetData(), myStats[0]);
+    cbuffer.Printf(GetResString(IDS_STATS_UNKNOWNCLIENT) .GetData(), myStats[0]);
     stattree->SetItemText(cli6, cbuffer);
-    cbuffer.Format(GetResString(IDS_STATS_FILTEREDCLIENTS) .GetData(), theApp.stat_filteredclients);
+    cbuffer.Printf(GetResString(IDS_STATS_FILTEREDCLIENTS) .GetData(), theApp.stat_filteredclients);
     stattree->SetItemText(cli7, cbuffer);
     //if (stattree->GetItemState(cli3, TVIS_EXPANDED)&&TVIS_EXPANDED == TVIS_EXPANDED ) {
     if (stattree->IsExpanded(cli3))
     {
-        uint32 totcnt = myStats[1];
+        uint32_t totcnt = myStats[1];
         //--- find top 4 eDonkey client versions ---
-        uint32 currtop = 0;
-        uint32 lasttop = 0xFFFFFFFF;
+        uint32_t currtop = 0;
+        uint32_t lasttop = 0xFFFFFFFF;
 
-        for (uint32 i = 0; i < 4; ++i)
+        for (uint32_t i = 0; i < 4; ++i)
         {
-            uint32 topver = 0;
-            uint32 topcnt = 0;
+            uint32_t topver = 0;
+            uint32_t topcnt = 0;
             double topper = 0;
 
             std::map<uint16_t, uint32_t>::const_iterator it;
@@ -566,7 +570,7 @@ void CStatisticsDlg::ShowStatistics()
 
             if (topcnt)
             {
-                cbuffer.Format("v%i: %i (%1.1f%%)", topver, topcnt, topper * 100);
+                cbuffer.Printf("v%i: %i (%1.1f%%)", topver, topcnt, topper * 100);
             }
             else
             {
@@ -579,14 +583,14 @@ void CStatisticsDlg::ShowStatistics()
     //if (stattree->GetItemState(cli2, TVIS_EXPANDED)&&TVIS_EXPANDED == TVIS_EXPANDED ) {
     if (stattree->IsExpanded(cli2))
     {
-        uint32 totcnt = myStats[4];
+        uint32_t totcnt = myStats[4];
         //--- find top 4 eDonkey Hybrid client versions ---
-        uint32 currtop = 0;
-        uint32 lasttop = 0xFFFFFFFF;
-        for (uint32 i = 0; i < 4; ++i)
+        uint32_t currtop = 0;
+        uint32_t lasttop = 0xFFFFFFFF;
+        for (uint32_t i = 0; i < 4; ++i)
         {
-            uint32 topver = 0;
-            uint32 topcnt = 0;
+            uint32_t topver = 0;
+            uint32_t topcnt = 0;
             double topper = 0;
 
             std::map<uint16_t, uint32_t>::const_iterator it;
@@ -621,7 +625,7 @@ void CStatisticsDlg::ShowStatistics()
 
             if (topcnt)
             {
-                cbuffer.Format("v%i: %i (%1.1f%%)", topver, topcnt, topper * 100);
+                cbuffer.Printf("v%i: %i (%1.1f%%)", topver, topcnt, topper * 100);
             }
             else
             {
@@ -634,15 +638,15 @@ void CStatisticsDlg::ShowStatistics()
     //if (stattree->GetItemState(cli1, TVIS_EXPANDED)&&TVIS_EXPANDED == TVIS_EXPANDED ) {
     if (stattree->IsExpanded(cli1))
     {
-        uint32 totcnt = myStats[2];
+        uint32_t totcnt = myStats[2];
         //--- find top 4 eMule client versions ---
-        uint32 currtop = 0;
-        uint32 lasttop = 0xFFFFFFFF;
+        uint32_t currtop = 0;
+        uint32_t lasttop = 0xFFFFFFFF;
 
-        for (uint32 i = 0 ; i < 4 ; i++)
+        for (uint32_t i = 0 ; i < 4 ; i++)
         {
-            uint32 topver = 0;
-            uint32 topcnt = 0;
+            uint32_t topver = 0;
+            uint32_t topcnt = 0;
             double topper = 0;
 
             std::map<uint8_t, uint32_t>::const_iterator it;
@@ -676,7 +680,7 @@ void CStatisticsDlg::ShowStatistics()
 
             if (topcnt)
             {
-                cbuffer.Format("v0.%02X: %i (%1.1f%%)", topver, topcnt, topper *100);
+                cbuffer.Printf("v0.%02X: %i (%1.1f%%)", topver, topcnt, topper *100);
             }
             else
             {
@@ -688,35 +692,35 @@ void CStatisticsDlg::ShowStatistics()
         // xrmb
     }
     // get serverstats
-    uint32 servtotal;
-    uint32 servfail;
-    uint32 servuser;
-    uint32 servfile;
-    uint32 servtuser;
-    uint32 servtfile;
+    uint32_t servtotal;
+    uint32_t servfail;
+    uint32_t servuser;
+    uint32_t servfile;
+    uint32_t servtuser;
+    uint32_t servtfile;
     float servocc;
     theApp.serverlist->GetStatus(servtotal, servfail, servuser, servfile, servtuser, servtfile, servocc);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_WORKING) .GetData(), servtotal - servfail);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_WORKING) .GetData(), servtotal - servfail);
     stattree->SetItemText(srv1, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_FAIL) .GetData(), servfail);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_FAIL) .GetData(), servfail);
     stattree->SetItemText(srv2, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_TOTAL) .GetData(), servtotal);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_TOTAL) .GetData(), servtotal);
     stattree->SetItemText(srv3, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_DELCOUNT) .GetData(), theApp.serverlist->GetDeletedServerCount());
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_DELCOUNT) .GetData(), theApp.serverlist->GetDeletedServerCount());
     stattree->SetItemText(srv4, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_WUSER) .GetData(), servuser);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_WUSER) .GetData(), servuser);
     stattree->SetItemText(srv5, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_WFILE) .GetData(), servfile);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_WFILE) .GetData(), servfile);
     stattree->SetItemText(srv6, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_USER) .GetData(), servtuser);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_USER) .GetData(), servtuser);
     stattree->SetItemText(srv7, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_FILE) .GetData(), servtfile);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_FILE) .GetData(), servtfile);
     stattree->SetItemText(srv8, cbuffer);
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_ACTIVECON) .GetData(), activeconnections);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_ACTIVECON) .GetData(), activeconnections);
     stattree->SetItemText(con6, cbuffer);
-    cbuffer.Format(GetResString(IDS_SF_SRVOCC), servocc);
+    cbuffer.Printf(GetResString(IDS_SF_SRVOCC), servocc);
     stattree->SetItemText(srv9, cbuffer);
-    uint32 m_itemp = theApp.listensocket->GetMaxConnectionReached();
+    uint32_t m_itemp = theApp.listensocket->GetMaxConnectionReached();
     if (m_itemp != m_ilastMaxConnReached)
     {
         char osDate[60];
@@ -725,25 +729,25 @@ void CStatisticsDlg::ShowStatistics()
         time_t mytime = time(NULL);
         struct tm *now = localtime( &mytime);
         strftime(osDate, sizeof(osDate) - 1, "%d.%m.%Y %H:%M:%S", now);
-        cbuffer.Format("%s: %i : %s", GetResString(IDS_SF_MAXCONLIMITREACHED) .GetData(), m_itemp, osDate);
+        cbuffer.Printf("%s: %i : %s", GetResString(IDS_SF_MAXCONLIMITREACHED) .GetData(), m_itemp, osDate);
         stattree->SetItemText(con7, cbuffer);
         m_ilastMaxConnReached = m_itemp;
     }
     else if(m_itemp == 0)
     {
-        cbuffer.Format("%s: %i", GetResString(IDS_SF_MAXCONLIMITREACHED) .GetData(), m_itemp);
+        cbuffer.Printf("%s: %i", GetResString(IDS_SF_MAXCONLIMITREACHED) .GetData(), m_itemp);
         stattree->SetItemText(con7, cbuffer);
     }
     if (theApp.serverconnect->IsConnected())
     {
-        cbuffer.Format("%s: %i", GetResString(IDS_SF_AVGCON) .GetData(), (int) averageconnections);
+        cbuffer.Printf("%s: %i", GetResString(IDS_SF_AVGCON) .GetData(), (int) averageconnections);
         stattree->SetItemText(con8, cbuffer);
     }
     else
     {
         stattree->SetItemText(con8, GetResString(IDS_STATS_WAITCONN));
     }
-    cbuffer.Format("%s: %i", GetResString(IDS_SF_PEAKCON) .GetData(), peakconnections);
+    cbuffer.Printf("%s: %i", GetResString(IDS_SF_PEAKCON) .GetData(), peakconnections);
     stattree->SetItemText(con9, cbuffer);
 }
 
@@ -759,7 +763,7 @@ float CStatisticsDlg::GetAvgDownloadRate(int averageType)
     else
     {
         if (downrateHistory.size() == 0) return 0;
-        uint64 sum;
+        uint64_t sum;
         sum = downrateHistory.front();
         if ((int) downrateHistory.size() >= (int)theApp.dynprefs->Get<long>("graph-average") * 60) sum -= downrateHistory.back();
         return (float)(sum/1024) / downrateHistory.size();
@@ -778,14 +782,14 @@ float CStatisticsDlg::GetAvgUploadRate(int averageType)
     else
     {
         if (uprateHistory.size() == 0) return 0;
-        uint64 sum = uprateHistory.front();
+        uint64_t sum = uprateHistory.front();
         if ((int) uprateHistory.size() >= (int)(theApp.dynprefs->Get<long>("graph-average") * 60)) sum -= uprateHistory.back();
         return(float)(sum/1024) /uprateHistory.size();
     }
 }
 
 #if 0
-void CStatisticsDlg::OnShowWindow(BOOL bShow, UINT nStatus)
+void CStatisticsDlg::OnShowWindow(bool bShow, UINT nStatus)
 {
 }
 
@@ -852,8 +856,8 @@ void CStatisticsDlg::Localize()
     GetDlgItem(IDC_STATIC_S0)->SetWindowText(GetResString(IDS_ST_ACTIVEC));
     GetDlgItem(IDC_STATIC_S1)->SetWindowText(GetResString(IDS_ST_ACTIVEU));
     GetDlgItem(IDC_STATIC_S3)->SetWindowText(GetResString(IDS_ST_WAITINGU));
-    CString value;
-    value.Format(" (%u mins)", theApp.glob_prefs->GetStatsAverageMinutes());
+    wxString value;
+    value.Printf(" (%u mins)", theApp.glob_prefs->GetStatsAverageMinutes());
     GetDlgItem(IDC_TIMEAVG1)->SetWindowText(GetResString(IDS_AVG) + value);
     GetDlgItem(IDC_TIMEAVG2)->SetWindowText(GetResString(IDS_AVG) + value);
 }
@@ -886,7 +890,7 @@ wxString CStatisticsDlg::ExportHTML()
 
 void CStatisticsDlg::ExportHTMLEvent(wxCommandEvent &evt)
 {
-    int8 ix;
+    int8_t ix;
     wxString temp;
     wxString text = "";
     wxTreeItemId item;
