@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright(C)2002 Tiku & Patrizio Bassi aka Hetfield <hetfield@email.it>
@@ -55,7 +55,7 @@
     #include <sys/socket.h>
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include "pixmaps/mule_Tr_grey.ico.xpm"
 
@@ -74,42 +74,52 @@ std::deque<COLORREF> m_pColors;
 #ifndef __SAFE_TRAY__
 gchar *getIP()
 {
-    gchar *ip = "Not Found";
-    wxString interface;
-    int index;
-    index = 0;
-    int sfd;
-    struct ifreq ifr;
-    struct sockaddr_in *sin = (struct sockaddr_in *) &ifr.ifr_addr;
-    memset( &ifr, 0, sizeof ifr);
-    sfd = socket(AF_INET, SOCK_STREAM, 0);
-    strcpy(ifr.ifr_name, "ppp0");
-    sin->sin_family = AF_INET;
-    if (0 == ioctl(sfd, SIOCGIFADDR, &ifr))
+    static gchar* ip = 0;
+
+    if (ip == 0)
     {
-        ip = inet_ntoa(sin->sin_addr);
-        return ip;
-    }
-    else
-    {
-        printf("Not connected at network with ppp0 direct connection\n");
-        do
+        wxString interface;
+        int index;
+        index = 0;
+        int sfd;
+        struct ifreq ifr;
+        struct sockaddr_in *sin = (struct sockaddr_in *) &ifr.ifr_addr;
+        memset( &ifr, 0, sizeof ifr);
+        sfd = socket(AF_INET, SOCK_STREAM, 0);
+        strcpy(ifr.ifr_name, "ppp0");
+        sin->sin_family = AF_INET;
+
+        if (0 == ioctl(sfd, SIOCGIFADDR, &ifr))
         {
-            interface = "eth" + wxString::Format("%d", index);
-            strcpy(ifr.ifr_name, interface);
-            sin->sin_family = AF_INET;
-            if (ioctl(sfd, SIOCGIFADDR, &ifr) == 0)
+            ip = inet_ntoa(sin->sin_addr);
+
+            return ip;
+        }
+        else
+        {
+            printf("Not connected at network with ppp0 direct connection\n");
+
+            do
             {
-                ip = inet_ntoa(sin->sin_addr);
-                index++;
+                interface << "eth" << index;
+                strcpy(ifr.ifr_name, interface);
+                sin->sin_family = AF_INET;
+
+                if (ioctl(sfd, SIOCGIFADDR, &ifr) == 0)
+                {
+                    ip = inet_ntoa(sin->sin_addr);
+                    index++;
+                }
+                else
+                {
+                    interface << "Not connected at network with " << interface;
+                    printf(interface.c_str());
+                }
             }
-            else
-            {
-                printf(wxString("Not connected at network with ") + interface);
-            }
+            while (0 == ioctl(sfd, SIOCGIFADDR, &ifr));
         }
-        while (0 == ioctl(sfd, SIOCGIFADDR, &ifr));
     }
+
     return ip;
 }
 
@@ -264,8 +274,8 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     wxString upl_speed, dl_speed;
     gchar *temp, *tempstring;
     int tempspeed;
-    uint16 max_dl_speed, max_up_speed;
-    uint16 actual_dl_speed, actual_up_speed;
+    uint16_t max_dl_speed, max_up_speed;
+    uint16_t actual_dl_speed, actual_up_speed;
     speed_check();
     actual_up_speed = theApp.dynprefs->Get<long>("limits-upload");
     actual_dl_speed = theApp.dynprefs->Get<long>("limits-download");
@@ -314,9 +324,9 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     if (theApp.glob_prefs->GetUserHash())
     {
-        CString hash;
+        wxString hash;
         hash = EncodeBase16((const unsigned char *) theApp.glob_prefs->GetUserHash(), 16);
-        info_item = gtk_menu_item_new_with_label(wxString("Hash: ") + hash.GetBuffer());
+        info_item = gtk_menu_item_new_with_label(wxString("Hash: ") + hash.c_str());
     }
     else
     {
