@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -24,6 +24,7 @@
 #else
 #	include "DownloadQueue.h"
 #include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP
+#include "PartFile.h"                       // Needed for CPartFile - audited 5 Nov 2004
 #	include "SearchDlg.h"
 #	include "SearchList.h"
 #	include "ServerList.h"
@@ -34,7 +35,7 @@
 #include "xmuleIPV4Address.h"               // xmuleIPV4Address
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences::Get
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences::Get
 
 #include <netdb.h>
 #include <pthread.h>
@@ -339,14 +340,14 @@ wxUint32 hostip, wxUint16 port)
             int iLeft;
             do
             {
-                uchar fileid[16];
+                unsigned char fileid[16];
                 data->Read(fileid, 16);
                 if (CPartFile *file = theApp.downloadqueue->GetFileByID(fileid))
                 file->AddSources(data, hostip, port - 4);
                 else
                 {
                     // skip sources for that file
-                    uint8 count;
+                    uint8_t count;
                     data->Read( &count, 1);
                     data->Seek(count * (4 + 2), wxFromStart);
                 }
@@ -354,7 +355,7 @@ wxUint32 hostip, wxUint16 port)
                 iLeft = (int)(data->GetLength() - data->GetPosition());
                 if (iLeft >= 2)
                 {
-                    uint8 protocol;
+                    uint8_t protocol;
                     data->Read( &protocol, 1);
                     iLeft--;
                     if (protocol != OP_EDONKEYPROT)
@@ -363,7 +364,7 @@ wxUint32 hostip, wxUint16 port)
                         iLeft += 1;
                         break;
                     }
-                    uint8 opcode;
+                    uint8_t opcode;
                     data->Read( &opcode, 1);
                     iLeft--;
                     if (opcode != OP_GLOBFOUNDSOURCES)
@@ -384,16 +385,16 @@ wxUint32 hostip, wxUint16 port)
             theApp.downloadqueue->AddDownDataOverheadOther(size);
             if (size < 12 || update == NULL)
             return true;
-#define get_uint32(p)	*((uint32*)(p))
-            uint32 challenge = get_uint32(packet);
+#define get_uint32(p)	*((uint32_t*)(p))
+            uint32_t challenge = get_uint32(packet);
             if (challenge != update->GetChallenge())
             return true;
-            uint32 cur_user = get_uint32(packet + 4);
-            uint32 cur_files = get_uint32(packet + 8);
-            uint32 cur_maxusers = 0;
-            uint32 cur_softfiles = 0;
-            uint32 cur_hardfiles = 0;
-            uint32 uUDPFlags = 0;
+            uint32_t cur_user = get_uint32(packet + 4);
+            uint32_t cur_files = get_uint32(packet + 8);
+            uint32_t cur_maxusers = 0;
+            uint32_t cur_softfiles = 0;
+            uint32_t cur_hardfiles = 0;
+            uint32_t uUDPFlags = 0;
             if (size >= 16)
             {
                 cur_maxusers = get_uint32(packet + 12);
@@ -466,8 +467,8 @@ bool CUDPSocket::ProcessExtPacket(unsigned char *packet, wxUint16 size, wxUint8
  case OP_UDPVERIFYUPREQ:{
  wxASSERT (size == 6);
  if (size == 6){
- uint32 checkclientip = 0;
- uint16 checkclientport = 0;
+ uint32_t checkclientip = 0;
+ uint16_t checkclientport = 0;
  memcpy(&checkclientip,packet,4);
  memcpy(&checkclientport,packet,2);
  if (theApp.clientlist->VerifyUpload(checkclientip,checkclientport)){
