@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -67,7 +67,7 @@ private:
 	bool	ProcessExtPacket(unsigned char* packet, wxUint16 size, wxUint8 opcode, wxUint32 hostip, wxUint16 port);
 	CServerConnect*	serverconnect;
 	char*	sendbuffer;
-	uint32	sendblen;
+	uint32_t	sendblen;
 	CServer* cur_server;
 	char	DnsHostBuffer[1024]; //MAXGETHOSTSTRUCT];	// dns lookup structure
 	wxIPV4address useless;
