@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,17 +22,24 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#include "ClientCredits.h"                  // CClientCredits
 #	include "ClientUDPSocket.h"
 #	include "KnownFile.h"
+#include "KnownFileList.h"                  // CKnownFileList
 #include "ListenSocket.h"                   // CClientReqSocket
 #include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP
 #	include "opcodes.h"
 #	include "otherfunctions.h"
 #	include "otherstructs.h"
 #	include "packets.h"
+#include "PartFile.h"                       // Needed for PR_VERYHIGH - audited 5 Nov 2004
+#include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
+#include "SafeFile.h"                       // CSafeMemFile - audited 5 Nov 2004
 #	include "SharedFileList.h"
+#include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
 #	include "TransferWnd.h"
 #	include "updownclient.h"
+#include "UploadListCtrl.h"                 // Needed for CUploadListCtrl - audited 5 Nov 2004
 #	include "UploadQueue.h"
 #	include "wintypes.h"
 #	include "xmule.h"
@@ -40,7 +47,7 @@
 #	include "NewSockets.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <zlib.h>
 
@@ -74,12 +81,12 @@ void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyre
         return;
     }
     float blockpixel = (float)(rect.width) / ((float)(PARTSIZE * (m_nUpPartCount)) /1024);
-    for (uint32 i = 0 ; i != m_nUpPartCount ; i++)
+    for (uint32_t i = 0 ; i != m_nUpPartCount ; i++)
     {
         if (m_abyUpPartStatus[i])
         {
-            gaprect.right = rect.x + (uint32)(((float) PARTSIZE *i/1024) *blockpixel);
-            gaprect.left = rect.x + (uint32)((float)((float) PARTSIZE * (i + 1) /1024) *blockpixel);
+            gaprect.right = rect.x + (uint32_t)(((float) PARTSIZE *i/1024) *blockpixel);
+            gaprect.left = rect.x + (uint32_t)((float)((float) PARTSIZE * (i + 1) /1024) *blockpixel);
             //dc->FillRect(&gaprect,&CBrush(RGB(0,0,0)));
             dc->SetBrush( *wxBLACK_BRUSH);
             mygaprect.x = gaprect.left;
@@ -115,7 +122,7 @@ void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyre
  s_UpStatusBar.SetWidth(rect->right - rect->left);
  s_UpStatusBar.Fill(crNeither);
  if (!onlygreyrect && m_abyUpPartStatus) {
- for (uint32 i = 0;i != m_nUpPartCount;i++){
+ for (uint32_t i = 0;i != m_nUpPartCount;i++){
  if (m_abyUpPartStatus[i]){
  s_StatusBar.FillRange(PARTSIZE*(i), PARTSIZE*(i+1), crClientOnly);
  }
@@ -125,7 +132,7 @@ void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyre
  }
     */
 
-uint32 CUpDownClient::GetScore(bool sysvalue, bool isdownloading, bool onlybasevalue)
+uint32_t CUpDownClient::GetScore(bool sysvalue, bool isdownloading, bool onlybasevalue)
 {
     //TODO: complete this (friends, uploadspeed, xmuleuser etc etc)
     if (!m_pszUsername)
@@ -201,7 +208,7 @@ uint32 CUpDownClient::GetScore(bool sysvalue, bool isdownloading, bool onlybasev
             return 0;
         }
     }
-    return(uint32) fBaseValue;
+    return(uint32_t) fBaseValue;
 }
 
 // Checks if it is next requested block from another chunk of the actual file or from another file
@@ -214,8 +221,8 @@ bool CUpDownClient::IsDifferentPartBlock(void)
 {
     Requested_Block_Struct *last_done_block;
     Requested_Block_Struct *next_requested_block;
-    uint32 last_done_part = 0xffffffff;
-    uint32 next_requested_part = 0xffffffff;
+    uint32_t last_done_part = 0xffffffff;
+    uint32_t next_requested_part = 0xffffffff;
     bool different_part = false;
     try
     {
@@ -298,7 +305,7 @@ bool CUpDownClient::CreateNextBlockPackage()
                 fullname = new char[strlen(srcfile->GetPath()) + strlen(srcfile->GetFileName()) + 10];
                 sprintf(fullname, "%s/%s", srcfile->GetPath(), srcfile->GetFileName());
             }
-            uint32 togo;
+            uint32_t togo;
             if (currentblock->StartOffset > currentblock->EndOffset)
             {
                 togo = currentblock->EndOffset + (srcfile->GetFileSize() - currentblock->StartOffset);
@@ -320,7 +327,7 @@ bool CUpDownClient::CreateNextBlockPackage()
                 fullname = 0;
                 file.Seek(currentblock->StartOffset);
                 filedata = new byte[togo + 500];
-                if (uint32 done = file.Read(filedata, togo) != togo)
+                if (uint32_t done = file.Read(filedata, togo) != togo)
                 {
                     file.Seek(0);
                     file.Read(filedata + done, togo - done);
@@ -334,7 +341,7 @@ bool CUpDownClient::CreateNextBlockPackage()
                 fullname = 0;
                 partfile->m_hpartfile.Seek(currentblock->StartOffset);
                 filedata = new byte[togo + 500];
-                if (uint32 done = partfile->m_hpartfile.Read(filedata, togo) != togo)
+                if (uint32_t done = partfile->m_hpartfile.Read(filedata, togo) != togo)
                 {
                     partfile->m_hpartfile.Seek(0);
                     partfile->m_hpartfile.Read(filedata + done, togo - done);
@@ -364,7 +371,7 @@ bool CUpDownClient::CreateNextBlockPackage()
     return true;
 }
 
-void CUpDownClient::ProcessUpFileStatus(char *packet, uint32 size)
+void CUpDownClient::ProcessUpFileStatus(char *packet, uint32_t size)
 {
     if (m_abyUpPartStatus)
     {
@@ -376,14 +383,14 @@ void CUpDownClient::ProcessUpFileStatus(char *packet, uint32 size)
     if (size == 16)
     return;
     CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
-    uchar cfilehash[16];
+    unsigned char cfilehash[16];
     data->Read(cfilehash, 16);
     CKnownFile *tempreqfile = theApp.sharedfiles->GetFileByID(cfilehash);
     data->Read( &m_nUpPartCount, 2);
     if (!m_nUpPartCount)
     {
         m_nUpPartCount = tempreqfile->GetPartCount();
-        m_abyUpPartStatus = new uint8[m_nUpPartCount];
+        m_abyUpPartStatus = new uint8_t[m_nUpPartCount];
         memset(m_abyUpPartStatus, 0, m_nUpPartCount);
     }
     else
@@ -395,13 +402,13 @@ void CUpDownClient::ProcessUpFileStatus(char *packet, uint32 size)
             m_nUpPartCount = 0;
             return;
         }
-        m_abyUpPartStatus = new uint8[m_nUpPartCount];
-        uint16 done = 0;
+        m_abyUpPartStatus = new uint8_t[m_nUpPartCount];
+        uint16_t done = 0;
         while (done != m_nUpPartCount)
         {
-            uint8 toread;
+            uint8_t toread;
             data->Read( &toread, 1);
-            for (sint32 i = 0 ; i != 8 ; i++)
+            for (int32_t i = 0 ; i != 8 ; i++)
             {
                 m_abyUpPartStatus[done] = ((toread >> i) &1) ? 1: 0;
                 //				We may want to use this for another feature..
@@ -418,12 +425,12 @@ void CUpDownClient::ProcessUpFileStatus(char *packet, uint32 size)
     delete data;
 }
 
-void CUpDownClient::CreateStandartPackets(byte *data, uint32 togo, Requested_Block_Struct *currentblock)
+void CUpDownClient::CreateStandartPackets(byte *data, uint32_t togo, Requested_Block_Struct *currentblock)
 {
-    uint32 nPacketSize;
+    uint32_t nPacketSize;
     CMemFile memfile((BYTE *) data, togo);
     if (togo > 10240)
-    nPacketSize = togo/ (uint32)(togo/10240);
+    nPacketSize = togo/ (uint32_t)(togo/10240);
     else
     nPacketSize = togo;
     while (togo)
@@ -433,20 +440,20 @@ void CUpDownClient::CreateStandartPackets(byte *data, uint32 togo, Requested_Blo
         togo -= nPacketSize;
         Packet *packet = new Packet(OP_SENDINGPART, nPacketSize + 24);
         memcpy( &packet->pBuffer[0], GetUploadFileID(), 16);
-        uint32 statpos = (currentblock->EndOffset - togo) - nPacketSize;
+        uint32_t statpos = (currentblock->EndOffset - togo) - nPacketSize;
         memcpy( &packet->pBuffer[16], &statpos, 4);
-        uint32 endpos = (currentblock->EndOffset - togo);
+        uint32_t endpos = (currentblock->EndOffset - togo);
         memcpy( &packet->pBuffer[20], &endpos, 4);
         memfile.Read( &packet->pBuffer[24], nPacketSize);
         m_BlockSend_queue.AddTail(packet);
     }
 }
 
-void CUpDownClient::CreatePackedPackets(byte *data, uint32 togo, Requested_Block_Struct *currentblock)
+void CUpDownClient::CreatePackedPackets(byte *data, uint32_t togo, Requested_Block_Struct *currentblock)
 {
     BYTE *output = new BYTE[togo + 300];
     uLongf newsize = togo + 300;
-    uint16 result = compress2(output, &newsize, data, togo, 9);
+    uint16_t result = compress2(output, &newsize, data, togo, 9);
     if (result != Z_OK || togo <= newsize)
     {
         delete[] output;
@@ -456,9 +463,9 @@ void CUpDownClient::CreatePackedPackets(byte *data, uint32 togo, Requested_Block
     m_bUsedComprUp = true;
     CMemFile memfile(output, newsize);
     togo = newsize;
-    uint32 nPacketSize;
+    uint32_t nPacketSize;
     if (togo > 10240)
-    nPacketSize = togo/ (uint32)(togo/10240);
+    nPacketSize = togo/ (uint32_t)(togo/10240);
     else
     nPacketSize = togo;
     while (togo)
@@ -468,7 +475,7 @@ void CUpDownClient::CreatePackedPackets(byte *data, uint32 togo, Requested_Block
         togo -= nPacketSize;
         Packet *packet = new Packet(OP_COMPRESSEDPART, nPacketSize + 24, OP_EMULEPROT);
         memcpy( &packet->pBuffer[0], GetUploadFileID(), 16);
-        uint32 statpos = currentblock->StartOffset;
+        uint32_t statpos = currentblock->StartOffset;
         memcpy( &packet->pBuffer[16], &statpos, 4);
         memcpy( &packet->pBuffer[20], &newsize, 4);
         memfile.Read( &packet->pBuffer[24], nPacketSize);
@@ -477,14 +484,22 @@ void CUpDownClient::CreatePackedPackets(byte *data, uint32 togo, Requested_Block
     delete[] output;
 }
 
-void CUpDownClient::SetUploadFileID(uchar *tempreqfileid)
+void CUpDownClient::SetUploadFileID(unsigned char* tempreqfileid)
 {
-    CKnownFile *newreqfile = NULL;
+    CKnownFile* newreqfile = NULL;
+
     if (tempreqfileid)
-    newreqfile = theApp.sharedfiles->GetFileByID(tempreqfileid);
-    CKnownFile *oldreqfile = theApp.sharedfiles->GetFileByID(requpfileid);
+    {
+        newreqfile = theApp.sharedfiles->GetFileByID(tempreqfileid);
+    }
+
+    CKnownFile* oldreqfile = theApp.sharedfiles->GetFileByID(requpfileid);
+    
     if (newreqfile == oldreqfile)
-    return;
+    {
+        return;
+    }
+
     if (newreqfile)
     {
         newreqfile->AddQueuedCount();
@@ -495,6 +510,7 @@ void CUpDownClient::SetUploadFileID(uchar *tempreqfileid)
     {
         memset(requpfileid, 0, 16);
     }
+
     if (oldreqfile)
     {
         oldreqfile->SubQueuedCount();
@@ -523,7 +539,7 @@ void CUpDownClient::AddReqBlock(Requested_Block_Struct *reqblock)
     m_BlockRequests_queue.AddTail(reqblock);
 }
 
-void CUpDownClient::SetUpStartTime(uint32 dwTime)
+void CUpDownClient::SetUpStartTime(uint32_t dwTime)
 {
     if (dwTime)
     m_dwUploadTime = dwTime;
@@ -531,7 +547,7 @@ void CUpDownClient::SetUpStartTime(uint32 dwTime)
     m_dwUploadTime =::GetTickCount();
 }
 
-void CUpDownClient::SetWaitStartTime(uint32 dwTime)
+void CUpDownClient::SetWaitStartTime(uint32_t dwTime)
 {
     if (dwTime)
     m_dwWaitTime = dwTime;
@@ -539,10 +555,10 @@ void CUpDownClient::SetWaitStartTime(uint32 dwTime)
     m_dwWaitTime =::GetTickCount();
 }
 
-uint32 CUpDownClient::SendBlockData(uint32 nMaxAmmount)
+uint32_t CUpDownClient::SendBlockData(uint32_t nMaxAmmount)
 {
-    uint32 msCur =::GetTickCount();
-    uint32 bytesToSend = 0;
+    uint32_t msCur =::GetTickCount();
+    uint32_t bytesToSend = 0;
     float lambdaAvg, kBpsToSend;
     m_AvarageUDR_list.AddTail(dataratems);
     m_nSumForAvgUpDataRate += dataratems;
@@ -574,14 +590,14 @@ uint32 CUpDownClient::SendBlockData(uint32 nMaxAmmount)
             &&m_BlockSend_queue.GetHead()->GetRealPacketSize() > MAXFRAGSIZE *2)
             {
                 // splitting packets
-                uint32 nSize = m_BlockSend_queue.GetHead()->GetRealPacketSize();
+                uint32_t nSize = m_BlockSend_queue.GetHead()->GetRealPacketSize();
                 char *pBuffer = m_BlockSend_queue.GetHead()->DetachPacket();
                 delete m_BlockSend_queue.RemoveHead();
-                uint32 nPos = nSize;
+                uint32_t nPos = nSize;
                 bool bLast = true;
                 while (nPos)
                 {
-                    uint32 nNewSize = (nPos < MAXFRAGSIZE) ? nPos: MAXFRAGSIZE;
+                    uint32_t nNewSize = (nPos < MAXFRAGSIZE) ? nPos: MAXFRAGSIZE;
                     nPos -= nNewSize;
                     char *pBuffer2 = new char[nNewSize];
                     memcpy(pBuffer2, pBuffer + nPos, nNewSize);
@@ -594,9 +610,9 @@ uint32 CUpDownClient::SendBlockData(uint32 nMaxAmmount)
             &&m_BlockSend_queue.GetHead()->GetRealPacketSize() <= m_nMaxSendAllowed)
             {
                 Packet *tosend = m_BlockSend_queue.RemoveHead();
-                wxUint32 nBlockSize = tosend->GetRealPacketSize();
+                uint32_t nBlockSize = tosend->GetRealPacketSize();
                 m_nMaxSendAllowed -= nBlockSize;
-                NewSocket_SendPacket(0, tosend, (wxUint32) this, nBlockSize);
+                NewSocket_SendPacket(0, tosend, (uint32_t) this, nBlockSize);
                 m_nTransferedUp += nBlockSize;
                 credits->AddUploaded(nBlockSize, GetIP());
                 if (m_BlockSend_queue.IsEmpty())
@@ -627,23 +643,23 @@ void CUpDownClient::FlushSendBlocks()
     {
         Packet *tosend = m_BlockSend_queue.RemoveHead();
         bool bBreak = tosend->IsLastSplitted();
-        NewSocket_SendPacket(0, tosend, (wxUint32) this, 0);
+        NewSocket_SendPacket(0, tosend, (uint32_t) this, 0);
     }
 }
 
 void CUpDownClient::SendHashsetPacket(char *forfileid)
 {
-    CKnownFile *file = theApp.sharedfiles->GetFileByID((uchar *) forfileid);
+    CKnownFile *file = theApp.sharedfiles->GetFileByID((unsigned char *) forfileid);
     if (file)
     {
         CMemFile *data = new CMemFile();
         data->Write(file->GetFileHash(), 16);
-        uint16 parts = file->GetHashCount();
+        uint16_t parts = file->GetHashCount();
         data->Write( &parts, 2);
         for (int i = 0 ; i != parts ; i++)
         data->Write(file->GetPartHash(i), 16);
         Packet *packet = new Packet(data);
-        NewSocket_SendPacketOP(2,OP_HASHSETANSWER, packet, (wxUint32) this, 1);
+        NewSocket_SendPacketOP(2,OP_HASHSETANSWER, packet, (uint32_t) this, 1);
         delete data;
     }
 }
@@ -672,13 +688,13 @@ void CUpDownClient::SendRankingInfo()
 {
     if (ExtProtocolAvailable())
     {
-        uint16 nRank = theApp.uploadqueue->GetWaitingPosition(this);
+        uint16_t nRank = theApp.uploadqueue->GetWaitingPosition(this);
         if (nRank)
         {
             Packet *packet = new Packet(OP_QUEUERANKING, 12, OP_EMULEPROT);
             memset(packet->pBuffer, 0, 12);
             memcpy(packet->pBuffer + 0, &nRank, 2);
-            NewSocket_SendPacketOP(2, OP_QUEUERANKING,packet, (wxUint32) this, 0);
+            NewSocket_SendPacketOP(2, OP_QUEUERANKING,packet, (uint32_t) this, 0);
         }
     }
 }
@@ -688,8 +704,8 @@ void CUpDownClient::SendCommentInfo(CKnownFile *file)
     if (m_bCommentDirty && (file != NULL) &&ExtProtocolAvailable() && (m_byAcceptCommentVer > 0))
     {
         m_bCommentDirty = false;
-        int8 rating = file->GetFileRate();
-        CString desc = file->GetFileComment();
+        int8_t rating = file->GetFileRate();
+        wxString desc = file->GetFileComment();
         if (file->GetFileRate() || (!desc.IsEmpty()))
         {
 #if defined(__DEBUG__)
@@ -697,7 +713,7 @@ void CUpDownClient::SendCommentInfo(CKnownFile *file)
 #endif
             CMemFile *data = new CMemFile();
             data->Write( &rating, sizeof(rating));
-            int length = desc.GetLength();
+            int length = desc.length();
             if (length > 128)
             {
                 length = 128;
@@ -705,16 +721,16 @@ void CUpDownClient::SendCommentInfo(CKnownFile *file)
             data->Write( &length, sizeof(length));
             if (length > 0)
             {
-                data->Write(desc.GetBuffer(), length);
+                data->Write(desc.c_str(), length);
             }
             Packet *packet = new Packet(data, OP_EMULEPROT);
             delete data;
-            NewSocket_SendPacketOP(2,OP_FILEDESC, packet, (wxUint32) this, 0);
+            NewSocket_SendPacketOP(2,OP_FILEDESC, packet, (uint32_t) this, 0);
         }
     }
 }
 
-void CUpDownClient::AddRequestCount(uchar *fileid)
+void CUpDownClient::AddRequestCount(unsigned char *fileid)
 {
     for (POSITION pos = m_RequestedFiles_list.GetHeadPosition() ; pos != 0 ; m_RequestedFiles_list.GetNext(pos))
     {
@@ -775,7 +791,7 @@ void CUpDownClient::UDPFileReasked()
 {
     AddAskedCount();
     SetLastUpRequest();
-    uint16 nRank = theApp.uploadqueue->GetWaitingPosition(this);
+    uint16_t nRank = theApp.uploadqueue->GetWaitingPosition(this);
     Packet *response = new Packet(OP_REASKACK, 2, OP_EMULEPROT);
     memcpy(response->pBuffer, &nRank, 2);
     NewSocket_SendPacket(1, response, GetIP(), GetUDPPort());
