@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,7 +22,10 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#	include "UploadListCtrl.h"
+
 #	include "ChatWnd.h"
+#include "ClientCredits.h"                  // CClientCredits
 #	include "ClientDetailDialog.h"
 #	include "FriendList.h"
 #	include "KnownFile.h"
@@ -32,7 +35,7 @@
 #include "Preferences.h"                    // CPreferences::List Settings
 #	include "SharedFileList.h"
 #	include "TransferWnd.h"
-#	include "UploadListCtrl.h"
+#include "updownclient.h"                   // Needed for CUpDownClient - audited 5 Nov 2004
 #	include "wintypes.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
@@ -164,7 +167,7 @@ void CUploadListCtrl::OnNMRclick(wxMouseEvent &evt)
 
 void CUploadListCtrl::AddClient(CUpDownClient *client)
 {
-    uint32 itemnr = GetItemCount();
+    uint32_t itemnr = GetItemCount();
     char buffer[100];
     //itemnr = InsertItem(LVIF_TEXT|LVIF_PARAM,itemnr,client->GetUserName(),0,0,1,(LPARAM)client);
     itemnr = InsertItem(itemnr, client->GetUserName());
@@ -182,8 +185,8 @@ void CUploadListCtrl::RemoveClient(CUpDownClient *client)
     //LVFINDINFO find;
     //find.flags = LVFI_PARAM;
     //find.lParam = (LPARAM)client;
-    //sint32 result = FindItem(&find);
-    sint32 result = FindItem( - 1, (long) client);
+    //int32_t result = FindItem(&find);
+    int32_t result = FindItem( - 1, (long) client);
     if (result != ( - 1))
     DeleteItem(result);
 }
@@ -193,21 +196,21 @@ void CUploadListCtrl::RefreshClient(CUpDownClient *client)
     //LVFINDINFO find;
     //find.flags = LVFI_PARAM;
     //find.lParam = (LPARAM)client;
-    //sint32 itemnr = FindItem(&find);
-    sint32 itemnr = FindItem( - 1, (long) client);
+    //int32_t itemnr = FindItem(&find);
+    int32_t itemnr = FindItem( - 1, (long) client);
     if (itemnr == ( - 1))
     return;
-    uint8 image;
+    uint8_t image;
     if (client->ExtProtocolAvailable())
     {
-        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
         image = 3;
         else
         image = 1;
     }
     else
     {
-        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
         image = 2;
         else
         image = 0;
@@ -323,19 +326,19 @@ int CUploadListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
     switch (lParamSort)
     {
     case 0:
-        return CString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
+        return wxString(item1->GetUserName()) .CmpNoCase(item2->GetUserName());
     case 100:
-        return CString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
+        return wxString(item2->GetUserName()) .CmpNoCase(item1->GetUserName());
     case 1:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
+        return wxString(file1->GetFileName()) .CmpNoCase(file2->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
         return 0;
     case 101:
         if ((file1 != NULL) && (file2 != NULL))
-        return CString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
+        return wxString(file2->GetFileName()) .CmpNoCase(file1->GetFileName());
         else if(file1 == NULL)
         return 1;
         else
@@ -427,9 +430,9 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
     cur_rec.right = rect.x + rect.width;
     cur_rec.bottom = rect.y + rect.height;
     // lagloose
-    CString rbuffer;
+    wxString rbuffer;
     // end lagloose
-    CString Sbuffer;
+    wxString Sbuffer;
     CKnownFile *file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
     //pHeaderCtrl->GetItemCount();:
@@ -454,12 +457,12 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
             {
             case 0:
                 {
-                    uint8 image;
+                    uint8_t image;
                     if (client->IsFriend())
                     image = 4;
                     else if(client->ExtProtocolAvailable())
                     {
-                        if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                        if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                         image = 3;
                         else
                         image = 1;
@@ -468,21 +471,21 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                     {
                         if (client->GetClientSoft() == SO_MLDONKEY)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 6;
                             else
                             image = 5;
                         }
                         else if(client->GetClientSoft() == SO_EDONKEYHYBRID)
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 8;
                             else
                             image = 7;
                         }
                         else
                         {
-                            if (client->credits->GetScoreRatio(client->GetIP()) > 1)
+                            if (client->Credits()->GetScoreRatio(client->GetIP()) > 1)
                             image = 2;
                             else
                             image = 0;
@@ -497,7 +500,7 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                                         };
                     imagelist.Draw(image, *dc, cur_rec.left, cur_rec.top + 1, wxIMAGELIST_DRAW_TRANSPARENT);
                     //imagelist.Draw(dc,image, point, ILD_NORMAL);
-                    Sbuffer.Format("%s", client->GetUserName());
+                    Sbuffer.Printf("%s", client->GetUserName());
                     cur_rec.left += 20;
                     //dc->DrawText(Sbuffer,Sbuffer.GetLength(),&cur_rec,DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS);
                     dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
@@ -506,7 +509,7 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                 }
             case 1:
                 if (file)
-                Sbuffer.Format("%s", file->GetFileName());
+                Sbuffer.Printf("%s", file->GetFileName());
                 else
                 Sbuffer = "?";
                 break;
@@ -515,26 +518,26 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                 if (client->GetDownloadState() == DS_DOWNLOADING)
                 {
                     Sbuffer = "";
-                    rbuffer.Format("%.1f", (float) client->GetDatarate() /1024);
+                    rbuffer.Printf("%.1f", (float) client->GetDatarate() /1024);
                     Sbuffer.Append(rbuffer);
                     Sbuffer.Append("/");
-                    rbuffer.Format("%.1f %s", (float) client->GetDownloadDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
+                    rbuffer.Printf("%.1f %s", (float) client->GetDownloadDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
                     Sbuffer.Append(rbuffer);
                 }
                 else
                 {
-                    Sbuffer.Format("%.1f %s", (float) client->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
+                    Sbuffer.Printf("%.1f %s", (float) client->GetDatarate() /1024, GetResString(IDS_KBYTESEC) .GetData());
                 }
                 // end lagloose
                 break;
             case 3:
-                Sbuffer.Format("%s", CastItoXBytes(client->GetSessionUp()) .GetData());
+                Sbuffer.Printf("%s", CastItoXBytes(client->GetSessionUp()) .GetData());
                 break;
             case 4:
-                Sbuffer.Format("%s", CastSecondsToHM((client->GetWaitTime()) /1000) .GetData());
+                Sbuffer.Printf("%s", CastSecondsToHM((client->GetWaitTime()) /1000) .GetData());
                 break;
             case 5:
-                Sbuffer.Format("%s", CastSecondsToHM((client->GetUpStartTimeDelay()) /1000) .GetData());
+                Sbuffer.Printf("%s", CastSecondsToHM((client->GetUpStartTimeDelay()) /1000) .GetData());
                 break;
             case 6:
                 switch (client->GetUploadState())
