@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -103,7 +103,7 @@ void Wizard::OnBnClickedApply(wxEvent &evt)
     }
     if (upload > 0 &&download > 0)
     {
-        app_prefs->prefs->maxupload = (uint16)(upload *.8);
+        app_prefs->prefs->maxupload = (uint16_t)(upload *.8);
         if (upload < 4 &&download > upload *3)
         {
             app_prefs->prefs->maxdownload = app_prefs->prefs->maxupload *3;
@@ -115,7 +115,7 @@ void Wizard::OnBnClickedApply(wxEvent &evt)
             download = upload *4;
         }
         else
-        app_prefs->prefs->maxdownload = (uint16)(download *.9);
+        app_prefs->prefs->maxdownload = (uint16_t)(download *.9);
         app_prefs->prefs->maxGraphDownloadRate = app_prefs->prefs->maxdownload;
         app_prefs->prefs->maxGraphUploadRate = app_prefs->prefs->maxupload;
         theApp.xmuledlg->statisticswnd->SetARange(false, app_prefs->prefs->maxGraphUploadRate);
@@ -252,23 +252,23 @@ void Wizard::OnBnClickedWizHighdownloadRadio(wxEvent &evt)
 
 void Wizard::OnBnClickedWizResetButton(wxEvent &evt)
 {
-    CString strBuffer;
-    strBuffer.Format("%i", 0);
+    wxString strBuffer;
+    strBuffer.Printf("%i", 0);
     GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(strBuffer);
     GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(strBuffer);
 }
 
 #define CheckDlgButton(a,b) GetDlgItem(a,wxRadioButton)->SetValue(b)
 
-BOOL Wizard::OnInitDialog()
+bool Wizard::OnInitDialog()
 {
     //CheckDlgButton(IDC_WIZ_XP_RADIO,1);
     //CheckDlgButton(ID_LOWDOWN, 1);
     //CheckDlgButton(ID_KBITS, 1);
-    CString temp;
-    temp.Format("%u", app_prefs->prefs->maxGraphDownloadRate *8);
+    wxString temp;
+    temp.Printf("%u", app_prefs->prefs->maxGraphDownloadRate *8);
     //GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(temp);
-    temp.Format("%u", app_prefs->prefs->maxGraphUploadRate *8);
+    temp.Printf("%u", app_prefs->prefs->maxGraphUploadRate *8);
     //GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(temp);
     m_provider->InsertColumn(0, GetResString(IDS_PW_CONNECTION), wxLIST_FORMAT_LEFT, 160);
     m_provider->InsertColumn(1, GetResString(IDS_WIZ_DOWN), wxLIST_FORMAT_LEFT, 90);
@@ -333,7 +333,7 @@ BOOL Wizard::OnInitDialog()
 
 void Wizard::SetCustomItemsActivation()
 {
-    BOOL active = (m_provider->GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED) < 1);
+    bool active = (m_provider->GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED) < 1);
     GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->Enable(active);
     GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->Enable(active);
     GetDlgItem(ID_KBITS, wxRadioButton)->Enable(active);
@@ -344,7 +344,7 @@ void Wizard::OnNMClickProviders(wxListEvent &evt)
 {
     //LPNMLISTVIEW pNMLV = reinterpret_cast<LPNMLISTVIEW>(pNMHDR);
     SetCustomItemsActivation();
-    uint16 up, down;
+    uint16_t up, down;
     int cursel = m_provider->GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
     switch (cursel)
     {
@@ -401,10 +401,10 @@ void Wizard::OnNMClickProviders(wxListEvent &evt)
         break;
     default: return;
     }
-    CString temp;
-    temp.Format("%u", down);
+    wxString temp;
+    temp.Printf("%u", down);
     //GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(temp);
-    temp.Format("%u", up);
+    temp.Printf("%u", up);
     //GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(temp);
     //CheckDlgButton(ID_KBITS, 1);
     //CheckDlgButton(ID_KBYTES, 0);
