@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -57,7 +57,7 @@ XBMDraw::~XBMDraw()
     }
 }
 
-bool XBMDraw::CreateImage(CString sName, int nWidth, int nHeight, BYTE bBackground)
+bool XBMDraw::CreateImage(wxString sName, int nWidth, int nHeight, BYTE bBackground)
 {
     try
     {
@@ -76,7 +76,7 @@ bool XBMDraw::CreateImage(CString sName, int nWidth, int nHeight, BYTE bBackgrou
     return false;
 }
 
-bool XBMDraw::GetImage(CString &sImage)
+bool XBMDraw::GetImage(wxString &sImage)
 {
     try
     {
@@ -106,7 +106,7 @@ bool XBMDraw::GetImage(CString &sImage)
             char *tmpbuf = new char[2 *nSize];
             sprintf(tmpbuf, "\n<script language=\"javascript\">\n%s = \'#define _width %d\\n#define _height %d\\nstatic unsigned char _bits[] = { %s }\'\n</script>\n",
             m_sName.GetData(), m_nWidth, m_nHeight, sBits);
-            sImage = CString(tmpbuf);
+            sImage = wxString(tmpbuf);
             delete[] sBits;
             delete[] tmpbuf;
             return true;
@@ -145,11 +145,11 @@ bool XBMDraw::Plot(int x, int y, bool bXOR)
     return false;
 }
 
-CString XBMDraw::GetImageTag()
+wxString XBMDraw::GetImageTag()
 {
     try
     {
-        CString sRet;
+        wxString sRet;
         sRet.Printf("<img src=\"javascript:%s\" width=\"%d\" height=\"%d\">", m_sName.GetData(), m_nWidth, m_nHeight);
         return sRet;
     }
