@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -32,14 +32,14 @@ class XBMDraw
 {
 public:
 	bool Line(int x1, int y1, int x2, int y2, bool bXOR = false);
-	CString GetImageTag();
+	wxString GetImageTag();
 	bool Plot(int x, int y, bool bXOR = false);
-	bool GetImage(CString &sImage);
-	bool CreateImage(CString sName, int nWidth, int nHeight, BYTE bBackground = 0x00);
+	bool GetImage(wxString &sImage);
+	bool CreateImage(wxString sName, int nWidth, int nHeight, BYTE bBackground = 0x00);
 	XBMDraw();
 	virtual ~XBMDraw();
 private:
-	CString	m_sName;
+	wxString	m_sName;
 	int		m_nWidth;
 	int		m_nHeight;
 	BYTE*	m_pImage;
