@@ -1,28 +1,10 @@
-// This file is a part of the xMule Project.
-//
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
-// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 /////////////////////////////////////////////////////////////////////////////
 // Name:        animate.h
 // Purpose:     Animation classes
 // Author:      Julian Smart and Guillermo Rodriguez Garcia
 // Modified by:
 // Created:     13/8/99
-// RCS-ID:      $Id: animate.h,v 1.15 2004/09/30 16:05:26 HopeSeekr Exp $
+// RCS-ID:      $Id: animate.h,v 1.16 2004/11/08 06:29:04 HopeSeekr Exp $
 // Copyright:   (c) Julian Smart and Guillermo Rodriguez Garcia
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -39,15 +21,20 @@
 #include <wx/gdicmn.h>
 #include <wx/list.h>
 #include <wx/timer.h>
+#include <wx/bitmap.h>
+#include <wx/colour.h>
 #include <wx/control.h>
-#include <wx/dcmemory.h>
-#include <wx/log.h>
 
-//#define ANIMDLLEXPORT WXDLLEXPORT
-#define ANIMDLLEXPORT
+#ifdef WXMAKINGDLL_ANIMATE
+    #define WXDLLIMPEXP_ANIMATE WXEXPORT
+#elif defined(WXUSINGDLL)
+    #define WXDLLIMPEXP_ANIMATE WXIMPORT
+#else // not making nor using DLL
+    #define WXDLLIMPEXP_ANIMATE
+#endif
 
-class ANIMDLLEXPORT wxAnimationBase;
-class ANIMDLLEXPORT wxAnimationPlayer;
+class WXDLLIMPEXP_ANIMATE wxAnimationBase;
+class WXDLLIMPEXP_ANIMATE wxAnimationPlayer;
 class WXDLLEXPORT wxImage;
 
 enum wxAnimationDisposal
@@ -58,7 +45,7 @@ enum wxAnimationDisposal
     wxANIM_TOPREVIOUS = 2
 } ;
 
-class ANIMDLLEXPORT wxAnimationTimer: public wxTimer
+class WXDLLIMPEXP_ANIMATE wxAnimationTimer: public wxTimer
 {
 public:
     wxAnimationTimer() { m_player = (wxAnimationPlayer*) NULL; }
@@ -71,13 +58,13 @@ protected:
 };
 
 /* wxAnimationPlayer
- * Create an object of this class, and either pass an wxXXXAnimation object in the constructor,
- * or call SetAnimation. Then call Play().
- * The wxAnimation object is only destroyed in the destructor if destroyAnimation is TRUE
- * in the constructor.
+ * Create an object of this class, and either pass an wxXXXAnimation object in
+ * the constructor, or call SetAnimation. Then call Play().  The wxAnimation
+ * object is only destroyed in the destructor if destroyAnimation is TRUE in
+ * the constructor.
  */
 
-class ANIMDLLEXPORT wxAnimationPlayer : public wxObject
+class WXDLLIMPEXP_ANIMATE wxAnimationPlayer : public wxObject
 {
     DECLARE_CLASS(wxAnimationPlayer)
 
@@ -159,7 +146,7 @@ public:
 //// Implementation
 
     // Play the frame
-    virtual bool PlayFrame(int frame, wxWindow& window, wxPoint& pos);
+    virtual bool PlayFrame(int frame, wxWindow& window, const wxPoint& pos);
     virtual bool PlayFrame();
     virtual void DrawFrame(int frame, wxDC& dc, const wxPoint& pos);
     virtual void DrawBackground(wxDC& dc, const wxPoint& pos, const wxColour& colour);
@@ -194,14 +181,15 @@ protected:
 
 /* wxAnimationBase
  * Base class for animations.
- * A wxXXXAnimation only stores the animation, providing accessors to wxAnimationPlayer.
- * Currently an animation is read-only, but we could extend the API for adding frames
- * programmatically, and perhaps have a wxMemoryAnimation class that stores its frames
- * in memory, and is able to save all files with suitable filenames. You could then use
- * e.g. Ulead GIF Animator to load the image files into a GIF animation.
+ * A wxXXXAnimation only stores the animation, providing accessors to
+ * wxAnimationPlayer.  Currently an animation is read-only, but we could
+ * extend the API for adding frames programmatically, and perhaps have a
+ * wxMemoryAnimation class that stores its frames in memory, and is able to
+ * save all files with suitable filenames. You could then use e.g. Ulead GIF
+ * Animator to load the image files into a GIF animation.
  */
 
-class ANIMDLLEXPORT wxAnimationBase : public wxObject
+class WXDLLIMPEXP_ANIMATE wxAnimationBase : public wxObject
 {
     DECLARE_ABSTRACT_CLASS(wxAnimationBase)
 
@@ -211,6 +199,7 @@ public:
 
 //// Accessors. Should be overridden by each derived class.
 
+    bool LoadData(char *data, int size) { return false; }
     virtual int GetFrameCount() const = 0;
     virtual wxImage* GetFrame(int i) const = 0; // Creates a new wxImage
     virtual wxAnimationDisposal GetDisposalMethod(int i) const = 0;
@@ -226,17 +215,16 @@ public:
 
 //// Operations
 
-    virtual bool LoadFile(const wxString& filename) { return FALSE; }
-    virtual bool LoadData(char* data,int size) { return FALSE; }
+    virtual bool LoadFile(const wxString& WXUNUSED(filename)) { return FALSE; }
 };
 
 /* wxGIFAnimation
  * This will be moved to a separate file in due course.
  */
 
-class ANIMDLLEXPORT wxGIFDecoder;
+class WXDLLIMPEXP_ANIMATE wxGIFDecoder;
 
-class ANIMDLLEXPORT wxGIFAnimation : public wxAnimationBase
+class WXDLLIMPEXP_ANIMATE wxGIFAnimation : public wxAnimationBase
 {
     DECLARE_CLASS(wxGIFAnimation)
 
@@ -245,6 +233,7 @@ public:
     ~wxGIFAnimation() ;
 
 //// Accessors
+    bool LoadData(char *data, int size);
 
     virtual int GetFrameCount() const;
     virtual wxImage* GetFrame(int i) const;
@@ -261,7 +250,6 @@ public:
 //// Operations
 
     virtual bool LoadFile(const wxString& filename);
-    virtual bool LoadData(char* data,int size);
 
 protected:
 
@@ -278,7 +266,7 @@ protected:
 // Resize to animation size if this is set
 #define wxAN_FIT_ANIMATION       0x0010
 
-class ANIMDLLEXPORT wxAnimationCtrlBase: public wxControl
+class WXDLLIMPEXP_ANIMATE wxAnimationCtrlBase: public wxControl
 {
 public:
     wxAnimationCtrlBase() { }
@@ -292,6 +280,7 @@ public:
     }
     ~wxAnimationCtrlBase();
 
+    bool LoadData(char *data, int size);
     bool Create(wxWindow *parent, wxWindowID id,
             const wxString& filename = wxEmptyString,
             const wxPoint& pos = wxDefaultPosition,
@@ -300,7 +289,6 @@ public:
 
     //// Operations
     virtual bool LoadFile(const wxString& filename = wxEmptyString);
-    virtual bool LoadData(char* data,int size);
     virtual bool Play(bool looped = TRUE) ;
     virtual void Stop() { m_animationPlayer.Stop(); }
     virtual void FitToAnimation();
@@ -336,7 +324,7 @@ private:
  * Provides a GIF animation class when required.
  */
 
-class ANIMDLLEXPORT wxGIFAnimationCtrl: public wxAnimationCtrlBase
+class WXDLLIMPEXP_ANIMATE wxGIFAnimationCtrl: public wxAnimationCtrlBase
 {
 public:
     wxGIFAnimationCtrl() { }
