@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -251,7 +251,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%g",fDefault);
+    //strDefault.Printf("%g",fDefault);
     strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return atof(m_chBuffer);
@@ -264,7 +264,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%g",fDefault);
+    //strDefault.Printf("%g",fDefault);
     strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(float) atof(m_chBuffer);
@@ -277,7 +277,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%d",nDefault);
+    //strDefault.Printf("%d",nDefault);
     strDefault = wxString::Format("%d", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault.GetData());
     return atoi(m_chBuffer);
@@ -290,7 +290,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%u",nDefault);
+    //strDefault.Printf("%u",nDefault);
     strDefault = wxString::Format("%u", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(WORD) atoi(m_chBuffer);
@@ -303,7 +303,7 @@ wxString const &CIni::GetSection() const
 )
 {
     wxString strDefault;
-    //strDefault.Format("%d",bDefault);
+    //strDefault.Printf("%d",bDefault);
     strDefault = wxString::Format("%d", bDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(atoi(m_chBuffer) != 0);
@@ -314,7 +314,7 @@ wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
     wxPoint ptReturn = ptDefault;
     wxString strDefault;
     strDefault = wxString::Format("(%d,%d)", ptDefault.x, ptDefault.y);
-    //strDefault.Format("(%d,%d)",ptDefault.x, ptDefault.y);
+    //strDefault.Printf("(%d,%d)",ptDefault.x, ptDefault.y);
     wxString strPoint = GetString(strEntry, (char *) strDefault.GetData());
     sscanf(strPoint, "(%d,%d)", &ptReturn.x, &ptReturn.y);
     return ptReturn;
@@ -325,8 +325,8 @@ wxRect CIni::GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
 #if 0
     wxRect rectReturn = rectDefault;
     wxString strDefault;
-    //old version :strDefault.Format("(%d,%d,%d,%d)",rectDefault.top,rectDefault.left,rectDefault.bottom,rectDefault.right);
-    strDefault.Format("%d,%d,%d,%d", rectDefault.left, rectDefault.top, rectDefault.right, rectDefault.bottom);
+    //old version :strDefault.Printf("(%d,%d,%d,%d)",rectDefault.top,rectDefault.left,rectDefault.bottom,rectDefault.right);
+    strDefault.Printf("%d,%d,%d,%d", rectDefault.left, rectDefault.top, rectDefault.right, rectDefault.bottom);
     wxString strRect = GetString(strEntry, strDefault);
     int nRead = 0;
     //new Version found
@@ -441,7 +441,7 @@ void CIni::WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    //strBuffer.Format("(%d,%d,%d,%d)",rect.top,rect.left,rect.bottom,rect.right);
+    //strBuffer.Printf("(%d,%d,%d,%d)",rect.top,rect.left,rect.bottom,rect.right);
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
