@@ -1,6 +1,7 @@
-// This file is a part of the xMule Project
-// Copyright (C)2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -435,17 +436,17 @@ class CTypedPtrList: public CList < TYPE, TYPE >
 
 #include <stdarg.h>
 // same for string list
-class CString: public wxString
+/*class wxString: public wxString
 {
     public:
-    CString(): wxString()
+    wxString(): wxString()
     {
     }
-    CString(wxChar *ptr)
+    wxString(wxChar *ptr)
     : wxString(ptr)
     {
     }
-    CString(const wxChar *ptr)
+    wxString(const wxChar *ptr)
     : wxString(ptr)
     {
     }
@@ -464,15 +465,15 @@ class CString: public wxString
         PrintfV(pszFormat, argptr);
         va_end(argptr);
     }
-    int Find(CString what) const
+    int Find(wxString what) const
     {
         return wxString:: Find(what);
     }
-    CString Mid(int from, int len)
+    wxString Mid(int from, int len)
     {
-        return CString(wxString:: Mid(from, len) .GetData());
+        return wxString(wxString:: Mid(from, len) .GetData());
     }
-    CString &operator = (wxString &src)
+    wxString &operator = (wxString &src)
     {
         if (this != &src)
         {
@@ -481,7 +482,7 @@ class CString: public wxString
         }
         return *this;
     }
-    CString &operator = (wxString src)
+    wxString &operator = (wxString src)
     {
         if (this != &src)
         {
@@ -490,7 +491,7 @@ class CString: public wxString
         }
         return *this;
     }
-    CString &operator = (const char a[])
+    wxString &operator = (const char a[])
     {
         Clear();
         Append((wxChar *) a);
@@ -498,7 +499,7 @@ class CString: public wxString
     }
 };
 
-WX_DECLARE_LIST(CString, stringList);
+WX_DECLARE_LIST(wxString, stringList);
 
 class CStringList: public stringList
 {
@@ -510,21 +511,21 @@ class CStringList: public stringList
     {
         return(POSITION) GetFirst();
     }
-    CString GetNext(POSITION &pos)
+    wxString GetNext(POSITION &pos)
     {
         stringList:: Node *nod = (stringList:: Node *) pos;
-        CString retval = * (nod->GetData());
+        wxString retval = * (nod->GetData());
         nod = nod->GetNext();
         pos = (POSITION) nod;
         return retval;
     }
-    CString GetAt(POSITION pos)
+    wxString GetAt(POSITION pos)
     {
         stringList:: Node *nod = (stringList:: Node *) pos;
         return * (nod->GetData());
     }
 };
-
+*/
 // default hasher
 template < class ARG_KEY >
 unsigned int HashKey(ARG_KEY key)
