@@ -1,6 +1,6 @@
 // This file is a part of the xmule project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This file was a part of eMule
@@ -24,9 +24,9 @@
 #define _OPCODES_H
 
 static const short int MAJOR_VERSION = 1;
-static const short int MINOR_VERSION = 9;
-static const short int RELEASE_VERSION = 4;
-static const short int REVISION_VERSION = 2;
+static const short int MINOR_VERSION = 10;
+static const short int RELEASE_VERSION = 0;
+static const short int REVISION_VERSION = 0;
 
 static const short int ET_MOD_VERSION = 0x55;
 // MOD Note: Do not change this part - Merkur
@@ -391,7 +391,6 @@ enum
     MP_LISTCOL_13,
     MP_LISTCOL_14,
     MP_LISTCOL_15,
-    MP_ASSIGNCAT,
 
   /* Razor 1a - Modif by MikaelB
      Opcodes for :
@@ -409,8 +408,14 @@ enum
     MP_CLEAN_UP_SOURCES,
     MP_SWAP_A4AF_TO_THIS,
     MP_SWAP_A4AF_TO_THIS_AUTO,
-    MP_SWAP_A4AF_TO_ANY_OTHER
+    MP_SWAP_A4AF_TO_ANY_OTHER,
+    MP_ASSIGNCAT
 };
   /* End Modif */
   
+enum
+{
+    ID_XMULEDLG
+};
+
 #endif
