@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -24,16 +24,16 @@
 #else
 #	include "otherfunctions.h"
 #	include "PartFile.h"
-#	include "Preferences.h"             // CPreferences::GetAllinCat
+#	include "Preferences.h"                 // CPreferences::GetAllinCat
 #	include "resource.h"
-#	include "types.h"
-#	include "wintypes.h"
+#	include "wintypes.h"                    // BYTE DWORD UINT WORD
 #	include "xmule.h"
 #endif
 
 #include <map>                              // Needed for std::map
+#include <stdint.h>                         // uint32_t
 #include <wx/utils.h>
-#include <wx/file.h>                    // Needed for wxFile
+#include <wx/file.h>                        // Needed for wxFile
 
 #include "strings.en"
 
@@ -158,95 +158,102 @@ static BYTE base16Lookup[BASE16_LOOKUP_MAX][2] =
 
 ;
 
-CString CastItoXBytes(uint64 count)
+wxString CastItoXBytes(uint64_t count)
 {
-    CString buffer;
+    wxString buffer;
+
     if (count < 1024)
     {
-        buffer.Format("%.0f %s", (float) count, GetResString(IDS_BYTES) .GetData());
+        buffer.Printf("%.0f %s", (float) count, GetResString(IDS_BYTES) .GetData());
     }
     else if(count < 1048576)
     {
-        buffer.Format("%.0f %s", (float) count/1024, GetResString(IDS_KBYTES) .GetData());
+        buffer.Printf("%.0f %s", (float) count/1024, GetResString(IDS_KBYTES) .GetData());
     }
     else if(count < 1073741824)
     {
-        buffer.Format("%.2f %s", (float) count/1048576, GetResString(IDS_MBYTES) .GetData());
+        buffer.Printf("%.2f %s", (float) count/1048576, GetResString(IDS_MBYTES) .GetData());
     }
     else if(count < 1099511627776LL)
     {
-        buffer.Format("%.2f %s", (float) count/1073741824, GetResString(IDS_GBYTES) .GetData());
+        buffer.Printf("%.2f %s", (float) count/1073741824, GetResString(IDS_GBYTES) .GetData());
     }
     else
     {
-        buffer.Format("%.3f %s", (float) count/1099511627776LL, GetResString(IDS_TBYTES) .GetData());
+        buffer.Printf("%.3f %s", (float) count/1099511627776LL, GetResString(IDS_TBYTES) .GetData());
     }
+
     return buffer;
 }
 
-CString CastItoIShort(uint64 count)
+wxString CastItoIShort(uint64_t count)
 {
-    CString output;
+    wxString output;
+
     if (count < 1000)
     {
-        output.Format("%i", count);
+        output.Printf("%i", count);
     }
     else if(count < 1000000)
     {
-        output.Format("%.0f" + GetResString(IDS_KILO), static_cast<float>(count / 1000));
+        output.Printf("%.0f" + GetResString(IDS_KILO), static_cast<float>(count / 1000));
     }
     else if(count < 1000000000)
     {
-        output.Format("%.2f" + GetResString(IDS_MEGA), static_cast<float>(count / 1000000));
+        output.Printf("%.2f" + GetResString(IDS_MEGA), static_cast<float>(count / 1000000));
     }
     else if(count < 1000000000000LL)
     {
-        output.Format("%.2f" + GetResString(IDS_GIGA), static_cast<float>(count / 1000000000LL));
+        output.Printf("%.2f" + GetResString(IDS_GIGA), static_cast<float>(count / 1000000000LL));
     }
     else if(count < 1000000000000000LL)
     {
-        output.Format("%.2f" + GetResString(IDS_TERRA), static_cast<float>(count / 1000000000000LL));
+        output.Printf("%.2f" + GetResString(IDS_TERRA), static_cast<float>(count / 1000000000000LL));
     }
+
     return output;
 }
 
-CString CastSecondsToHM(sint32 count)
+wxString CastSecondsToHM(int32_t count)
 {
-    CString buffer;
+    wxString buffer;
+
     if (count < 0)
     {
         buffer = "?";
     }
     else if(count < 60)
     {
-        buffer.Format("%i %s", count, GetResString(IDS_SECS) .GetData());
+        buffer.Printf("%i %s", count, GetResString(IDS_SECS) .GetData());
     }
     else if(count < 3600)
     {
-        buffer.Format("%i:%s %s", count/60, LeadingZero(count - (count/60) *60) .GetData(), GetResString(IDS_MINS) .GetData());
+        buffer.Printf("%i:%s %s", count / 60, LeadingZero(count - (count/60) *60) .GetData(), GetResString(IDS_MINS) .GetData());
     }
     else if(count < 86400)
     {
-        buffer.Format("%i:%s %s", count/3600, LeadingZero((count - (count/3600) *3600) /60) .GetData(), GetResString(IDS_HOURS) .GetData());
+        buffer.Printf("%i:%s %s", count  /3600, LeadingZero((count - (count/3600) *3600) /60) .GetData(), GetResString(IDS_HOURS) .GetData());
     }
     else
     {
-        buffer.Format("%i %s %i %s", count/86400, GetResString(IDS_DAYS) .GetData(), (count - (count/86400) *86400) /3600, GetResString(IDS_HOURS) .GetData());
+        buffer.Printf("%i %s %i %s", count / 86400, GetResString(IDS_DAYS) .GetData(), (count - (count/86400) *86400) /3600, GetResString(IDS_HOURS) .GetData());
     }
+
     return buffer;
 }
 
-CString LeadingZero(uint32 units)
+wxString LeadingZero(uint32_t units)
 {
-    CString temp;
+    wxString temp;
     if (units < 10)
     {
-        temp.Format("0%i", units);
+        temp.Printf("0%i", units);
     }
     else
     {
-        temp.Format("%i", units);
+        temp.Printf("%i", units);
     }
+
     return temp;
 }
 
@@ -362,7 +369,7 @@ wxString URLEncode(wxString sIn)
     return sOut;
 }
 
-inline BYTE toHex(const BYTE &x)
+inline unsigned char toHex(const unsigned char& x)
 {
     return x > 9 ? x + 55: x + 48;
 }
@@ -472,9 +479,9 @@ wxString GetFiletypeByName(wxString infile)
     return GetResString(IDS_SEARCH_ANY);
 }
 
-CString MakeStringEscaped(CString in)
+wxString MakeStringEscaped(wxString in)
 {
-    in.Replace("&", "&&");
+    in.Replace(wxT("&"), wxT("&&"));
     return in;
 }
 
@@ -573,7 +580,7 @@ int GetMaxConnections()
     return - 1;
 }
 
-wxString GetRateString(uint16 rate)
+wxString GetRateString(uint16_t rate)
 {
     switch (rate)
     {
@@ -599,12 +606,6 @@ wxString GetRateString(uint16 rate)
     return GetResString(IDS_CMT_NOTRATED);
 }
 
-WORD DetectWinVersion()
-{
-    // we are at least this good
-    return _WINVER_XP_;
-}
-
 // Returns a BASE32 encoded BYTE array
 //
 // [In]
@@ -612,12 +613,13 @@ WORD DetectWinVersion()
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   CString object with BASE32 encoded BYTE array
-CString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
+//   wxString object with BASE32 encoded BYTE array
+wxString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
 {
-    CString Base32Buff;
+    wxString Base32Buff;
     unsigned int i, index;
     unsigned char word;
+
     for (i = 0, index = 0 ; i < bufLen ;)
     {
         // Is the current word going to span a BYTE boundary?
@@ -626,8 +628,12 @@ CString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
             word = (buffer[i] & (0xFF >> index));
             index = (index + 5) % 8;
             word <<= index;
+
             if (i < bufLen - 1)
-            word |= buffer[i + 1] >> (8 - index);
+            {
+                word |= buffer[i + 1] >> (8 - index);
+            }
+
             i++;
         }
         else
@@ -635,10 +641,14 @@ CString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
             word = (buffer[i] >> (8 - (index + 5))) &0x1F;
             index = (index + 5) % 8;
             if (index == 0)
-            i++;
+            {
+                i++;
+            }
         }
-        Base32Buff += (char) base32Chars[word];
+
+        Base32Buff += (char)base32Chars[word];
     }
+
     return Base32Buff;
 }
 
@@ -649,15 +659,17 @@ CString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   CString object with BASE16 encoded BYTE array
-CString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
+//   wxString object with BASE16 encoded BYTE array
+wxString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
 {
-    CString Base16Buff;
-    for (unsigned int i = 0 ; i < bufLen ; i++)
+    wxString Base16Buff;
+
+    for (unsigned int i = 0; i < bufLen; ++i)
     {
         Base16Buff += base16Chars[buffer[i] >> 4];
         Base16Buff += base16Chars[buffer[i] &0xf];
     }
+
     return Base16Buff;
 }
 
@@ -709,10 +721,10 @@ void UpdateURLMenu(CMenu &menu, int &counter)
 {
     counter = 0;
     theApp.webservices.RemoveAll();
-    CString name, url, sbuffer;
+    wxString name, url, sbuffer;
     char buffer[1024];
     int lenBuf = 1024;
-    FILE *readFile = fopen(CString(theApp.glob_prefs->GetAppDir()) + "webservices.dat", "r");
+    FILE *readFile = fopen(wxString(theApp.glob_prefs->GetAppDir()) + "webservices.dat", "r");
     if (readFile != NULL)
     {
         while (!feof(readFile))
@@ -736,20 +748,8 @@ void UpdateURLMenu(CMenu &menu, int &counter)
 
 #endif
 
-void RunURL(CAbstractFile *file, CString urlpattern)
+void RunURL(CAbstractFile *file, wxString urlpattern)
 {
-#if 0
-    // Convert hash to hexadecimal text and add it to the URL
-    urlpattern.Replace("#hashid", EncodeBase16(file->GetFileHash(), 16));
-    // Add file size to the URL
-    CString temp;
-    temp.Format("%u", file->GetFileSize());
-    urlpattern.Replace("#filesize", temp);
-    // add filename to the url
-    urlpattern.Replace("#filename", URLEncode(file->GetFileName()));
-    // Open URL
-    ShellExecute(NULL, NULL, urlpattern, NULL, theApp.glob_prefs->GetAppDir(), SW_SHOWDEFAULT);
-#endif
 }
 
 wxString GetCatTitle(int catid)
@@ -866,17 +866,24 @@ long long atoll(char *s)
 
 #endif /* __FreeBSD__ */
 
-void MakeFoldername(char *path)
+void MakeFoldername(wxString& path)
 {
-    wxString string(path);
-    if (string.Length() > 0) if(string.Right(1) == '\\') string = string.Left(string.Length() - 1);
-    sprintf(path, "%s", string.GetData());
+    int length = path.length();
+    if (length <= 0)
+    {
+        return;
+    }
+    
+    if (path.Right(1) == '/')
+    {
+        path = path.Left(length - 1);
+    }
 }
 
 void HexDump(const void *buffer, unsigned long buflen)
 {
 #if defined(__DEBUG__)
-    const uint8 *cbuf = (const uint8 *) buffer;
+    const uint8_t *cbuf = (const uint8_t *) buffer;
     for (unsigned long ofs = 0 ; ofs < buflen ; /* no increment here */
     )
     {
