@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -24,10 +24,13 @@
 #endif
 
 #include "packets.h"
-#include "config.h"
+#include "config.h"                         // HAVE_CRYPTOPP
 #include "otherfunctions.h"
+#include "otherstructs.h"
+#include "CFile.h"
+#include "CMemFile.h"
 
-#if !HAVE_CRYPTO
+#if !HAVE_CRYPTOPP
     #include "CryptoXMpp.h"
 #else
     #include <cryptopp/cryptlib.h>
@@ -52,7 +55,7 @@ struct Packet_int
     int bFromPF;
 };
 
-Packet::Packet(const uint8 protocol)
+Packet::Packet(const uint8_t protocol)
 {
     my = new Packet_int;
     my->bSplitted = false;
@@ -81,7 +84,7 @@ Packet::Packet(const char* header)
 }
 
 // -khaos--+++> Slightly modified for our stats uses...
-Packet::Packet(const char* type, const char* pPacketPart, const uint32 nSize, const bool bLast, const bool bFromPF)
+Packet::Packet(const char* type, const char* pPacketPart, const uint32_t nSize, const bool bLast, const bool bFromPF)
 {
     // only used for splitted packets!
     my = new Packet_int;
@@ -98,7 +101,7 @@ Packet::Packet(const char* type, const char* pPacketPart, const uint32 nSize, co
 // -khaos--+++> Slightly modified for our stats uses...
 //				If my->bFromPF = true then packet was formed from a partfile
 //				If my->bFromPF = false then this packet was formed from a complete shared file.
-Packet::Packet(const char* type, const int8 in_opcode, const uint32 in_size, const uint8 protocol, const bool bFromPF)
+Packet::Packet(const char* type, const int8_t in_opcode, const uint32_t in_size, const uint8_t protocol, const bool bFromPF)
 {
     my = new Packet_int;
     my->bFromPF = bFromPF;
@@ -125,7 +128,7 @@ Packet::Packet(const char* type, const int8 in_opcode, const uint32 in_size, con
     prot = protocol;
 }
 
-Packet::Packet(const char* pPacketPart, const uint32 nSize, const bool bLast)
+Packet::Packet(const char* pPacketPart, const uint32_t nSize, const bool bLast)
 {
     // only used for splitted packets!
     my = new Packet_int;
@@ -138,7 +141,7 @@ Packet::Packet(const char* pPacketPart, const uint32 nSize, const bool bLast)
     size = nSize - 6;
 }
 
-Packet::Packet(const int8 in_opcode, const uint32 in_size, const uint8 protocol, const unsigned char* buffer)
+Packet::Packet(const int8_t in_opcode, const uint32_t in_size, const uint8_t protocol, const unsigned char* buffer)
 {
     my = new Packet_int;
     my->bSplitted = false;
@@ -163,7 +166,7 @@ Packet::Packet(const int8 in_opcode, const uint32 in_size, const uint8 protocol,
     prot = protocol;
 }
 
-Packet::Packet(const int8 in_opcode, const uint32 in_size, const uint8 protocol)
+Packet::Packet(const int8_t in_opcode, const uint32_t in_size, const uint8_t protocol)
 {
     my = new Packet_int;
     my->bSplitted = false;
@@ -188,7 +191,7 @@ Packet::Packet(const int8 in_opcode, const uint32 in_size, const uint8 protocol)
     prot = protocol;
 }
 
-Packet::Packet(CMemFile* datafile, const uint8 protocol)
+Packet::Packet(CMemFile* datafile, const uint8_t protocol)
 {
     my = new Packet_int;
     my->bSplitted = false;
@@ -318,7 +321,7 @@ void Packet::PackPacket()
     assert(!my->bSplitted);
     BYTE* output = new BYTE[size + 300];
     uLongf newsize(size + 300);
-    uint16 result(compress2(output, &newsize, (BYTE *) pBuffer, size, Z_BEST_COMPRESSION));
+    uint16_t result(compress2(output, &newsize, (BYTE *) pBuffer, size, Z_BEST_COMPRESSION));
 
     if (result != Z_OK || size <= newsize)
     {
@@ -335,7 +338,7 @@ void Packet::PackPacket()
 bool Packet::UnPackPacket(UINT uMaxDecompressedSize)
 {
     assert(prot == OP_PACKEDPROT);
-    uint32 nNewSize(size *10 + 300);
+    uint32_t nNewSize(size *10 + 300);
 
     if (nNewSize > uMaxDecompressedSize)
     {
@@ -344,7 +347,7 @@ bool Packet::UnPackPacket(UINT uMaxDecompressedSize)
 
     BYTE* unpack = new BYTE[nNewSize];
     uLongf unpackedsize(nNewSize);
-    uint16 result(uncompress(unpack, &unpackedsize, (BYTE *) pBuffer, size));
+    uint16_t result(uncompress(unpack, &unpackedsize, (BYTE *) pBuffer, size));
     
     if (result == Z_OK)
     {
@@ -361,7 +364,7 @@ bool Packet::UnPackPacket(UINT uMaxDecompressedSize)
     return false;
 }
 
-CTag::CTag(char* name, uint32 intvalue)
+CTag::CTag(char* name, uint32_t intvalue)
 {
     tag = new Tag_Struct;
     memset(tag, 0, sizeof(Tag_Struct));
@@ -370,7 +373,7 @@ CTag::CTag(char* name, uint32 intvalue)
     tag->intvalue = intvalue;
 }
 
-CTag::CTag(int8 special, uint32 intvalue)
+CTag::CTag(int8_t special, uint32_t intvalue)
 {
     tag = new Tag_Struct;
     memset(tag, 0, sizeof(Tag_Struct));
@@ -388,7 +391,7 @@ CTag::CTag(char* name, char* strvalue)
     tag->stringvalue = nstrdup(strvalue);
 }
 
-CTag::CTag(int8 special, char* strvalue)
+CTag::CTag(int8_t special, char* strvalue)
 {
     tag = new Tag_Struct;
     memset(tag, 0, sizeof(Tag_Struct));
@@ -421,7 +424,7 @@ CTag::CTag(CFile* in_data)
 
     if (1 == in_data->Read( &tag->type, 1))
     {
-        uint16 length;
+        uint16_t length;
 
         if (2 == in_data->Read( &length, 2))
         {
@@ -506,7 +509,7 @@ CTag::CTag(CMemFile* in_data)
 
     if (1 == in_data->Read( &tag->type, 1))
     {
-        uint16 length;
+        uint16_t length;
 
         if (2 == in_data->Read( &length, 2))
         {
@@ -596,7 +599,7 @@ CTag::CTag(FILE* in_data)
         throw CInvalidPacket("short packet reading tag data type");
     }
 
-    uint16 length;
+    uint16_t length;
 
     if (1 != fread( &length, 2, 1, in_data))
     {
@@ -672,29 +675,29 @@ bool CTag::WriteTagToFile(CFile* file) const
 
     if (tag->tagname)
     {
-        uint16 taglen = (uint16)strlen(tag->tagname);
-        uint16 w_taglen = LE_BE(taglen);
+        uint16_t taglen = (uint16_t)strlen(tag->tagname);
+        uint16_t w_taglen = LE_BE(taglen);
         file->Write(&w_taglen, 2);
         file->Write(tag->tagname, taglen);
     }
     else
     {
-        uint16 taglen = 1;
-        uint16 w_taglen = LE_BE((uint16)1);
+        uint16_t taglen = 1;
+        uint16_t w_taglen = LE_BE((uint16_t)1);
         file->Write(&taglen, 2);
         file->Write(&tag->specialtag, taglen);
     }
 
     if ((TTagType) tag->type == TAG_STRING)
     {
-        uint16 len = (uint16) strlen(tag->stringvalue);
-        uint16 w_len = LE_BE(len);
+        uint16_t len = (uint16_t) strlen(tag->stringvalue);
+        uint16_t w_len = LE_BE(len);
         file->Write(&w_len, 2);
         file->Write(tag->stringvalue, len);
     }
     else if ((TTagType) tag->type == TAG_INTEGER)
     {
-        uint32 w_intvalue = LE_BE((CryptoXMpp::word32)tag->intvalue);
+        uint32_t w_intvalue = LE_BE((CryptoXMpp::word32)tag->intvalue);
         file->Write(&w_intvalue, 4);
     }
 
@@ -707,29 +710,29 @@ bool CTag::WriteTagToFile(CMemFile* file) const
 
     if (tag->tagname)
     {
-        uint16 taglen = (uint16) strlen(tag->tagname);
-        uint16 w_taglen = LE_BE(taglen);
+        uint16_t taglen = (uint16_t) strlen(tag->tagname);
+        uint16_t w_taglen = LE_BE(taglen);
         file->Write(&w_taglen, 2);
         file->Write(tag->tagname, taglen);
     }
     else
     {
-        uint16 taglen = 1;
-        uint16 w_taglen = LE_BE((uint16)1);
+        uint16_t taglen = 1;
+        uint16_t w_taglen = LE_BE((uint16_t)1);
         file->Write(&w_taglen, 2);
         file->Write(&tag->specialtag, taglen);
     }
 
     if ((TTagType) tag->type == TAG_STRING)
     {
-        uint16 len = (uint16) strlen(tag->stringvalue);
-        uint16 w_len = LE_BE(len);
+        uint16_t len = (uint16_t) strlen(tag->stringvalue);
+        uint16_t w_len = LE_BE(len);
         file->Write(&w_len, 2);
         file->Write(tag->stringvalue, len);
     }
     else if ((TTagType) tag->type == TAG_INTEGER)
     {
-        uint32 w_intvalue = LE_BE((CryptoXMpp::word32)tag->intvalue);
+        uint32_t w_intvalue = LE_BE((CryptoXMpp::word32)tag->intvalue);
         file->Write(&w_intvalue, 4);
     }
 
@@ -742,29 +745,29 @@ bool CTag::WriteTagToFile(FILE* file) const
 
     if (tag->tagname && (!tag->specialtag))
     {
-        uint16 taglen = (uint16) strlen(tag->tagname);
-        uint16 w_taglen = LE_BE(taglen);
+        uint16_t taglen = (uint16_t) strlen(tag->tagname);
+        uint16_t w_taglen = LE_BE(taglen);
         fwrite(&w_taglen, 2, 1, file);
         fwrite(tag->tagname, taglen, 1, file);
     }
     else
     {
-        uint16 taglen = 1;
-        uint16 w_taglen = LE_BE((uint16)1);
+        uint16_t taglen = 1;
+        uint16_t w_taglen = LE_BE((uint16_t)1);
         fwrite(&w_taglen, 2, 1, file);
         fwrite(&tag->specialtag, taglen, 1, file);
     }
 
     if ((TTagType) tag->type == TAG_STRING)
     {
-        uint16 len = (uint16) strlen(tag->stringvalue);
-        uint16 w_len = LE_BE(len);
+        uint16_t len = (uint16_t) strlen(tag->stringvalue);
+        uint16_t w_len = LE_BE(len);
         fwrite(&w_len, 2, 1, file);
         fwrite(tag->stringvalue, len, 1, file);
     }
     else if ((TTagType) tag->type == TAG_INTEGER)
     {
-        uint32 w_intvalue = LE_BE((CryptoXMpp::word32)tag->intvalue);
+        uint32_t w_intvalue = LE_BE((CryptoXMpp::word32)tag->intvalue);
         fwrite(&w_intvalue, 4, 1, file);
     }
 
