@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -19,17 +19,16 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-
 #ifndef SERVER_H
 #define SERVER_H
 
-#include "SafeFile.h"
-#include "types.h"
-#include "otherstructs.h"
-#include "wx/list.h"
-#include "wx/treectrl.h"
+#include <stdint.h>                         // uint32_t
+#include <wx/list.h>                        // WX_DECLARE_LIST
+#include <wx/treectrl.h>                    // wxTreeCtrl wxTreeItemId
 
+class CSafeFile;
 class CTag;
+class ServerMet_Struct;
 
 WX_DECLARE_LIST(CTag,TagList);
 
@@ -41,78 +40,78 @@ WX_DECLARE_LIST(CTag,TagList);
 class CServer{
 public:
 	CServer(ServerMet_Struct* in_data);
-	CServer(uint16 in_port, char* i_addr);
+	CServer(uint16_t in_port, char* i_addr);
 	CServer(CServer* pOld);
 	~CServer();
 	void	AddTag(CTag* in_tag)			{taglist->Append(in_tag);}
 	char*	GetListName()					{return listname;}
 	char*	GetFullIP()						{return ipfull;}
 	char*	GetAddress();
-	uint16	GetPort()						{return port;}
+	uint16_t	GetPort()						{return port;}
 	void	FillWindowTags(wxTreeCtrl* wnd,wxTreeItemId rootitem);
 	bool	AddTagFromFile(CSafeFile* servermet);
 	void	SetListName(char* newname);
 	void	SetDescription(char* newdescription);
-	uint32	GetIP()			{return ip;}
-	uint32	GetFiles()						{return files;} 
-	uint32	GetUsers()						{return users;} 
+	uint32_t	GetIP()			{return ip;}
+	uint32_t	GetFiles()						{return files;} 
+	uint32_t	GetUsers()						{return users;} 
 	char*	GetDescription()				{return description;} 
-	uint32	GetPing()						{return ping;} 
-	uint32	GetPreferences()				{return preferences;} 
-	uint32	GetMaxUsers()					{return maxusers;}
-	void	SetMaxUsers(uint32 in_maxusers) {maxusers = in_maxusers;}
-	void	SetUserCount(uint32 in_users)	{users = in_users;}
-	void	SetFileCount(uint32 in_files)	{files = in_files;}
+	uint32_t	GetPing()						{return ping;} 
+	uint32_t	GetPreferences()				{return preferences;} 
+	uint32_t	GetMaxUsers()					{return maxusers;}
+	void	SetMaxUsers(uint32_t in_maxusers) {maxusers = in_maxusers;}
+	void	SetUserCount(uint32_t in_users)	{users = in_users;}
+	void	SetFileCount(uint32_t in_files)	{files = in_files;}
 	void	ResetFailedCount()				{failedcount = 0;} 
 	void	AddFailedCount()				{failedcount++;} 
-	uint32	GetFailedCount()				{return failedcount;} 
-	void	SetID(uint32 newip);
+	uint32_t	GetFailedCount()				{return failedcount;} 
+	void	SetID(uint32_t newip);
 	char*	GetDynIP()						{return dynip;}
 	bool	HasDynIP()						{return dynip;}
 	void	SetDynIP(char* newdynip);
-	uint32	GetLastPinged()					{return lastpinged;}
-	void	SetLastPinged(uint32 in_lastpinged)	{lastpinged = in_lastpinged;}
-	void	SetPing(uint32 in_ping)					{ping = in_ping;}
-	void	SetPreference(uint32 in_preferences)	{preferences = in_preferences;}
+	uint32_t	GetLastPinged()					{return lastpinged;}
+	void	SetLastPinged(uint32_t in_lastpinged)	{lastpinged = in_lastpinged;}
+	void	SetPing(uint32_t in_ping)					{ping = in_ping;}
+	void	SetPreference(uint32_t in_preferences)	{preferences = in_preferences;}
 	void	SetIsStaticMember(bool in)				{staticservermember=in;}
 	bool	IsStaticMember()						{return staticservermember;}
-	uint32	GetChallenge()							{return challenge;}
-	void	SetChallenge(uint32 in_challenge)		{challenge = in_challenge;}
-	uint32	GetSoftFiles()						{return softfiles;}
-	void	SetSoftFiles(uint32 in_softfiles)			{softfiles = in_softfiles;}
-	uint32	GetHardFiles()						{return hardfiles;}
-	void	SetHardFiles(uint32 in_hardfiles)			{hardfiles = in_hardfiles;}
+	uint32_t	GetChallenge()							{return challenge;}
+	void	SetChallenge(uint32_t in_challenge)		{challenge = in_challenge;}
+	uint32_t	GetSoftFiles()						{return softfiles;}
+	void	SetSoftFiles(uint32_t in_softfiles)			{softfiles = in_softfiles;}
+	uint32_t	GetHardFiles()						{return hardfiles;}
+	void	SetHardFiles(uint32_t in_hardfiles)			{hardfiles = in_hardfiles;}
 	const	wxString GetVersion() const				{return m_strVersion;}
-	void	SetVersion(LPCTSTR pszVersion)				{m_strVersion = pszVersion;}
-	void	SetTCPFlags(uint32 uFlags)				{m_uTCPFlags = uFlags;}
-	uint32	GetTCPFlags() const					{return m_uTCPFlags;}
-	void	SetUDPFlags(uint32 uFlags)				{m_uUDPFlags = uFlags;}
-	uint32	GetUDPFlags() const					{return m_uUDPFlags;}
+	void	SetVersion(unsigned char* pszVersion)				{m_strVersion = pszVersion;}
+	void	SetTCPFlags(uint32_t uFlags)				{m_uTCPFlags = uFlags;}
+	uint32_t	GetTCPFlags() const					{return m_uTCPFlags;}
+	void	SetUDPFlags(uint32_t uFlags)				{m_uUDPFlags = uFlags;}
+	uint32_t	GetUDPFlags() const					{return m_uUDPFlags;}
 
 private:
-	uint32		challenge;
-	uint32		lastpinged;
-	uint32		files;
-	uint32		users;
-	uint32		maxusers;
-	uint32		preferences;
-	uint32		ping;
+	uint32_t		challenge;
+	uint32_t		lastpinged;
+	uint32_t		files;
+	uint32_t		users;
+	uint32_t		maxusers;
+	uint32_t		preferences;
+	uint32_t		ping;
 	char*		description;
 	char*		listname;
 	char*		dynip;
-	uint32		tagcount;
+	uint32_t		tagcount;
 	char		ipfull[17];
-	uint32		ip;
-	uint16		port;
-	uint32		failedcount; 
+	uint32_t		ip;
+	uint16_t		port;
+	uint32_t		failedcount; 
 	TagList* taglist;
 	//CTypedPtrList<CPtrList, CTag*>*	taglist;
-	uint8		staticservermember;
-	uint32		softfiles;
-	uint32		hardfiles;
+	uint8_t		staticservermember;
+	uint32_t		softfiles;
+	uint32_t		hardfiles;
 	wxString		m_strVersion;
-	uint32		m_uTCPFlags;
-	uint32		m_uUDPFlags;
+	uint32_t		m_uTCPFlags;
+	uint32_t		m_uUDPFlags;
 };
 
 #endif
