@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -28,6 +28,8 @@
 #include "Preferences.h"                    // CPreferences::GetUseHash
 #	include "SearchDlg.h"
 #	include "SearchList.h"
+#include "ServerList.h"                     // CServerList
+#include "ServerListCtrl.h"                 // CServerListCtrl - audited 5 Nov 2004
 #	include "ServerSocket.h"
 #	include "ServerWnd.h"
 #	include "SharedFileList.h"
@@ -38,7 +40,7 @@
 #	include "xmuleDlg.h"
 #endif
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <ctime>
 #include <iostream>                         // Needed for std::cout std::endl
@@ -79,7 +81,7 @@ void CServerConnect::TryAnotherConnectionrequest()
     }
 }
 
-void CServerConnect::ConnectToAnyServer(uint32 startAt, bool prioSort, bool isAuto)
+void CServerConnect::ConnectToAnyServer(uint32_t startAt, bool prioSort, bool isAuto)
 {
     lastStartAt = startAt;
     StopConnectionTry();
@@ -179,17 +181,17 @@ void CServerConnect::ConnectionEstablished(CServerSocket *sender)
         }
         CMemFile *data = new CMemFile();
         data->Write(theApp.glob_prefs->GetUserHash(), 16);
-        uint32 clientid = GetClientID();
+        uint32_t clientid = GetClientID();
         data->Write( &clientid, 4);
-        uint16 port = static_cast<uint16>(theApp.dynprefs->Get<long>("tcp-port"));
+        uint16_t port = static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port"));
         data->Write( &port, 2);
-        uint32 tagcount = 4;
+        uint32_t tagcount = 4;
         data->Write( &tagcount, 4);
         CTag tagName(CT_NAME, const_cast<char *>(theApp.dynprefs->Get<wxString>("nickname").c_str()));
         tagName.WriteTagToFile(data);
         CTag tagVersion(CT_VERSION, EDONKEYVERSION);
         tagVersion.WriteTagToFile(data);
-        CTag tagPort(CT_PORT, static_cast<uint16>(theApp.dynprefs->Get<long>("tcp-port")));
+        CTag tagPort(CT_PORT, static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port")));
         tagPort.WriteTagToFile(data);
         // I am zlib aware! :-):
         CTag tagFlags(0x20, 0x00000001);
@@ -351,10 +353,12 @@ void CServerConnect::ConnectionFailed(CServerSocket *sender)
                     if (tmpsock == sender)
                     {
                         connectionattempts.erase(it->first);
+                        delete tmpsock;
                         break;
                     }
                     ++it;
                 }
+
                 TryAnotherConnectionrequest();
             }
         }
@@ -379,15 +383,13 @@ void CServerConnect::CheckForTimeout()
         if (!tmpsock)
         {
             theApp.xmuledlg->AddLogLine(false, "Error: Socket invalid at timeoutcheck");
-            connectionattempts.erase(it);
-            --it;
+            connectionattempts.erase(it++);
             continue;
         }
         else if (tmpkey <= maxage)
         {
             theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_CONTIMEOUT), tmpsock->info.GetData(), tmpsock->cur_server->GetFullIP(), tmpsock->cur_server->GetPort());
-            connectionattempts.erase(it);
-            --it;
+            connectionattempts.erase(it++);
             TryAnotherConnectionrequest();
             DestroySocket(tmpsock);
             continue;
@@ -406,7 +408,7 @@ bool CServerConnect::Disconnect()
         connected = false;
         theApp.xmuledlg->ShowConnectionState(false, "");
         theApp.stat_serverConnectTime = 0;
-        //theApp.xmuledlg->serverwnd->servermsgbox.AppendText(CString("\n\n\n\n"));
+        //theApp.xmuledlg->serverwnd->servermsgbox.AppendText(wxString("\n\n\n\n"));
         return true;
     }
     else
@@ -425,7 +427,7 @@ CServerConnect::CServerConnect(CServerList *in_serverlist, CPreferences *in_pref
     singleconnecting = false;
     wxIPV4address tmp;
     tmp.AnyAddress();
-    tmp.Service(static_cast<uint16>(theApp.dynprefs->Get<long>("tcp-port")) + 10);
+    tmp.Service(static_cast<uint16_t>(theApp.dynprefs->Get<long>("tcp-port")) + 10);
     // initalize socket for udp packets:
     udpsocket = new CUDPSocket(this, tmp);
     //udpsocket->Create();
@@ -438,7 +440,7 @@ CServerConnect::CServerConnect(CServerList *in_serverlist, CPreferences *in_pref
 
 CServerConnect::~CServerConnect()
 {
-/*  K...I have *no* idea how this got here or what I was thinking...it causes crashes, so it's gone.
+/*  K...I have *no* idea how this got here or what I was thinking...it causes crashes, so it's gone.*/
     for (POSITION pos = m_lstOpenSockets.GetHeadPosition() ; pos != NULL ;)
     {
         CServerSocket* tmp((CServerSocket *)m_lstOpenSockets.GetNext(pos));
@@ -446,7 +448,7 @@ CServerConnect::~CServerConnect()
         tmp->Destroy();
         delete tmp;
     }
-*/
+
     m_idRetryTimer.Stop();
     StopConnectionTry();
     DestroySocket(connectedsocket);
@@ -466,7 +468,7 @@ CServer *CServerConnect::GetCurrentServer()
     }
 }
 
-void CServerConnect::SetClientID(uint32 newid)
+void CServerConnect::SetClientID(uint32_t newid)
 {
     clientid = newid;
     theApp.xmuledlg->ShowConnectionState(IsConnected(), GetCurrentServer()->GetListName());
@@ -526,7 +528,7 @@ void CServerConnect::InitLocalIP()
     }
 }
 
-bool CServerConnect::IsLocalServer(uint32 dwIP, uint16 nPort)
+bool CServerConnect::IsLocalServer(uint32_t dwIP, uint16_t nPort)
 {
     if (IsConnected())
     {
