@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -24,17 +24,9 @@
 #ifndef _SOCKETS_H
 #define _SOCKETS_H
 
-#include "wintypes.h"
-#include "types.h"
-#include "server.h"
-#include "ServerListCtrl.h"
-#include "server.h"
-#include "ServerList.h"
-//#include "ServerSocket.h"
-
-#include <map>                              // std::map
-#include <stdint.h>                         // uint32_t
-#include <wx/socket.h>
+#include <map>                              // Needed for std::map
+#include <stdint.h>                         // Needed for uint32_t
+#include <wx/timer.h>                       // Needed for wxTimer
 
 #define CS_FATALERROR	-5
 #define CS_DISCONNECTED	-4
@@ -48,6 +40,8 @@
 #define CS_RETRYCONNECTTIME  30 // seconds
 
 class CPreferences;
+class CServer;
+class CServerList;
 class CServerSocket;
 class CUDPSocket;
 class Packet;
@@ -60,7 +54,7 @@ public:
 	void	ConnectionEstablished(CServerSocket* sender);
 	
 	void	ConnectToAnyServer() {ConnectToAnyServer(0,true,true);}
-	void	ConnectToAnyServer(uint32 startAt,bool prioSort=false,bool isAuto=true);
+	void	ConnectToAnyServer(uint32_t startAt,bool prioSort=false,bool isAuto=true);
 	void	ConnectToServer(CServer* toconnect, bool multiconnect=false);
 	void	StopConnectionTry();
 	//static  VOID CALLBACK RetryConnectCallback(HWND hWnd, UINT nMsg, UINT nId, DWORD dwTime);
@@ -74,11 +68,11 @@ public:
 	bool	IsConnected()	{return connected;}
 	wxUint32	GetClientID()		{return clientid;}
 	CServer*	GetCurrentServer();
-	uint32	clientid;
-	uint8	pendingConnects;
+	uint32_t	clientid;
+	uint8_t	pendingConnects;
 	bool	IsLowID()		{return (clientid < 16777216);}
-	void	SetClientID(uint32 newid);
-	bool	IsLocalServer(uint32 dwIP, uint16 nPort);
+	void	SetClientID(uint32_t newid);
+	bool	IsLocalServer(uint32_t dwIP, uint16_t nPort);
 	void	TryAnotherConnectionrequest();
 	bool	IsSingleConnect()	{return singleconnecting;}
 	void	InitLocalIP();
@@ -88,8 +82,8 @@ private:
 	bool	connecting;
 	bool	singleconnecting;
 	bool	connected;
-	int8	max_simcons;
-	uint32 lastStartAt;
+	int8_t	max_simcons;
+	uint32_t lastStartAt;
 	CPreferences*	app_prefs;
 	CServerSocket*	connectedsocket;
 	CServerList*	used_list;
