@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -22,14 +22,12 @@
 #ifndef _UPDOWNCLIENT_H
 #define _UPDOWNCLIENT_H
 
-#include "mfc.h"                            // CString
-#include "wintypes.h"
-#include "types.h"
-#include "ClientCredits.h"                  // Needed for some unknown reason
-#include "BarShader.h"
-#include "otherfunctions.h"                 // Needed for GetTickCount
+#include "mfc.h"                            // Needed for wxString - audited 4 Nov 2004
+#include "wintypes.h"                       // Needed for BYTE DWORD - audited 4 Nov 2004
+#include "BarShader.h"                      // Needed for CBarShader - audited 5 Nov 2004
 
-#include <iostream>                         // std::cout std::endl
+#include <iostream>                         // Needed for std::cout std::endl
+#include <stdint.h>                         // Needed for uint16_t uint32_t
 
 class CClientCredits;
 class CKnownFile;
@@ -42,7 +40,7 @@ class Pending_Block_Struct;
 class Requested_Block_Struct;
 class Requested_File_Struct;
 typedef unsigned char byte;
-extern inline long GetTickCount();
+extern long GetTickCount();
 
 
 // uploadstate
@@ -113,32 +111,32 @@ class CUpDownClient
 public:
 	//base
 	CUpDownClient(CClientReqSocket* sender = 0);
-	CUpDownClient(uint16 in_port, uint32 in_userid, uint32 in_serverup, uint16 in_serverport,CPartFile* in_reqfile);
+	CUpDownClient(uint16_t in_port, uint32_t in_userid, uint32_t in_serverup, uint16_t in_serverport,CPartFile* in_reqfile);
 	~CUpDownClient();
 	void			Destroy();
 	void			Disconnected();
 	bool			TryToConnect(bool bIgnoreMaxCon = false);
 	void			ConnectionEstablished();
-	uint32			GetUserID()					{return m_nUserID;}
-	void			SetUserID(wxUint32 nUserID)			{ m_nUserID=nUserID; }
+	uint32_t			GetUserID()					{return m_nUserID;}
+	void			SetUserID(uint32_t nUserID)			{ m_nUserID=nUserID; }
 	char*			GetUserName()				{return m_pszUsername;}
-	uint32			GetIP()						{return m_dwUserIP;}
+	uint32_t			GetIP()						{return m_dwUserIP;}
 	bool			HasLowID()					{return (m_nUserID < 16777216);}
 	char*			GetFullIP()					{return m_szFullUserIP;}
-	uint32			GetUserPort()				{return m_nUserPort;}
-	uint32			GetTransferedUp()			{return m_nTransferedUp;}
-	uint32			GetTransferedDown()			{return m_nTransferedDown;}
-	uint32			GetServerIP()				{return m_dwServerIP;}
-	void			SetServerIP(wxUint32 nIP)		{ m_dwServerIP=nIP; }
-	uint16			GetServerPort()				{return m_nServerPort;}
-	void			SetServerPort(wxUint16 nPort)		{ m_nServerPort=nPort; }
-	uchar*			GetUserHash()				{return (uchar*)m_achUserHash;}
-	void			SetUserHash(uchar* achUserHash);
+	uint32_t			GetUserPort()				{return m_nUserPort;}
+	uint32_t			GetTransferedUp()			{return m_nTransferedUp;}
+	uint32_t			GetTransferedDown()			{return m_nTransferedDown;}
+	uint32_t			GetServerIP()				{return m_dwServerIP;}
+	void			SetServerIP(uint32_t nIP)		{ m_dwServerIP=nIP; }
+	uint16_t			GetServerPort()				{return m_nServerPort;}
+	void			SetServerPort(uint16_t nPort)		{ m_nServerPort=nPort; }
+	unsigned char*			GetUserHash()				{return (unsigned char*)m_achUserHash;}
+	void			SetUserHash(unsigned char* achUserHash);
 	bool			HasValidHash()				{return ((int*)m_achUserHash)[0] != 0 || ((int*)m_achUserHash)[1] != 0 ||
 												        ((int*)m_achUserHash)[2] != 0 || ((int*)m_achUserHash)[3] != 0; }
 	int			GetHashType();
-	uint32			GetVersion()				{return m_nClientVersion;}
-	uint8			GetMuleVersion()			{if(m_byEmuleVersion==0x99) return 0x42; else return m_byEmuleVersion;}
+	uint32_t			GetVersion()				{return m_nClientVersion;}
+	uint8_t			GetMuleVersion()			{if(m_byEmuleVersion==0x99) return 0x42; else return m_byEmuleVersion;}
 	bool			ExtProtocolAvailable()		{return m_bEmuleProtocol;}
 	bool			IsEmuleClient()				{return m_byEmuleVersion;}
 	CClientCredits* 	Credits()					{return credits;}
@@ -146,51 +144,51 @@ public:
 	char*			GetClientFilename()			{return m_pszClientFilename;}
 	wxString		GetClientFilename_NEW() const		{return m_strClientFilename;}
 	bool			SupportsUDP()				{return m_byUDPVer != 0 && m_nUDPPort != 0;}
-	uint16			GetUDPPort()				{return m_nUDPPort;}
-	void			SetUDPPort(uint16 nPort)	{ m_nUDPPort = nPort; }
-	uint8			GetUDPVersion()				{return m_byUDPVer;}
-	uint8			GetExtendedRequestsVersion(){return m_byExtendedRequestsVer;}
+	uint16_t			GetUDPPort()				{return m_nUDPPort;}
+	void			SetUDPPort(uint16_t nPort)	{ m_nUDPPort = nPort; }
+	uint8_t			GetUDPVersion()				{return m_byUDPVer;}
+	uint8_t			GetExtendedRequestsVersion(){return m_byExtendedRequestsVer;}
 	bool			IsFriend()					{return m_Friend != NULL;}
 	float			GetCompression()	{return (float)compressiongain/notcompressed*100.0f;} // Add rod show compression
 	void			ResetCompressionGain() {compressiongain = 0; notcompressed=1;} // Add show compression
 
 	void			RequestSharedFileList();
-	void			ProcessSharedFileList(char* pachPacket, uint32 nSize);
+	void			ProcessSharedFileList(char* pachPacket, uint32_t nSize);
 	
         wxString                 GetUploadFileInfo();
 
 	void			SetUserName(char* pszNewName);
 	EClientSoftware		GetClientSoft()				{return m_clientSoft;}
 	void			ReGetClientSoft();
-	bool			ProcessHelloAnswer(char* pachPacket, uint32 nSize);
-	bool			ProcessHelloPacket(char* pachPacket, uint32 nSize);
+	bool			ProcessHelloAnswer(char* pachPacket, uint32_t nSize);
+	bool			ProcessHelloPacket(char* pachPacket, uint32_t nSize);
 	void			SendHelloAnswer();
 	void			SendHelloPacket();
 	void			SendMuleInfoPacket(bool bAnswer);
-	void			ProcessMuleInfoPacket(char* pachPacket, uint32 nSize);
-	void			ProcessMuleCommentPacket(char* pachPacket, uint32 nSize);
+	void			ProcessMuleInfoPacket(char* pachPacket, uint32_t nSize);
+	void			ProcessMuleCommentPacket(char* pachPacket, uint32_t nSize);
 	bool			Compare(CUpDownClient* tocomp);
 	void			SetLastStateChange()	{m_dwLastStateChange = ::GetTickCount();}
 	void			SetLastSrcReqTime()		{m_dwLastSourceRequest = ::GetTickCount();}
 	void			SetLastSrcAnswerTime()		{m_dwLastSourceAnswer = ::GetTickCount();}
 	void			SetLastAskedForSources()	{m_dwLastAskedForSources = ::GetTickCount();}
-	uint32			GetLastStateChange()	{return m_dwLastStateChange;}
-	uint32			GetLastSrcReqTime()			{return m_dwLastSourceRequest;}
-	uint32			GetLastSrcAnswerTime()		{return m_dwLastSourceAnswer;}
-	uint32			GetLastAskedForSources()	{ return m_dwLastAskedForSources;}
+	uint32_t			GetLastStateChange()	{return m_dwLastStateChange;}
+	uint32_t			GetLastSrcReqTime()			{return m_dwLastSourceRequest;}
+	uint32_t			GetLastSrcAnswerTime()		{return m_dwLastSourceAnswer;}
+	uint32_t			GetLastAskedForSources()	{ return m_dwLastAskedForSources;}
 	bool			GetFriendSlot()				{return m_bFriendSlot;}
 	void			SetFriendSlot(bool bNV)		{m_bFriendSlot = bNV;}
 	void			SetCommentDirty(bool bDirty = true) {m_bCommentDirty = bDirty;}
-	uint8			GetSourceExchangeVersion()	{return m_bySourceExchangeVer;}
+	uint8_t			GetSourceExchangeVersion()	{return m_bySourceExchangeVer;}
 
 	void			SendPublicKeyPacket();
 	void			SendSignaturePacket();
-	void			ProcessPublicKeyPacket(uchar* pachPacket, uint32 nSize);
-	void			ProcessSignaturePacket(uchar* pachPacket, uint32 nSize);
-	uint8			GetSecureIdentState()		{return m_SecureIdentState;}
+	void			ProcessPublicKeyPacket(unsigned char* pachPacket, uint32_t nSize);
+	void			ProcessSignaturePacket(unsigned char* pachPacket, uint32_t nSize);
+	uint8_t			GetSecureIdentState()		{return m_SecureIdentState;}
 	void			SendSecIdentStatePacket();
-	void			ProcessSecIdentStatePacket(unsigned char* pachPacket,wxUint32 nSize);
-	uint8			GetInfoPacketsReceived() const { return m_byInfopacketsReceived; }
+	void			ProcessSecIdentStatePacket(unsigned char* pachPacket,uint32_t nSize);
+	uint8_t			GetInfoPacketsReceived() const { return m_byInfopacketsReceived; }
 	void			InfoPacketsReceived();
 	void			ResetFileStatusInfo();
 
@@ -198,61 +196,63 @@ public:
 	bool			SafeSendPacket(Packet* packet);
 
 	CClientReqSocket*	socket;
+private:
 	CClientCredits*		credits;
+public:
 	CFriend*			m_Friend;
 	//upload
-	uint32	compressiongain; /// Add show compression
-	uint32  notcompressed; // Add show compression
-	uint8			GetUploadState()			{return m_byUploadState;}
-	void			SetUploadState(uint8 news)	{m_byUploadState = news;}
-	uint32			GetWaitStartTime()			{return m_dwWaitTime;}
-	uint32			GetWaitTime()				{return m_dwUploadTime-m_dwWaitTime;}
+	uint32_t	compressiongain; /// Add show compression
+	uint32_t  notcompressed; // Add show compression
+	uint8_t			GetUploadState()			{return m_byUploadState;}
+	void			SetUploadState(uint8_t news)	{m_byUploadState = news;}
+	uint32_t			GetWaitStartTime()			{return m_dwWaitTime;}
+	uint32_t			GetWaitTime()				{return m_dwUploadTime-m_dwWaitTime;}
 	bool			IsDownloading()				{return (m_byUploadState == US_UPLOADING);}
 	bool			HasBlocks()					{return !(m_BlockSend_queue.IsEmpty() && m_BlockRequests_queue.IsEmpty());}
-	uint32			GetDatarate()				{return m_nUpDatarate;}	
-	uint32			GetScore(bool sysvalue, bool isdownloading = false, bool onlybasevalue = false);
+	uint32_t			GetDatarate()				{return m_nUpDatarate;}	
+	uint32_t			GetScore(bool sysvalue, bool isdownloading = false, bool onlybasevalue = false);
 	void			AddReqBlock(Requested_Block_Struct* reqblock);
 	bool			CreateNextBlockPackage();
-	void			SetUpStartTime(uint32 dwTime = 0);
-	uint32			GetUpStartTimeDelay()		{return ::GetTickCount() - m_dwUploadTime;}
-	void			SetWaitStartTime(uint32 dwTime = 0);
+	void			SetUpStartTime(uint32_t dwTime = 0);
+	uint32_t			GetUpStartTimeDelay()		{return ::GetTickCount() - m_dwUploadTime;}
+	void			SetWaitStartTime(uint32_t dwTime = 0);
 	void			SendHashsetPacket(char* forfileid);
-	void			SetUploadFileID(uchar* tempreqfileid);
-	uchar*			GetUploadFileID()	{return requpfileid;}
+	void			SetUploadFileID(unsigned char* tempreqfileid);
+	unsigned char*			GetUploadFileID()	{return requpfileid;}
 	CPartFile*		GetDownloadFile()	{return reqfile;}
 	void			SetDownloadFile(CPartFile*);
-	uint32			SendBlockData(uint32 maxammount);
+	uint32_t			SendBlockData(uint32_t maxammount);
 	void			ClearUploadBlockRequests();
 	void			SendRankingInfo();
 	void			SendCommentInfo(CKnownFile *file);
-	uint32			GetLastAskedDelay();
-	void			AddRequestCount(uchar* fileid);
+	uint32_t			GetLastAskedDelay();
+	void			AddRequestCount(unsigned char* fileid);
 	bool 			IsDifferentPartBlock();
 	void			UnBan();
 	void			Ban();
-	uint32			GetBanTime()				{return m_dwBanTime;}
-	uint32			GetAskedCount()				{return m_cAsked;}
+	uint32_t			GetBanTime()				{return m_dwBanTime;}
+	uint32_t			GetAskedCount()				{return m_cAsked;}
 	void			AddAskedCount()				{m_cAsked++;}
-	void			SetAskedCount( uint32 m_cInAsked)				{m_cAsked = m_cInAsked;}
+	void			SetAskedCount( uint32_t m_cInAsked)				{m_cAsked = m_cInAsked;}
 	void			FlushSendBlocks();			// call this when you stop upload, or the socket might be not able to send
 	void			SetLastUpRequest()			{m_dwLastUpRequest = ::GetTickCount();}
-	uint32			GetLastUpRequest()			{return m_dwLastUpRequest;}
+	uint32_t			GetLastUpRequest()			{return m_dwLastUpRequest;}
 	void			UDPFileReasked();
-	uint32			GetSessionUp()			{return m_nTransferedUp - m_nCurSessionUp;}
+	uint32_t			GetSessionUp()			{return m_nTransferedUp - m_nCurSessionUp;}
 	void			ResetSessionUp()		{m_nCurSessionUp = m_nTransferedUp;} 
-	void			ProcessUpFileStatus(char* packet,uint32 size);
-	uint16			GetUpPartCount()			{return m_nUpPartCount;}
+	void			ProcessUpFileStatus(char* packet,uint32_t size);
+	uint16_t			GetUpPartCount()			{return m_nUpPartCount;}
 	void			DrawUpStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat);
 
 	//download
-	uint32			GetAskedCountDown()				{return m_cDownAsked;} //<<--
+	uint32_t			GetAskedCountDown()				{return m_cDownAsked;} //<<--
 	void			AddAskedCountDown()				{m_cDownAsked++;}
-	void			SetAskedCountDown( uint32 m_cInDownAsked)				{m_cDownAsked = m_cInDownAsked;}
-	uint8			GetDownloadState()			{return m_nDownloadState;}
-	void			SetDownloadState(uint8 byNewState);
-	uint32			GetLastAskedTime()			{return m_dwLastAskedTime;}
+	void			SetAskedCountDown( uint32_t m_cInDownAsked)				{m_cDownAsked = m_cInDownAsked;}
+	uint8_t			GetDownloadState()			{return m_nDownloadState;}
+	void			SetDownloadState(uint8_t byNewState);
+	uint32_t			GetLastAskedTime()			{return m_dwLastAskedTime;}
 	
-    bool IsPartAvailable(uint16 iPart)
+    bool IsPartAvailable(uint16_t iPart)
     {
         bool status = false;
         try
@@ -268,7 +268,7 @@ public:
         return status;
     }
 
-    bool IsUpPartAvailable(uint16 iPart)
+    bool IsUpPartAvailable(uint16_t iPart)
     {
         bool status = false;
         try
@@ -283,57 +283,57 @@ public:
 
         return status;
     }
-	uint8*			GetPartStatus()				{return m_abyPartStatus;}
-	uint32			GetDownloadDatarate()		{return m_nDownDatarate;}
-	uint16			GetRemoteQueueRank()		{return m_nRemoteQueueRank;}
+	uint8_t*			GetPartStatus()				{return m_abyPartStatus;}
+	uint32_t			GetDownloadDatarate()		{return m_nDownDatarate;}
+	uint16_t			GetRemoteQueueRank()		{return m_nRemoteQueueRank;}
 	void			SetRemoteQueueFull( bool flag )	{m_bRemoteQueueFull = flag;}
 	bool			IsRemoteQueueFull()			{return m_bRemoteQueueFull;}
-	void			SetRemoteQueueRank(uint16 nr);
+	void			SetRemoteQueueRank(uint16_t nr);
 	void			DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat);
 	void			AskForDownload();
 	void			SendFileRequest_HOPE();
 	void			SendFileRequest();
-	void			ProcessFileInfo(char* packet,uint32 size);
-	void			ProcessFileStatus(char* packet,uint32 size);
-	void			ProcessHashSet(unsigned char* packet,uint32 size);
+	void			ProcessFileInfo(char* packet,uint32_t size);
+	void			ProcessFileStatus(char* packet,uint32_t size);
+	void			ProcessHashSet(unsigned char* packet,uint32_t size);
 	bool			AddRequestForAnotherFile(CPartFile* file);
 	void			SendBlockRequests();
-	void			ProcessBlockPacket(char* packet, uint32 size, bool packed = false);
-	uint32			CalculateDownloadRate();
-	uint16			GetAvailablePartCount();
+	void			ProcessBlockPacket(char* packet, uint32_t size, bool packed = false);
+	uint32_t			CalculateDownloadRate();
+	uint16_t			GetAvailablePartCount();
 	//			SwapToAnotherFile(bool bIgnoreNoNeeded = false);   Razor 1a - Modif by MikaelB 
 
-	void			UDPReaskACK(uint16 nNewQR);
+	void			UDPReaskACK(uint16_t nNewQR);
 	void			UDPReaskFNF();
 	void			UDPReaskForDownload();
 	bool			IsSourceRequestAllowed();
 
-	uint16 GetUpCompleteSourcesCount() { return m_nUpCompleteSourcesCount; }
-	void SetUpCompleteSourcesCount(uint16 n) { m_nUpCompleteSourcesCount = n; }
+	uint16_t GetUpCompleteSourcesCount() { return m_nUpCompleteSourcesCount; }
+	void SetUpCompleteSourcesCount(uint16_t n) { m_nUpCompleteSourcesCount = n; }
 	
 	int				sourcesslot;
 
 	//chat
-	uint8			GetChatState()				{return m_byChatstate;}
-	void			SetChatState(uint8 nNewS)	{m_byChatstate = nNewS;}
+	uint8_t			GetChatState()				{return m_byChatstate;}
+	void			SetChatState(uint8_t nNewS)	{m_byChatstate = nNewS;}
 	bool			m_bIsSpammer;
-	uint8			m_cMessagesReceived; //Count of chatmessages he sent to me
-	uint8			m_cMessagesSend; //Count of chatmessages i sent to him
+	uint8_t			m_cMessagesReceived; //Count of chatmessages he sent to me
+	uint8_t			m_cMessagesSend; //Count of chatmessages i sent to him
 
 	//File Comment 
-    CString			GetFileComment()			{return m_strComment;} 
-    void			SetFileComment(char *desc)	{m_strComment.Format("%s",desc);}
-    uint8			GetFileRate()				{return m_iRate;}
-    void			SetFileRate(int8 iNewRate)	{m_iRate=iNewRate;}
+    wxString			GetFileComment()			{return m_strComment;} 
+    void			SetFileComment(char *desc)	{m_strComment.Printf("%s",desc);}
+    uint8_t			GetFileRate()				{return m_iRate;}
+    void			SetFileRate(int8_t iNewRate)	{m_iRate=iNewRate;}
 
 	// Barry - Process zip file as it arrives, don't need to wait until end of block
-	int unzip(Pending_Block_Struct *block, BYTE *zipped, uint32 lenZipped, BYTE **unzipped, uint32 *lenUnzipped, bool recursive = false);
+	int unzip(Pending_Block_Struct *block, BYTE *zipped, uint32_t lenZipped, BYTE **unzipped, uint32_t *lenUnzipped, bool recursive = false);
 	// Barry - Sets string to show parts downloading, eg NNNYNNNNYYNYN
 	void ShowDownloadingParts(wxString &partsYN);
 	void UpdateDisplayedInfo(bool force=false);
 	int  GetFileListRequested() { return m_iFileListRequested; }
 	void SetFileListRequested(int iFileListRequested) { m_iFileListRequested = iFileListRequested; }
-	uint8	m_cFailed;
+	uint8_t	m_cFailed;
     bool deletethis;
     bool SpecialPerson;
 private:
@@ -345,31 +345,31 @@ private:
 	void	SendHelloTypePacket(CMemFile* data);
 	bool	m_bIsBotuser;
 //	bool	isfriend;
-	uint32	m_dwUserIP;
-	uint32	m_dwServerIP;
-	uint32	m_nUserID;
-	int16	m_nUserPort;
-	int16	m_nServerPort;
-	uint32	m_nClientVersion;
-	uint32	m_nUpDatarate;
-	uint32	dataratems;
-	uint32	m_cSendblock;
-	uint8	m_byEmuleVersion;
-	uint8	m_byDataCompVer;
+	uint32_t	m_dwUserIP;
+	uint32_t	m_dwServerIP;
+	uint32_t	m_nUserID;
+	int16_t	m_nUserPort;
+	int16_t	m_nServerPort;
+	uint32_t	m_nClientVersion;
+	uint32_t	m_nUpDatarate;
+	uint32_t	dataratems;
+	uint32_t	m_cSendblock;
+	uint8_t	m_byEmuleVersion;
+	uint8_t	m_byDataCompVer;
 	bool	m_bEmuleProtocol;
 	char*	m_pszUsername;
 	char	m_szFullUserIP[21];
 	char	m_achUserHash[16];
-	uint16	m_nUDPPort;
-	uint8	m_byUDPVer;
-	uint8	m_bySourceExchangeVer;
-	uint8	m_byAcceptCommentVer;
-	uint8	m_byExtendedRequestsVer;
+	uint16_t	m_nUDPPort;
+	uint8_t	m_byUDPVer;
+	uint8_t	m_bySourceExchangeVer;
+	uint8_t	m_byAcceptCommentVer;
+	uint8_t	m_byExtendedRequestsVer;
 	EClientSoftware	m_clientSoft;
-	uint32	m_dwLastSourceRequest;
-	uint32	m_dwLastSourceAnswer;
-	uint32  m_dwLastAskedForSources;
-	uint32  m_dwLastStateChange;
+	uint32_t	m_dwLastSourceRequest;
+	uint32_t	m_dwLastSourceAnswer;
+	uint32_t  m_dwLastAskedForSources;
+	uint32_t  m_dwLastStateChange;
 	int	m_iFileListRequested;
 	bool	m_bFriendSlot;
 	bool	m_bCommentDirty;
@@ -378,44 +378,44 @@ private:
 	bool	m_bGPLEvildoer;
 	bool	m_bPreviewReqPending;
 	bool	m_bPreviewAnsPending;
-	uint16	m_nKadPort;
+	uint16_t	m_nKadPort;
 	bool	m_bMultiPacket;
 
 	ESecureIdentState	m_SecureIdentState;
-	uint8	m_byInfopacketsReceived;
-	uint32	m_dwLastSignatureIP;
-	uint8	m_bySupportSecIdent;
+	uint8_t	m_byInfopacketsReceived;
+	uint32_t	m_dwLastSignatureIP;
+	uint8_t	m_bySupportSecIdent;
 	bool	m_bySupportsPreview;
 	
-	uint32	m_byCompatibleClient;
+	uint32_t	m_byCompatibleClient;
 	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
 	DWORD	m_lastRefreshedDLDisplay;
 
 	//upload
-	void CreateStandartPackets(byte* data,uint32 togo, Requested_Block_Struct* currentblock);
-	void CreatePackedPackets(byte* data,uint32 togo, Requested_Block_Struct* currentblock);
+	void CreateStandartPackets(byte* data,uint32_t togo, Requested_Block_Struct* currentblock);
+	void CreatePackedPackets(byte* data,uint32_t togo, Requested_Block_Struct* currentblock);
 	bool		m_bBanned;
-	uint32		m_nTransferedUp;
-	uint8		m_byUploadState;
-	uint32		m_dwWaitTime;
-	uint32		m_dwUploadTime;
-	uint32		m_nMaxSendAllowed;
-	uint32		m_nAvUpDatarate;
-	uint32		m_cAsked;
-	uint32		m_dwLastUpRequest;
-	uint32		m_dwBanTime;
+	uint32_t		m_nTransferedUp;
+	uint8_t		m_byUploadState;
+	uint32_t		m_dwWaitTime;
+	uint32_t		m_dwUploadTime;
+	uint32_t		m_nMaxSendAllowed;
+	uint32_t		m_nAvUpDatarate;
+	uint32_t		m_cAsked;
+	uint32_t		m_dwLastUpRequest;
+	uint32_t		m_dwBanTime;
 	bool		m_bUsedComprUp;	//only used for interface output
-	uint32		m_nCurSessionUp;
-	uint16		m_nUpPartCount;
+	uint32_t		m_nCurSessionUp;
+	uint16_t		m_nUpPartCount;
 	static		CBarShader s_UpStatusBar;
-	uchar		requpfileid[16];
-	uint16 m_nUpCompleteSourcesCount;
+	unsigned char		requpfileid[16];
+	uint16_t m_nUpCompleteSourcesCount;
 	public:
-	uint8*		m_abyUpPartStatus;
-	uint16		m_lastPartAsked;
+	uint8_t*		m_abyUpPartStatus;
+	uint16_t		m_lastPartAsked;
 	DWORD		m_dwEnteredConnectedState;
-	CString		m_strModVersion;
-	uint32		m_nSumForAvgUpDataRate;
+	wxString		m_strModVersion;
+	uint32_t		m_nSumForAvgUpDataRate;
 
 	private:
 	CList<int,int>	 m_AvarageUDR_list;
@@ -427,33 +427,33 @@ private:
 	//download
 	bool		m_bRemoteQueueFull;
 	bool		usedcompressiondown; //only used for interface output
-	uint8		m_nDownloadState;
-	uint16		m_nPartCount;
-	uint32		m_cDownAsked;
-	uint8*		m_abyPartStatus;
-	uint32		m_dwLastAskedTime;
+	uint8_t		m_nDownloadState;
+	uint16_t		m_nPartCount;
+	uint32_t		m_cDownAsked;
+	uint8_t*		m_abyPartStatus;
+	uint32_t		m_dwLastAskedTime;
 	wxString	m_strClientFilename;
 	char*		m_pszClientFilename;
-	uint32		m_nTransferedDown;
-	uint32      m_nLastBlockOffset;   // Patch for show parts that you download [Cax2]
-	uint32		m_nDownDatarate;
-	uint32		m_nDownDataRateMS;
-	uint32		m_nAvDownDatarate;
-	uint16		m_cShowDR;
-	uint32		m_dwLastBlockReceived;
-	uint16		m_nRemoteQueueRank;
+	uint32_t		m_nTransferedDown;
+	uint32_t      m_nLastBlockOffset;   // Patch for show parts that you download [Cax2]
+	uint32_t		m_nDownDatarate;
+	uint32_t		m_nDownDataRateMS;
+	uint32_t		m_nAvDownDatarate;
+	uint16_t		m_cShowDR;
+	uint32_t		m_dwLastBlockReceived;
+	uint16_t		m_nRemoteQueueRank;
 	bool		m_bCompleteSource;
 	bool		m_bReaskPending;
 	bool		m_bUDPPending;
-	uint32		m_nSumForAvgDownDataRate;
+	uint32_t		m_nSumForAvgDownDataRate;
 	bool		m_bHashsetRequested;
 	bool		m_bSharedDirectories;
  	bool		m_bNoViewSharedFiles;
 	bool		m_bSupportsPreview;
 
 	CList<int,int>	 m_AvarageDDR_list;
-	sint32		sumavgDDR;
-	sint32		sumavgUDR;
+	int32_t		sumavgDDR;
+	int32_t		sumavgUDR;
 	CTypedPtrList<CPtrList, Pending_Block_Struct*>	 m_PendingBlocks_list;
  // CTypedPtrList<CPtrList, CPartFile*>	 m_OtherRequests_list;    ---> See Razor 1a modif  : becomes public
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_DownloadBlocks_list;
@@ -461,9 +461,9 @@ private:
 
 	static CBarShader s_StatusBar;
 	// chat
-	uint8 m_byChatstate;
-	CString m_strComment;
-	int8 m_iRate;
+	uint8_t m_byChatstate;
+	wxString m_strComment;
+	int8_t m_iRate;
 
   /* Razor 1a - Modif by MikaelB */
   
@@ -518,14 +518,14 @@ private:
   public:
 
 	bool			thief;  // is a thief ?
-	uint64	getUID() 
+	uint64_t	getUID() 
  	{
-			uint64 ip = ((uint64) m_dwUserIP) << 32;
-			uint64 port = ((uint64) m_nUserPort) << 16;
-			uint64 uid = ip + port;
+			uint64_t ip = ((uint64_t) m_dwUserIP) << 32;
+			uint64_t port = ((uint64_t) m_nUserPort) << 16;
+			uint64_t uid = ip + port;
 			return uid;
 	}		
-		//return ((uint64)m_dwUserIP<<32)+((uint64)m_nUserPort<<16); }
+		//return ((uint64_t)m_dwUserIP<<32)+((uint64_t)m_nUserPort<<16); }
 	int				leechertype;  // what kind of leecher is it ?
   
 };
