@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 // 
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 // 
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -61,7 +61,8 @@
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmuleDlg.h"                       // Needed for CxmuleDlg
 
-#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
+#include <DynPrefs/DynPrefsCtrl.h>          // Needed for wxEVT_PREFS_CHANGED
 
 #include <iostream>                         // Needed for std::cout
 #include <gtk/gtk.h>                        // Needed for GTK_WINDOW_TOPLEVEL
@@ -73,6 +74,8 @@
 
 #include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
+#include <unistd.h>                         // Needed for close
+
 using std::cout;
 using std::endl;
 
@@ -329,7 +332,7 @@ hu+JvF+Z2knW4lRM7VrainKZOdpEvT3EKEBI
 
 void CxmuleApp::ProcessCommand()
 {
-    uint32 num,i;
+    uint32_t num,i;
     wxString St1;
     bool notunderstood=true;
 
@@ -442,13 +445,13 @@ void CxmuleApp::RefreshFiles()
     }
 }
 
-void CxmuleApp::UpdateReceivedBytes(int32 bytesToAdd)
+void CxmuleApp::UpdateReceivedBytes(int32_t bytesToAdd)
 {
     SetTimeOnTransfer();
     stat_sessionReceivedBytes += bytesToAdd;
 }
 
-void CxmuleApp::UpdateSentBytes(int32 bytesToAdd)
+void CxmuleApp::UpdateSentBytes(int32_t bytesToAdd)
 {
     SetTimeOnTransfer();
     stat_sessionSentBytes += bytesToAdd;
@@ -506,11 +509,11 @@ wxString CxmuleApp::CreateED2kSourceLink(CAbstractFile * f)
         xmuledlg->AddLogLine(true, GetResString(IDS_SOURCELINKFAILED));
         return wxString("");
     }
-    uint32 dwID = serverconnect->GetClientID();
+    uint32_t dwID = serverconnect->GetClientID();
     wxString strLink;
     // spaces to dots:
     strLink.Printf("ed2k://|file|%s|%u|%s|/|sources,%i.%i.%i.%i:%i|/", StripInvalidFilenameChars(f->GetFileName(), false) .GetData(),
-    f->GetFileSize(), EncodeBase16(f->GetFileHash(), 16) .GetData(), (uint8) dwID, (uint8)(dwID >> 8), (uint8)(dwID >> 16), (uint8)(dwID >> 24), theApp.dynprefs->Get<long>("tcp-port"));
+    f->GetFileSize(), EncodeBase16(f->GetFileHash(), 16) .GetData(), (uint8_t) dwID, (uint8_t)(dwID >> 8), (uint8_t)(dwID >> 16), (uint8_t)(dwID >> 24), theApp.dynprefs->Get<long>("tcp-port"));
     return strLink;
 }
 
