@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -22,9 +22,9 @@
 #ifndef XMULE_H
 #define XMULE_H
 
-#include "types.h"                          // Needed for uint64
-#include "wintypes.h"                       // Needed for DWORD
+#include "wintypes.h"                       // Needed for DWORD - audited 4 Nov 2004
 
+#include <stdint.h>                         // uint32_t
 #include <wx/app.h>                         // Needed for wxApp
 #include <wx/intl.h>                        // Needed for wxLocale
 #include <wx/settings.h>                    // Needed for wxSystemColour
@@ -72,17 +72,17 @@ public:
     CClientCreditsList *clientcredits;
     CFriendList *friendlist;
 //    CWebServer *webserver;
-    //virtual BOOL		InitInstance();
+    //virtual bool		InitInstance();
     virtual bool OnInit();
     wxString *pendinglink;
     //tagCOPYDATASTRUCT  sendstruct; //added by Cax2 28/10/02
     CIPFilter *ipfilter;
-    uint64 stat_sessionReceivedBytes;
-    uint64 stat_sessionSentBytes;
-    uint16 stat_reconnects;
+    uint64_t stat_sessionReceivedBytes;
+    uint64_t stat_sessionSentBytes;
+    uint16_t stat_reconnects;
     DWORD stat_transferStarttime;
     DWORD stat_serverConnectTime;
-    uint16 stat_filteredclients;
+    uint16_t stat_filteredclients;
     DWORD Start_time;
     bool daemon, nowindow;
     CLDaemon* lda;
@@ -94,8 +94,8 @@ public:
     wxString CreateED2kSourceLink(CAbstractFile *f);
     bool CopyTextToClipboard(wxString strText);
     void OnlineSig(bool zero = false);
-    void UpdateReceivedBytes(int32 bytesToAdd);
-    void UpdateSentBytes(int32 bytesToAdd);
+    void UpdateReceivedBytes(int32_t bytesToAdd);
+    void UpdateSentBytes(int32_t bytesToAdd);
     void ProcessCommand ();
     void RefreshFiles ();
     
