@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 // 
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 // 
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -39,8 +39,9 @@
 #include "ListenSocket.h"                   // Needed for CListenSocket
 #include "muuli_wdr.h"                      // Needed for ID_BUTTONCONNECT
 #include "NewSockets.h"                     // Needed for NewSocket_Stop
+#include "opcodes.h"                        // Needed for ID_XMULEDLG
 #include "PartFile.h"                       // Needed for CPartFile
-#include "Preferences.h"                    // CPreferences::ShowRatesOnTitle
+#include "Preferences.h"                    // Needed for CPreferences
 #include "PreferencesDlg.h"                 // Needed for CPreferencesDlg
 #include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
 #include "SearchDlg.h"                      // Needed for CSearchDlg
@@ -61,7 +62,7 @@
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmule.h"                          // Needed for theApp
 
-#include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
+#include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <cerrno>                           // Needed for errno
 #include <cmath>                            // Needed for ceil
@@ -82,9 +83,9 @@
 #include "pixmaps/mule_Tr_grey.ico.xpm"
 
 #if wxMINOR_VERSION > 4
-#	define CLOSEBOX wxCLOSE_BOX
+    #define CLOSEBOX wxCLOSE_BOX
 #else
-#	define CLOSEBOX 0
+    #define CLOSEBOX 0
 #endif
 
 #define ID_UQTIMER 59742
@@ -160,17 +161,22 @@ void muleDefaultToolbar(wxToolBar * parent)
     //    parent->AddCheckTool( ID_BUTTONIRC, _("IRC"),xmuleDlgImages( 19 ), wxNullBitmap, _("Internet Relay Chat"));
     parent->AddCheckTool(ID_BUTTONSTATISTICS, _("Statistics"), xmuleDlgImages(4), wxNullBitmap, _("Show current statistics"));
     parent->AddSeparator();
-    parent->AddTool(ID_BUTTONPREFERENCES, _("Preferences"), xmuleDlgImages(5), _("Modify preferences"));
+    parent->AddTool(ID_BUTTONFLOWCHART, _("Main Prefs"), xmuleDlgImages(5), _("Most setings"));
+    parent->AddTool(ID_BUTTONPREFERENCES, _("Minor Prefs"), xmuleDlgImages(6), _("Modify preferences"));
     parent->AddSeparator();
-    parent->AddTool(ID_BUTTONFLOWCHART, _("FlowChart"), xmuleDlgImages(6), _("FlowChart - Debuging & Docs"));
     parent->Realize();
 }
 
 // CxmuleDlg Dialog
 
 CxmuleDlg::CxmuleDlg(wxWindow * pParent, wxString title)
-: wxFrame(pParent, -1, title, wxDefaultPosition, wxSize(800, 520),
+: wxFrame(pParent, ID_XMULEDLG, title, wxDefaultPosition, wxSize(800, 520),
 wxCAPTION | wxRESIZE_BORDER | wxSYSTEM_MENU | wxDIALOG_NO_PARENT | wxTHICK_FRAME | wxMINIMIZE_BOX | wxMAXIMIZE_BOX | CLOSEBOX)
+{
+    OnInit();
+}
+
+void CxmuleDlg::OnInit()
 {
     theApp.xmuledlg = this;
     m_app_state = APP_STATE_STARTING;
@@ -512,7 +518,7 @@ void CxmuleDlg::AddLogLine(bool addtostatusbar, const wxChar * line, ...)
     }
     // Write into log file
     wxString filename;
-    filename = filename.Format("%s/.xMule/logfile", getenv("HOME"));
+    filename =  wxString(getenv("HOME"), *wxConvCurrent) + wxT("/.xMule/logfile");
     wxFile file(filename, wxFile::write_append);
     if (file.IsOpened())
     {
@@ -536,7 +542,7 @@ void CxmuleDlg::AddServerMessageLine(char * line, ...)
         cv->AppendText(wxString(bufferline) + wxString("\n"));
         cv->ShowPosition(cv->GetValue() .Length() - 1);
     }
-    //serverwnd.servermsgbox.AppendText(CString(bufferline)+CString("\n"));
+    //serverwnd.servermsgbox.AppendText(wxString(bufferline)+wxString("\n"));
 }
 
 void CxmuleDlg::ShowConnectionState(bool connected)
@@ -592,7 +598,7 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server, bool iconOn
  else
  statusbar.SetIcon(3,connicons[2]);
     */
-        //statusbar.SetText(GetResString(IDS_MAIN_CONNECTEDTO) +CString(server),0,0);
+        //statusbar.SetText(GetResString(IDS_MAIN_CONNECTEDTO) +wxString(server),0,0);
         wxStaticText * tx = (wxStaticText *) FindWindow("infoLabel");
         tx->SetLabel(GetResString(IDS_MAIN_CONNECTEDTO) + wxString(server));
         ((wxStaticText *) FindWindow("connLabel"))->SetLabel(server);
@@ -658,9 +664,9 @@ void CxmuleDlg::ShowConnectionState(bool connected, wxString server, bool iconOn
     }
 }
 
-void CxmuleDlg::ShowUserCount(uint32 user_toshow, uint32 file_toshow)
+void CxmuleDlg::ShowUserCount(uint32_t user_toshow, uint32_t file_toshow)
 {
-    uint32 totaluser, totalfile;
+    uint32_t totaluser, totalfile;
     totaluser = totalfile = 0;
     if (user_toshow || file_toshow)
     theApp.serverlist->GetUserFileStatus(totaluser, totalfile);
@@ -671,7 +677,7 @@ void CxmuleDlg::ShowUserCount(uint32 user_toshow, uint32 file_toshow)
     //statusbar.SetText(buffer,1,0);
 }
 
-void CxmuleDlg::ShowMessageState(uint8 iconnr)
+void CxmuleDlg::ShowMessageState(uint8_t iconnr)
 {
     //statusbar.SetIcon(4,imicons[iconnr]);
 }
@@ -748,7 +754,7 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll)
     }
 
     //PLK Show-Rates on title
-    if (theApp.glob_prefs->ShowRatesOnTitle())
+    if (theApp.dynprefs->Get<bool>("xfer-on-title") == true)
     {
         if (theApp.dynprefs->Get<bool>("command-line") == true)
         {
