@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -23,7 +23,8 @@
 #ifndef XMULEDLG_H
 #define XMULEDLG_H
 
-#include "types.h"                          // Needed for uint32
+#include <stdint.h>                         // uint8_t uint32_t
+#include <wx/imaglist.h>
 
 class CTransferWnd;
 class CServerWnd;
@@ -39,8 +40,6 @@ class wxMenu;
 class wxSocketEvent;
 class wxTimerEvent;
 
-#include <wx/imaglist.h>
-
 enum APPState {APP_STATE_RUNNING=0,
                APP_STATE_SHUTINGDOWN,
                APP_STATE_DONE,
@@ -60,6 +59,8 @@ class CKnownFileList;
 // CxmuleDlg Dialogfeld
 class CxmuleDlg :public wxFrame //CTrayDialog
 {
+private:
+    void OnInit();
 // Konstruktion
 public:
         CxmuleDlg(wxWindow* pParent=NULL, wxString title=wxT(""));      // Standardkonstruktor
@@ -71,8 +72,8 @@ public:
         void                    ShowConnectionState(bool connected);
         void                    ShowConnectionState(bool connected,wxString server,bool iconOnly=false);
         void                    ShowNotifier(wxString Text, int MsgType, bool ForceSoundOFF = false);
-        void                    ShowUserCount(uint32 toshow,uint32 filetoshow);
-        void                    ShowMessageState(uint8 iconnr);
+        void                    ShowUserCount(uint32_t toshow,uint32_t filetoshow);
+        void                    ShowMessageState(uint8_t iconnr);
         void                    SetActiveDialog(wxWindow* dlg);
         void                    ShowTransferRate(bool forceAll=true);
         void                    ShowStatistics();
@@ -98,8 +99,8 @@ public:
         CStatisticsDlg *statisticswnd;
         CSysTray *m_wndTaskbarNotifier;
         volatile APPState               m_app_state;    // added volatile to get some more security when accessing this as a shared object...
-        uint8                   status;
-        uint16                  lastbutton;
+        uint8_t                   status;
+        uint16_t                  lastbutton;
 
         DECLARE_EVENT_TABLE()
 
@@ -131,8 +132,8 @@ private:
         bool                    ready;
         wxBitmap transicons[4];
 
-        uint32                  lastuprate;
-        uint32                  lastdownrate;
+        uint32_t                  lastuprate;
+        uint32_t                  lastdownrate;
         wxImageList             imagelist;
         wxMenu          *trayPopup;
 
